<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Auntri_Elementor_Blog extends Widget_Base {

	
	public function get_name() {
		return 'auntri_elementor_blog';
	}
	
	public function get_title() {
		return esc_html__( 'Blog', 'auntri' );
	}
	
	public function get_icon() {
		return 'eicon-posts-ticker';
	}
	
	public function get_categories() {
		return [ 'auntri' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$args = array(
			'orderby' => 'name',
			'order' => 'ASC'
		);
  
		$categories 	= get_categories($args);
		$cate_array 	= array();
		$arrayCateAll 	= array( 'all' => esc_html__( 'All categories', 'auntri' ) );
		if ($categories) {
			foreach ( $categories as $cate ) {
				$cate_array[$cate->slug] = $cate->cat_name;
			}
		} else {
			$cate_array[ esc_html__( 'No content Category found', 'auntri' ) ] = 0;
		}
  
		  	//SECTION CONTENT
		  	$this->start_controls_section(
			  	'section_content',
			  	[
				  	'label' => esc_html__( 'Content', 'auntri' ),
			  	]
		  	);

		  	$this->add_control(
				'version',
				[
					'label' => esc_html__( 'Version', 'auntri' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'version_2',
					'options' => [
						'version_1' => esc_html__( 'Version 1', 'auntri' ),
						'version_2' => esc_html__( 'Version 2', 'auntri' ),
						'version_3' => esc_html__( 'Version 3', 'auntri' ),
						'version_4' => esc_html__( 'Version 4', 'auntri' ),
					]
				]
			);
  
			$this->add_control(
				'category',
				[
					'label' => esc_html__( 'Category', 'auntri' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'all',
					'options' => array_merge($arrayCateAll,$cate_array),
				]
			);
  
			$this->add_control(
				'total_count',
				[
					'label' => esc_html__( 'Post Total', 'auntri' ),
					'type' => Controls_Manager::NUMBER,
					'default' => 3,
				]
			);
  
			$this->add_control(
				'number_column',
				[
					'label' => esc_html__( 'Columns', 'auntri' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'column_3',
					'options' => [
						'column_2' => esc_html__( '2 Columns', 'auntri' ),
						'column_3' => esc_html__( '3 Columns', 'auntri' ),
						'column_4' => esc_html__( '4 Columns', 'auntri' ),
					  ],
					'condition' => [
					  	'version!' => 'version_2', 
					],
				]
			);
  
  
			$this->add_control(
				'order',
				[
					  'label' => esc_html__('Order', 'auntri'),
					  'type' => Controls_Manager::SELECT,
					  'default' => 'desc',
					  'options' => [
						  'asc' => esc_html__('Ascending', 'auntri'),
						  'desc' => esc_html__('Descending', 'auntri'),
					  ]
				]
			);

			$this->add_control(
				'order_by',
				[
					'label' 	=> esc_html__('Order By', 'auntri'),
					'type' 		=> \Elementor\Controls_Manager::SELECT,
					'default' 	=> 'ID',
					'options' 	=> [
						'none' => esc_html__('None', 'auntri'),
						'ID' => esc_html__('ID', 'auntri'),
						'title' => esc_html__('Title', 'auntri'),
						'date' => esc_html__('Date', 'auntri'),
						'modified' => esc_html__('Modified', 'auntri'),
						'rand' => esc_html__('Rand', 'auntri'),
					]
				]
			);
  
			$this->add_control(
				  'text_readmore',
				  [
					  'label' => esc_html__( 'Text Read More', 'auntri' ),
					  'type' => Controls_Manager::TEXT,
					  'default' => esc_html__('Read More', 'auntri'),
					  'condition' => [
					  	'version' => 'version_1', 
					  ],
				  ]
			);
  
			$this->add_control(
				  'show_short_desc',
				  [
					  'label' => esc_html__( 'Show Short Description', 'auntri' ),
					  'type' => \Elementor\Controls_Manager::SWITCHER,
					  'label_on' => esc_html__( 'Show', 'auntri' ),
					  'label_off' => esc_html__( 'Hide', 'auntri' ),
					  'return_value' => 'yes',
					  'default' => 'yes',
					   'condition' => [
					  	'version' => ['version_1','version_4'], 
					  ],
				  ]
			);

			$this->add_control(
				  'order_text',
				  [
					  'label' => esc_html__( 'Description Words Total', 'auntri' ),
					  'type' => Controls_Manager::NUMBER,
					  'default' => 15,
					  'condition' => [
						  'show_short_desc' => 'yes',
						  'version' => 'version_4',
					  ]
				  ]
			);
  
			$this->add_control(
				  'show_comment',
				  [
					  'label' => esc_html__( 'Show Comment', 'auntri' ),
					  'type' => \Elementor\Controls_Manager::SWITCHER,
					  'label_on' => esc_html__( 'Show', 'auntri' ),
					  'label_off' => esc_html__( 'Hide', 'auntri' ),
					  'return_value' => 'yes',
					  'default' => 'yes',
					   'condition' => [
					  	'version!' => 'version_3', 
					  ],
				  ]
			);
  
			$this->add_control(
				  'show_date',
				  [
					  'label' => esc_html__( 'Show Date', 'auntri' ),
					  'type' => \Elementor\Controls_Manager::SWITCHER,
					  'label_on' => esc_html__( 'Show', 'auntri' ),
					  'label_off' => esc_html__( 'Hide', 'auntri' ),
					  'return_value' => 'yes',
					  'default' => 'yes',
					  'condition' => [
					  	'version!' => 'version_2', 
					  ],
				  ]
			);
  
			$this->add_control(
				  'show_author',
				  [
					  'label' => esc_html__( 'Show Author', 'auntri' ),
					  'type' => \Elementor\Controls_Manager::SWITCHER,
					  'label_on' => esc_html__( 'Show', 'auntri' ),
					  'label_off' => esc_html__( 'Hide', 'auntri' ),
					  'return_value' => 'yes',
					  'default' => 'yes',
					  'condition' => [		
						'version!' => ['version_4'],
					  ]
				  ]
			);
  
  
			$this->add_control(
				'show_title',
				[
					  'label' => esc_html__( 'Show Title', 'auntri' ),
					  'type' => \Elementor\Controls_Manager::SWITCHER,
					  'label_on' => esc_html__( 'Show', 'auntri' ),
					  'label_off' => esc_html__( 'Hide', 'auntri' ),
					  'return_value' => 'yes',
					  'default' => 'yes',
				]
			);
  
			$this->add_control(
				'show_read_more',
				[
					  'label' => esc_html__( 'Show Read More', 'auntri' ),
					  'type' => \Elementor\Controls_Manager::SWITCHER,
					  'label_on' => esc_html__( 'Show', 'auntri' ),
					  'label_off' => esc_html__( 'Hide', 'auntri' ),
					  'return_value' => 'yes',
					  'default' => 'yes',
					  'condition' => [
						'version' => ['version_1'],
					]
				]
			);

			$this->add_control(
				  'show_icon',
				  [
					  'label' => esc_html__( 'Show Icon', 'auntri' ),
					  'type' => \Elementor\Controls_Manager::SWITCHER,
					  'label_on' => esc_html__( 'Show', 'auntri' ),
					  'label_off' => esc_html__( 'Hide', 'auntri' ),
					  'return_value' => 'yes',
					  'default' => 'yes',
					  'condition' => [
						'version' => ['version_4'],
					]
				  ]
			);

			$this->add_control(
				'icon_readmore',
				[
					'label' => esc_html__( 'Icon', 'auntri' ),
					'type' => \Elementor\Controls_Manager::ICONS,
					'default' 	=> [
						'value' 	=> 'flaticon flaticon-right-arrow',
						'library' 	=> 'all',	
					],
					'condition' => [
						'show_icon' => 'yes',
						'version' => 'version_4',
					]
				]
			);
  
		  $this->end_controls_section();
		  //END SECTION CONTENT
  
  
		  /* Begin General Style */
		  $this->start_controls_section(
			  'general',
			  [
				  'label' => esc_html__( 'General', 'auntri' ),
				  'tab' 	=> Controls_Manager::TAB_STYLE,
			  ]
		  );
  
			  $this->add_responsive_control(
				  'general_align',
				  [
					  'label' 	=> esc_html__( 'Alignment', 'auntri' ),
					  'type' 		=> \Elementor\Controls_Manager::CHOOSE,
					  'options' 	=> [
						  'left' => [
							  'title' => esc_html__( 'Left', 'auntri' ),
							  'icon' 	=> 'eicon-text-align-left',
						  ],
						  'center' => [
							  'title' => esc_html__( 'Center', 'auntri' ),
							  'icon' 	=> 'eicon-text-align-center',
						  ],
						  'right' => [
							  'title' => esc_html__( 'Right', 'auntri' ),
							  'icon' 	=> 'eicon-text-align-right',
						  ],
						  
					  ],
					  'toggle' 	=> true,
					  'selectors' => [
						  '{{WRAPPER}} .ova-blog .item .content' => 'text-align: {{VALUE}};',
						  
					  ],
				  ]
			  );
  
			  	$this->add_responsive_control(
				  	'general_padding',
				  	[
					  	'label' => esc_html__( 'Padding', 'auntri' ),
					  	'type' => Controls_Manager::DIMENSIONS,
					  	'size_units' => [ 'px', 'em', '%' ],
					  	'selectors' => [
						  	'{{WRAPPER}} .ova-blog .item .content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					  	],
				  	]
			  	);
  
			  
			  	$this->add_responsive_control(
				  	'general_margin',
				  	[
					  	'label' => esc_html__( 'Margin', 'auntri' ),
					  	'type' => Controls_Manager::DIMENSIONS,
					  	'size_units' => [ 'px', 'em', '%' ],
					  	'selectors' => [
						  	'{{WRAPPER}} .ova-blog .item .content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					  	],
				  	]
			  	);
  
			  	$this->add_control(
				 	'template_general_background',
				  	[
					  	'label'	 	=> esc_html__( 'Background', 'auntri' ),
					  	'type' 		=> Controls_Manager::COLOR,
					  	'selectors' => [
						  '{{WRAPPER}} .ova-blog .item .content' => 'background-color : {{VALUE}};'	
					  	],
					  	'condition' => [
					  		'version' => ['version_1','version_4'],
					  	],
				  	]
			  	);

			  	$this->add_control(
				 	'line_bottom_content_v1',
				  	[
					  	'label'	 	=> esc_html__( 'Line Bottom Color', 'auntri' ),
					  	'type' 		=> Controls_Manager::COLOR,
					  	'selectors' => [
						  '{{WRAPPER}} .ova-blog.version_1 .item .content:after' => 'background-color : {{VALUE}};'	
					  	],
					  	'condition' => [
					  		'version' => ['version_1'],
					  	],
				  	]
			  	);

			  	// version 2
				$this->start_controls_tabs(
					'style_tabs_version_2_background',

				);

					$this->start_controls_tab(
						'style_bg_normal_tab',
						[
							'label' => esc_html__( 'Normal', 'auntri' ),
							'condition' => [
						  		'version' => 'version_2',
						  	],
						]
					);
						$this->add_group_control(
							\Elementor\Group_Control_Background::get_type(),
							[
								'name' 		=> 	'background_template_2__item',
								'label' 	=> 	esc_html__( 'Background First Item', 'auntri' ),
								'types' 	=> 	[ 'classic', 'gradient' ],
								'selector' 	=> 	'{{WRAPPER}} .ova-blog.version_2 .item:not(:first-child) .content',
								'condition' => [
							  		'version' => 'version_2',
							  	],
							]
						);

					$this->end_controls_tab();				

					$this->start_controls_tab(
						'style_bg_first_item_tab',
						[
							'label' => esc_html__( 'First Item', 'auntri' ),
							'condition' => [
						  		'version' => 'version_2',
						  	],
						]
					);

						$this->add_group_control(
							\Elementor\Group_Control_Background::get_type(),
							[
								'name' 		=> 	'background_template_2_first_item',
								'label' 	=> 	esc_html__( 'Background First Item', 'auntri' ),
								'types' 	=> 	[ 'classic', 'gradient' ],
								'selector' 	=> 	'{{WRAPPER}} .ova-blog.version_2 .item:first-child .media a:after',
								'condition' => [
							  		'version' => 'version_2',
							  	],
							]
						);

						$this->add_group_control(
							\Elementor\Group_Control_Border::get_type(),
							[
								'name' => 'border_first-item-template-2',
								'label' => esc_html__( 'Border', 'auntri' ),
								'selector' => '{{WRAPPER}} .ova-blog.version_2 .item:first-child',
							]
						);

					$this->end_controls_tab();

				$this->end_controls_tabs();

			  	//version 3
		  		$this->add_group_control(
					\Elementor\Group_Control_Background::get_type(),
					[
						'name' => 'background_template_3',
						'label' => esc_html__( 'Background', 'auntri' ),
						'types' => [ 'classic', 'gradient' ],
						'selector' => '{{WRAPPER}} .ova-blog.version_3 .item .media a:after',
						'condition' => [
						  	'version' => 'version_3',
						],
					]
				);
  
		  	$this->end_controls_section();
		  	/* End General style */
  
  
		  	//SECTION TAB STYLE TITLE
		  	$this->start_controls_section(
			  	'section_title',
			  	[
				  	'label' => esc_html__( 'Title', 'auntri' ),
				  	'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			  	]
		  	);
  
		  $this->add_group_control(
			  \Elementor\Group_Control_Typography::get_type(),
			  [
				  'name' => 'title_typography',
				  'selector' => '{{WRAPPER}} .ova-blog .item .content .post-title a',
				  
			  ]
		  );
  
		  $this->add_control(
			  'color_title',
			  [
				  'label' => esc_html__( 'Color', 'auntri' ),
				  'type' => \Elementor\Controls_Manager::COLOR,
				  'selectors' => [
					  '{{WRAPPER}} .ova-blog .item .content .post-title a' => 'color : {{VALUE}};',
				  ],
			  ]
		  );
  
		  $this->add_control(
			  'color_title_hover',
			  [
				  'label' => esc_html__( 'Color Hover', 'auntri' ),
				  'type' => \Elementor\Controls_Manager::COLOR,
				  'selectors' => [
					  '{{WRAPPER}} .ova-blog .item .content .post-title a:hover' => 'color : {{VALUE}};',
				  ],
			  ]
		  );
  
		  $this->add_responsive_control(
			  'margin_title',
			  [
				  'label' => esc_html__( 'Margin', 'auntri' ),
				  'type' => \Elementor\Controls_Manager::DIMENSIONS,
				  'size_units' => [ 'px', 'em', '%' ],
				  'selectors' => [
					  '{{WRAPPER}} .ova-blog .item .content .post-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				  ],
			  ]
		  );
  
		  $this->add_responsive_control(
			  'padding_title',
			  [
				  'label' => esc_html__( 'Padding', 'auntri' ),
				  'type' => \Elementor\Controls_Manager::DIMENSIONS,
				  'size_units' => [ 'px', 'em', '%' ],
				  'selectors' => [
					  '{{WRAPPER}} .ova-blog .item .content .post-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				  ],
			  ]
		  );
  
		  $this->end_controls_section();
		  //END SECTION TAB STYLE TITLE
  
  
		  $this->start_controls_section(
			  'section_short_desc',
			  [
				  'label' => esc_html__( 'Short Description', 'auntri' ),
				  'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				  'condition' => [
				  	'version' => ['version_1','version_4'],
				  ]
			  ]
		  );
  
		  $this->add_group_control(
			  \Elementor\Group_Control_Typography::get_type(),
			  [
				  'name' => 'short_desc_typography',
				  'selector' => '{{WRAPPER}} .ova-blog .item .content .short_desc p',
				  
			  ]
		  );
  
		  $this->add_control(
			  'color_short_desc',
			  [
				  'label' => esc_html__( 'Color', 'auntri' ),
				  'type' => \Elementor\Controls_Manager::COLOR,
				  'selectors' => [
					  '{{WRAPPER}} .ova-blog .short_desc p' => 'color : {{VALUE}};',
				  ],
			  ]
		  );
  
		  $this->add_responsive_control(
			  'margin_short_desc',
			  [
				  'label' => esc_html__( 'Margin', 'auntri' ),
				  'type' => \Elementor\Controls_Manager::DIMENSIONS,
				  'size_units' => [ 'px', 'em', '%' ],
				  'selectors' => [
					  '{{WRAPPER}} .ova-blog .item .content .short_desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				  ],
			  ]
		  );
  
		  $this->add_responsive_control(
			  'padding_short_desc',
			  [
				  'label' => esc_html__( 'Padding', 'auntri' ),
				  'type' => \Elementor\Controls_Manager::DIMENSIONS,
				  'size_units' => [ 'px', 'em', '%' ],
				  'selectors' => [
					  '{{WRAPPER}} .ova-blog .item .content .short_desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				  ],
			  ]
		  );
  
		  $this->end_controls_section();
		  //END SECTION TAB STYLE TITLE
  
			//BEGIN META STYLE
			$this->start_controls_section(
			  'section_meta',
			  	[
				  	'label' => esc_html__( 'Meta', 'auntri' ),
				  	'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				  	'condition' => [
				  		'version!' => 'version_3',
				  	]
			  	]
			);

			$this->add_group_control(
			  \Elementor\Group_Control_Typography::get_type(),
			  [
				  'name' => 'meta_typography',
				  'selector' => '{{WRAPPER}} .ova-blog .item .content .post-meta .item-meta .right a, .ova-blog .item .content .post-meta .item-meta .left i',
				  
			  ]
			);

			$this->add_control(
			  'text_color_meta',
			  [
				  'label' => esc_html__( 'Text Color', 'auntri' ),
				  'type' => \Elementor\Controls_Manager::COLOR,
				  'selectors' => [
					  '{{WRAPPER}} .ova-blog .item .content .post-meta .item-meta .right a' => 'color : {{VALUE}};',
					  '{{WRAPPER}} .item .content .post-meta .item-meta .right .by' => 'color : {{VALUE}};',
				  ],
			  ]
			);

			$this->add_control(
			  	'link_color_meta_hover',
			  	[
				 	 'label' => esc_html__( 'Link Color hover', 'auntri' ),
				  	'type' => \Elementor\Controls_Manager::COLOR,
				  	'selectors' => [
					  	'{{WRAPPER}} .ova-blog .item .post-meta .item-meta .right a:hover' => 'color : {{VALUE}};',
				  	],
			  	]
			);

			$this->add_control(
			  'icon_color_meta',
			  [
				  'label' => esc_html__( 'Icon Color', 'auntri' ),
				  'type' => \Elementor\Controls_Manager::COLOR,
				  'selectors' => [
					  '{{WRAPPER}} .ova-blog .item .post-meta .item-meta .left' => 'color : {{VALUE}};',
				  ],
			  ]
			);

			$this->add_responsive_control(
			  'margin_meta',
			  [
				  'label' => esc_html__( 'Margin', 'auntri' ),
				  'type' => \Elementor\Controls_Manager::DIMENSIONS,
				  'size_units' => [ 'px', 'em', '%' ],
				  'selectors' => [
					  '{{WRAPPER}} .ova-blog .item .content .post-meta' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				  ],
			  ]
			);

			$this->add_responsive_control(
			  'padding_meta_item',
			  [
				  'label' => esc_html__( 'Padding Item', 'auntri' ),
				  'type' => \Elementor\Controls_Manager::DIMENSIONS,
				  'size_units' => [ 'px', 'em', '%' ],
				  'selectors' => [
					  '{{WRAPPER}} .ova-blog.version_1 .item .content .post-meta li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				  ],
				  'condition' => [
					  	'version' => 'version_1',
					],
			  ]
			);

			$this->start_controls_tabs(
				'style_tabs_author_comment',
			);

				$this->start_controls_tab(
					'style_author_tab',
					[
						'label' => esc_html__( 'Author', 'auntri' ),
						'condition' => [
						  	'version' => 'version_1',
						],

					]
				);

					$this->add_responsive_control(
					  'margin_author',
					  [
						  'label' => esc_html__( 'Margin', 'auntri' ),
						  'type' => \Elementor\Controls_Manager::DIMENSIONS,
						  'size_units' => [ 'px', 'em', '%' ],
						  'selectors' => [
							  '{{WRAPPER}} .ova-blog.version_1 .item .content .post-meta .item-meta.wp-author' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						  ],
						  'condition' => [
						  	'version' => 'version_1',
						  ],
					  ]
					);

				$this->end_controls_tab();

				$this->start_controls_tab(
					'style_comment_tab',
					[
						'label' => esc_html__( 'Comments', 'auntri' ),
						'condition' => [
						  	'version' => 'version_1',
						],
					]
				);
					$this->add_responsive_control(
					  'margin_comment',
					  [
						  'label' => esc_html__( 'Margin', 'auntri' ),
						  'type' => \Elementor\Controls_Manager::DIMENSIONS,
						  'size_units' => [ 'px', 'em', '%' ],
						  'selectors' => [
							  '{{WRAPPER}} .ova-blog.version_1 .item .content .post-meta .item-meta.wp-author' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						  ],
						  'condition' => [
						  	'version' => 'version_1',
						  ],
					  ]
					);

				$this->end_controls_tab();

			$this->end_controls_tabs();
  
		  $this->end_controls_section();
  
		  // DATE TAB
		  $this->start_controls_section(
			  'date_section',
			  [
				  'label' => esc_html__( 'Date', 'auntri' ),
				  'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				   'condition' => [
				  	'version!' => 'version_2',
				  ]
			  ]
		  );
  
			  $this->add_group_control(
				  \Elementor\Group_Control_Typography::get_type(),
				  [
					  'name' => 'date_typography',
					  'selector' => '{{WRAPPER}} .ova-blog .item .post-date',
					  
				  ]
			  );
	  
			  $this->add_control(
				  'date_color',
				  [
					  'label' => esc_html__( 'Color', 'auntri' ),
					  'type' => \Elementor\Controls_Manager::COLOR,
					  'selectors' => [
						  '{{WRAPPER}} .ova-blog .item .post-date' => 'color : {{VALUE}};',
					  ],
				  ]
			  );
	  
			  $this->add_control(
				  'date_color_hover',
				  [
					  'label' => esc_html__( 'Color Hover', 'auntri' ),
					  'type' => \Elementor\Controls_Manager::COLOR,
					  'selectors' => [
						  '{{WRAPPER}} .ova-blog .item .post-date:hover' => 'color : {{VALUE}};',
					  ],
				  ]
			  );
	  
			$this->add_control(
				'date_cat_color',
				[
					'label' => esc_html__( 'Background', 'auntri' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-blog .item .post-date, {{WRAPPER}} .ova-blog .item .post-date:before, {{WRAPPER}} .ova-blog .item .post-date:after' => 'background-color : {{VALUE}};',
					],
					'condition' => [
				  		'version!' => 'version_3'
				  	]
				]
			);
	  
			$this->add_control(
				'bg_date_color_hover',
				[
				  	'label' => esc_html__( 'Background Hover', 'auntri' ),
				  	'type' => \Elementor\Controls_Manager::COLOR,
				  	'selectors' => [
					  	'{{WRAPPER}} .ova-blog:hover .item .post-date, {{WRAPPER}} .ova-blog.version_1:hover .item .post-date:before, {{WRAPPER}} .ova-blog.version_1:hover .item .post-date:after' => 'background-color : {{VALUE}};',
				  	],
				  	'condition' => [
				  		'version!' => 'version_3'
				  	]
				]
			);
	  
			  $this->add_responsive_control(
				  'date_padding',
				  [
					  'label' => esc_html__( 'Padding', 'auntri' ),
					  'type' => \Elementor\Controls_Manager::DIMENSIONS,
					  'size_units' => [ 'px', 'em', '%' ],
					  'selectors' => [
						  '{{WRAPPER}} .ova-blog .item .post-date' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					  ],
				  ]
			  );
	  
			  $this->add_responsive_control(
				  'date_margin',
				  [
					  'label' => esc_html__( 'Margin', 'auntri' ),
					  'type' => \Elementor\Controls_Manager::DIMENSIONS,
					  'size_units' => [ 'px', 'em', '%' ],
					  'selectors' => [
						  '{{WRAPPER}} .ova-blog .item .post-date' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					  ],
				  ]
			  );

			    $this->add_responsive_control(
				  'date_align',
				  	[
					  	'label' 	=> esc_html__( 'Alignment', 'auntri' ),
					  	'type' 		=> \Elementor\Controls_Manager::CHOOSE,
					  	'options' 	=> [
						  	'right:unset;' => [
							  	'title' => esc_html__( 'Left', 'auntri' ),
							  	'icon' 	=> 'eicon-text-align-left',
						  	],
						  	'left:unset;' => [
							  	'title' => esc_html__( 'Right', 'auntri' ),
							  	'icon' 	=> 'eicon-text-align-right',
						  	],	  
					  	],
					  	'toggle' 	=> true,
					  	'selectors' => [
						 	'{{WRAPPER}} .ova-blog.version_1 .item .post-date' => '{{VALUE}};',
						  	'{{WRAPPER}} .ova-blog.version_3 .item .content .post-meta' => '{{VALUE}};',
						  
					  	],
					  	'condition' => [
						  	'version' => ['version_1','version_3']
						],
				  	]
			    );

			    $this->add_responsive_control(
					'date_position_top',
					[
						'label' => esc_html__( 'Top', 'auntri' ),
						'type' => Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'min' => 20,
								'max' => 150,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .ova-blog.version_1 .item .post-date' => 'top: {{SIZE}}{{UNIT}}; ',
							'{{WRAPPER}} .ova-blog.version_3 .item .content .post-meta' => 'top: {{SIZE}}{{UNIT}}; ',
						],
						'condition' => [
						  	'version' => ['version_1','version_3']
						],				
					]
				);


			$this->add_responsive_control(
				'date_position_left',
				[
					'label' => esc_html__( 'Left', 'auntri' ),
					'type' => Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 20,
							'max' => 150,
						],
					],
					'toggle' 	=> true,
					'selectors' => [
						'{{WRAPPER}} .ova-blog.version_1 .item .post-date' => 'left: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}} .ova-blog.version_3 .item .content .post-meta' => 'left: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'date_align' => 'right:unset;',
						'version' => ['version_1','version_3']
					]
				]
			); 

			  $this->add_responsive_control(
				'date_position_right',
				[
					'label' => esc_html__( 'Right', 'auntri' ),
					'type' => Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 20,
							'max' => 150,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-blog.version_1 .item .post-date' => 'right: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}} .ova-blog.version_3 .item .content .post-meta' => 'right: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'date_align' => 'left:unset;',
						'version' => ['version_1','version_3']
					]
				]
			);
  
		  $this->end_controls_section(); 
		  // END Category Tab
  
		  //SECTION TAB STYLE READMORE
		  $this->start_controls_section(
			  'section_readmore',
			  [
				  'label' => esc_html__( 'Read More', 'auntri' ),
				  'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				  'condition' => [
				  	'version' => [
				  		'version_1',
				  	],
				  ]
			  ]
		  );
  
			  $this->add_group_control(
				  \Elementor\Group_Control_Typography::get_type(),
				  [
					  'name' => 'readmore_typography',
					  'selector' => '{{WRAPPER}} .ova-blog .item .content .read-more',
					  
				  ]
			  );
	  
			  $this->add_control(
				  'color_readmore',
				  [
					  'label' => esc_html__( 'Color', 'auntri' ),
					  'type' => \Elementor\Controls_Manager::COLOR,
					  'selectors' => [
						  '{{WRAPPER}} .ova-blog .item .content .read-more' => 'color : {{VALUE}};',
					  ],
				  ]
			  );
	  
			  $this->add_control(
				  'color_readmore_hover',
				  [
					  'label' => esc_html__( 'Color Hover', 'auntri' ),
					  'type' => \Elementor\Controls_Manager::COLOR,
					  'selectors' => [
						  '{{WRAPPER}} .ova-blog .item .content .read-more:hover' => 'color : {{VALUE}};',
					  ],
				  ]
			  );

			  $this->add_control(
				  'color_line_readmore',
				  [
					  'label' => esc_html__( 'Line', 'auntri' ),
					  'type' => \Elementor\Controls_Manager::COLOR,
					  'selectors' => [
						  '{{WRAPPER}} .ova-blog.version_1 .item .content .read-more::after' => 'background-color : {{VALUE}};',
					  ],
				  ]
			  );
	  
			  $this->add_control(
				  'color_line_readmore_hover',
				  [
					  'label' => esc_html__( 'Line Hover', 'auntri' ),
					  'type' => \Elementor\Controls_Manager::COLOR,
					  'selectors' => [
						  '{{WRAPPER}} .ova-blog.version_1 .item .content .read-more::before' => 'background-color : {{VALUE}};',
					  ],
				  ]
			  );
	  
			  $this->add_responsive_control(
				  'margin_readmore',
				  [
					  'label' => esc_html__( 'Margin', 'auntri' ),
					  'type' => \Elementor\Controls_Manager::DIMENSIONS,
					  'size_units' => [ 'px', 'em', '%' ],
					  'selectors' => [
						  '{{WRAPPER}} .ova-blog .item .content .read-more' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					  ],
				  ]
			  );
  
		  $this->end_controls_section();
		  //END SECTION TAB STYLE READMORE
		  
		  //SECTION TAB STYLE ICON
		  $this->start_controls_section(
			  'section_icon',
			  [
				  'label' => esc_html__( 'Icon', 'auntri' ),
				  'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				  'condition' => [
				  	'version' => [
				  		'version_4',
				  	],
				  ]
			  ]
		  );

			$this->add_control(
				'icon_color',
				[
				  	'label' => esc_html__( 'Color', 'auntri' ),
				  	'type' => \Elementor\Controls_Manager::COLOR,
				  	'selectors' => [
					  	'{{WRAPPER}} .ova-blog.version_4 .item .content .icon' => 'color : {{VALUE}};',
				  	],
				]
			);

			$this->add_control(
				'icon_color_hover',
				[
				  	'label' => esc_html__( 'Color Hover', 'auntri' ),
				  	'type' => \Elementor\Controls_Manager::COLOR,
				  	'selectors' => [
					  	'{{WRAPPER}} .ova-blog.version_4 .item:hover .content .icon' => 'color : {{VALUE}};',
				  	],
				]
			);

			$this->add_control(
				'icon_background_color',
				[
				  	'label' => esc_html__( 'Background', 'auntri' ),
				  	'type' => \Elementor\Controls_Manager::COLOR,
				  	'selectors' => [
					  	'{{WRAPPER}} .ova-blog.version_4 .item .content .icon' => 'background-color : {{VALUE}};',
				  	],
				]
			);

			$this->add_control(
				'icon_background_color_hover',
				[
				  	'label' => esc_html__( 'Background Hover', 'auntri' ),
				  	'type' => \Elementor\Controls_Manager::COLOR,
				  	'selectors' => [
					  	'{{WRAPPER}} .ova-blog.version_4 .item .content .icon:hover:before' 	=> 'background-color : {{VALUE}};',
					  	'{{WRAPPER}} .ova-blog.version_4 .item:hover .content .icon' 			=> 'background-color : {{VALUE}};',
				  	],
				]
			);

			$this->add_responsive_control(
				'icon_size',
				[
					'label' => esc_html__( 'Font Size', 'auntri' ),
					'type' => Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 10,
							'max' => 20,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-blog.version_4 .item .content .icon i' => 'font-size: {{SIZE}}{{UNIT}}',
					],
				]
			);

			$this->add_responsive_control(
				'icon_width',
				[
					'label' => esc_html__( 'Background Size', 'auntri' ),
					'type' => Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 20,
							'max' => 50,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-blog.version_4 .item .content .icon' => 'width: {{SIZE}}{{UNIT}} ;height: {{SIZE}}{{UNIT}}',
					],
				]
			);

			$this->add_responsive_control(
				'icon_position',
				[
					'label' => esc_html__( 'Right', 'auntri' ),
					'type' => Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 20,
							'max' => 50,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-blog.version_4 .item .content .icon' => 'right: {{SIZE}}{{UNIT}} ',
					],
				]
			);

			$this->add_control(
				'line_background_color',
				[
				  'label' => esc_html__( 'Line', 'auntri' ),
				  'type' => \Elementor\Controls_Manager::COLOR,
				  'selectors' => [
					  '{{WRAPPER}} .ova-blog.version_4 .item .content:after' => 'background-color : {{VALUE}};',
				  ],
				]
			);

			$this->add_control(
				'line_hover_background_color',
				[
				  'label' => esc_html__( 'Line Hover', 'auntri' ),
				  'type' => \Elementor\Controls_Manager::COLOR,
				  'selectors' => [
					  '{{WRAPPER}} .ova-blog.version_4 .item .content:before' => 'background-color : {{VALUE}};',
				  ],
				]
			);


		  $this->end_controls_section();
		  //END SECTION TAB STYLE ICON
  		
		//SECTION TAB First ITEM VERSION 2
		$this->start_controls_section(
			'section_first_item',
			[
				'label' => esc_html__( 'First Item', 'auntri' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				'condition' => [
				  	'version' => [
				  		'version_2',
				  	],
				]
			]
		);

		    $this->add_group_control(
			  	\Elementor\Group_Control_Typography::get_type(),
			  	[
				  	'name' => 'first_item_typography',
				  	'selector' => '{{WRAPPER}} .ova-blog.version_2 .item:first-child .content .post-title a',
				  
			  	]
			);

		  	$this->add_control(
				'first_item_title_color',
				[
				  'label' => esc_html__( 'Color', 'auntri' ),
				  'type' => \Elementor\Controls_Manager::COLOR,
				  'selectors' => [
					  '{{WRAPPER}} .ova-blog.version_2 .item:first-child .content .post-title a' => 'color : {{VALUE}};',
				  ],
				]
			);

			$this->add_control(
				'first_item_title_color_hover',
				[
				  'label' => esc_html__( 'Color Hover', 'auntri' ),
				  'type' => \Elementor\Controls_Manager::COLOR,
				  'selectors' => [
					  '{{WRAPPER}} .ova-blog.version_2 .item:first-child .content .post-title a:hover' => 'color : {{VALUE}};',
				  ],
				]
			);

			$this->add_responsive_control(
				  'first_item_padding_content',
				  [
					  'label' => esc_html__( 'Padding', 'auntri' ),
					  'type' => \Elementor\Controls_Manager::DIMENSIONS,
					  'size_units' => [ 'px', 'em', '%' ],
					  'selectors' => [
						  '{{WRAPPER}} .ova-blog.version_2 .item:first-child .content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					  ],
				  ]
			);

		
		$this->end_controls_section();
  
	  }
  
	  /**
	   * Render the widget output on the frontend.
	   *
	   * Written in PHP and used to generate the final HTML.
	   *
	   * @since 1.0.0
	   *
	   * @access protected
	   */
	  	protected function render() {
			$settings 			= $this->get_settings_for_display();
			$version 			=	$settings['version'];
			$category 			= 	$settings['category'];
			$total_count 		= 	$settings['total_count'];
			$order 				= 	$settings['order'];
			$order_by 			= 	$settings['order_by'];
			$number_column 		= 	$settings['number_column'];
			$order_text	 		= 	$settings['order_text'] ? $settings['order_text'] : '10';

			$show_date 			= 	$settings['show_date'];
			$show_author 		= 	$settings['show_author'];
			$show_title 		= 	$settings['show_title'];
			$show_short_desc 	= 	$settings['show_short_desc'];
			$show_comment 		= 	$settings['show_comment'];
			$show_read_more		= 	$settings['show_read_more'];
			$text_readmore 		= 	$settings['text_readmore'];
			$show_icon 			=	$settings['show_icon'];
			$icon_readmore 		=	$settings['icon_readmore'];

			if ( $version == 'version_2') {
				$number_column = 'column';
			}
  
			$args = [];
			if ($category == 'all') {
			  	$args = [
				  	'post_type' 		=> 'post',
				  	'posts_per_page' 	=> $total_count,
				  	'order' 			=> $order,
				  	'orderby' 			=> $order_by,
			  	];
			} else {
			  	$args = [
				  	'post_type' 		=> 	'post', 
				  	'category_name'		=>	$category,
				  	'posts_per_page' 	=> 	$total_count,
				  	'order' 			=> 	$order,
				  	'orderby' 			=> $order_by,
				  	'fields'			=> 	'ids'
			  	];
			}

			$blog = new \WP_Query($args);

			?>

			<ul class="ova-blog ova-<?php echo esc_attr( $number_column ); ?> <?php echo esc_attr( $version); ?> ">
			  	<?php
				  	if($blog->have_posts()) : while($blog->have_posts()) : $blog->the_post();
			  	?>
				  <li class="item">

				  	<div class="media">

					  	<?php
					  		$size_img  = $version == 'version_2' ? 'large' : 'auntri_thumbnail' ;
						  	$thumbnail = wp_get_attachment_image_url(get_post_thumbnail_id() , $size_img );
						  	$url_thumb = $thumbnail ? $thumbnail : \Elementor\Utils::get_placeholder_image_src();
					  	?>

					  	<div class="box-img">
					  		<a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>">
							  	<img src="<?php echo esc_url( $url_thumb ) ?>" alt="<?php the_title(); ?>">
						  	</a>
					  	</div>		  	
					  	
					  	<?php if($version == 'version_1'): ?>
							<?php if( $show_date == 'yes' ){ ?>
								<div class="post-date">
									<span class="date-j"><?php the_time('j' );?></span>
									<span class="date-f"><?php the_time('M' );?></span>
								</div>
						<?php } endif;?>

				  	</div>

				  	<div class="content">
							
					  	<ul class="post-meta">
							<?php if($version == 'version_1' || $version == 'version_2' || $version == 'version_3' ){ ?>
							  	<?php if( $show_author == 'yes' ){ ?>
								  <li class="item-meta wp-author">
									  <span class="left author">
										   <i class="fas fa-user-circle"></i>
									  </span>
									  <span class="right post-author">
									  		<span class="by">
									  			<?php echo esc_html__('by', 'auntri'); ?>	
									  		</span>
									  		
										  	<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ) ); ?>">
											  	<?php the_author_meta( 'display_name' ); ?>
										  	</a>
									  </span>
								  </li>
						  		<?php }  };?>

								
								<?php if( $show_date == 'yes' && $version == 'version_4' ){ ?>
										<li class="post-date">
											<span class="date-j"><?php the_time('j' );?></span>
											<span class="date-f"><?php the_time('M' );?></span>
										</li>
								<?php } ?>

								<?php if( $show_date == 'yes' && $version == 'version_3' ){ ?>
										<li class="post-date">
											<span class="date-j"><?php the_time('j' );?></span>
											<span class="date-f"><?php the_time('M' );?></span>
										</li>
								<?php } ?>

							  		<?php if( $version == 'version_1' || $version == 'version_2' ){ ?>
							  			<?php if( $show_author == 'yes' && $show_comment == 'yes' ){ ?>

										<li class="item-space"> <span> <?php echo esc_html__('/','auntri'); ?> </span></li>
									<?php } } ?>

							  	<?php if($show_comment == 'yes' && $version != 'version_3' ): ?>
								  	<li class="item-meta  post-comment">
									  	<span class="left comment">
										  	<i class="fas fa-comments"></i>
									  	</span>
									  	<span class="right comment">
										  	<?php
										  		comments_popup_link(
											  	esc_html__('0 Comments', 'auntri'), 
											  	esc_html__('1 Comments', 'auntri'), 
											  	'(%)Comments',
											  	'',
											  	esc_html__( 'Comment off', 'auntri' ) )
										  	; ?> 
									  	</span>            
								  	</li>

							  	<?php endif; ?>

					  	</ul>
					  
						  <?php if( $show_title == 'yes' ){ ?>
							  <h2 class="post-title">
								  <a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>">
									<?php the_title(); ?>
								  </a>
							  </h2>
						  <?php } ?>

						  <?php if( $show_short_desc == 'yes' && (($version == 'version_1') || ($version == 'version_4')) ) { ?> 
							  	<div class="short_desc">
								  	<p><?php echo wp_trim_words(get_the_excerpt(), $order_text); ?></p>
							  	</div>
						  <?php } ?>

						  <?php if( $show_read_more == 'yes' && $version == 'version_1'){ ?>
							  <a class="read-more" href="<?php the_permalink(); ?>">
								  	<?php  echo esc_html( $text_readmore ); ?>
								  	<?php 
								        \Elementor\Icons_Manager::render_icon( $icon_readmore, [ 'aria-hidden' => 'true' ] );
								    ?>
							  </a>
						  <?php }?>	

						   	<?php if( $show_icon == 'yes' && $version == 'version_4'){ ?>
						   		<a class="icon" href="<?php the_permalink(); ?>">
						   			<?php 
								        \Elementor\Icons_Manager::render_icon( $icon_readmore, [ 'aria-hidden' => 'true' ] );
								    ?>
						   		</a>
						   		
						   	 <?php } ?>
					  </div>
					  
				  </li>	
					  
			  <?php
				  endwhile; endif; wp_reset_postdata();
			  ?>
			</ul>

		<?php
	}

	
}
$widgets_manager->register( new Auntri_Elementor_Blog() );