<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Auntri_Elementor_Contact_Info_Box extends Widget_Base {

	public function get_name() {
		return 'auntri_elementor_contact_info_box';
	}

	public function get_title() {
		return esc_html__( 'Contact Info Box', 'auntri' );
	}

	public function get_icon() {
		return 'eicon-info-box';
	}

	public function get_categories() {
		return [ 'auntri' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}

	protected function register_controls() {

		/**
		 * Content Tab
		 */
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'auntri' ),
				
			]
		);

			$this->add_control(
				'icon',
				[
					'label' => esc_html__( 'Icon', 'auntri' ),
					'type' => \Elementor\Controls_Manager::ICONS,
					'default' 	=> [
						'value' 	=> 'flaticon flaticon-contact',
						'library' 	=> 'all',	
					],
				]
			);

			$this->add_control(
				'label',
				[
					'label' 	=> esc_html__( 'Label', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::TEXT,
					'default' 	=> esc_html__('Label', 'auntri'),
				]
			);

			$repeater = new \Elementor\Repeater();

				$repeater->add_control(
					'type',
					[
						'label' => esc_html__( 'Type', 'auntri' ),
						'type' => \Elementor\Controls_Manager::SELECT,
						'default' => 'email',
						'options' => [
							'email' => esc_html__('Email', 'auntri'),
							'phone' => esc_html__('Phone', 'auntri'),
							'link' 	=> esc_html__('Link', 'auntri'),
							'text' 	=> esc_html__('Text', 'auntri'),
						]
					]
				);

				$repeater->add_control(
					'email_label',
					[
						'label'   => esc_html__( 'Email Label', 'auntri' ),
						'type'    => \Elementor\Controls_Manager::TEXT,
						'description' => esc_html__( 'email@company.com', 'auntri' ),
						'condition' => [
							'type' => 'email',
						]

					]
				);

				$repeater->add_control(
					'email_address',
					[
						'label'   => esc_html__( 'Email Adress', 'auntri' ),
						'type'    => \Elementor\Controls_Manager::TEXT,
						'description' => esc_html__( 'email@company.com', 'auntri' ),
						'condition' => [
							'type' => 'email',
						]

					]
				);


				$repeater->add_control(
					'phone_label',
					[
						'label'   => esc_html__( 'Phone Label', 'auntri' ),
						'type'    => \Elementor\Controls_Manager::TEXT,
						'description' => esc_html__( '+012 (345) 678', 'auntri' ),
						'condition' => [
							'type' => 'phone',
						]

					]
				);

				$repeater->add_control(
					'phone_address',
					[
						'label'   => esc_html__( 'Phone Adress', 'auntri' ),
						'type'    => \Elementor\Controls_Manager::TEXT,
						'description' => esc_html__( '+012345678', 'auntri' ),
						'condition' => [
							'type' => 'phone',
						]

					]
				);

				$repeater->add_control(
					'link_label',
					[
						'label'   		=> esc_html__( 'Link Label', 'auntri' ),
						'type'    		=> \Elementor\Controls_Manager::TEXT,
						'description' 	=> esc_html__( 'https://your-domain.com', 'auntri' ),
						'condition' 	=> [
							'type' => 'link',
						]

					]
				);

				$repeater->add_control(
					'link_address',
					[
						'label'   => esc_html__( 'Link Adress', 'auntri' ),
						'type'    => \Elementor\Controls_Manager::URL,
						'description' => esc_html__( 'https://your-domain.com', 'auntri' ),
						'condition' => [
							'type' => 'link',
						],
						'show_external' => false,
						'default' => [
							'url' => '#',
							'is_external' 	=> false,
							'nofollow' 		=> false,
						],

					]
				);

				$repeater->add_control(
					'text',
					[
						'label'   => esc_html__( 'Text', 'auntri' ),
						'type'    => \Elementor\Controls_Manager::TEXT,
						'description' => esc_html__( 'Your text', 'auntri' ),
						'condition' => [
							'type' => 'text',
						]

					]
				);

				$this->add_control(
					'items_info',
					[
						'label'       => esc_html__( 'Items Info', 'auntri' ),
						'type'        => \Elementor\Controls_Manager::REPEATER,
						'fields'      => $repeater->get_controls(),
						'default' => [
							[
								'type' 			=> 'email',
								'email_label' 	=> esc_html__('email@company.com', 'auntri'),
								'email_address' => esc_html__('email@company.com', 'auntri'),
							],
							
						],
						'title_field' => '{{{ type }}}',
					]
				);

				$this->add_control(
					'text_btn',
					[
						'label' 	=> esc_html__( 'Button', 'auntri' ),
						'type' 		=> \Elementor\Controls_Manager::TEXT,
						'default' 	=> esc_html__('Contact', 'auntri'),
						  
					]
				);

				$this->add_control(
					'btn_link',
					[
						'label' 		=> esc_html__( 'Link Button', 'auntri' ),
						'type' 			=> \Elementor\Controls_Manager::URL,
						'placeholder' 	=> esc_html__( 'https://your-link.com', 'auntri' ),
						'options' 		=> [ 'url', 'is_external', 'nofollow' ],
						'default' 		=> [
							'url' => '#',
							'is_external' => true,
							'nofollow' => true,
						],
						'label_block' => true,
						'condition' => [
							'text_btn!' => ''
						], 
					]
				);

		$this->end_controls_section(); 
		// End Content Tab

		/**
		 * GENERAL Style Tab
		 */
		$this->start_controls_section(
			'section_general_style',
			[
				'label' => esc_html__( 'General', 'auntri' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_responsive_control(
				'general_padding',
				[
					'label' 	=> esc_html__( 'Padding', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-contact-info-box .contact' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'general_border_color',
				[
					'label' 	=> esc_html__( 'Border Color', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-contact-info-box .contact' 							=> 'border-color : {{VALUE}};',
						'{{WRAPPER}} .ova-contact-info-box .contact-btn' 						=> 'border-right-color : {{VALUE}};',
						'{{WRAPPER}} .ova-contact-info-box .contact-btn .button-mask:after' 	=> 'background-color : {{VALUE}};',
						'{{WRAPPER}} .ova-contact-info-box .contact-btn .button-mask' 			=> 'border-top-color : {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'general_border_color_hover',
				[
					'label' 	=> esc_html__( 'Border Color Hover', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-contact-info-box:hover .contact' 							=> 'border-color : {{VALUE}};',
						'{{WRAPPER}} .ova-contact-info-box:hover .contact-btn' 						=> 'border-right-color : {{VALUE}};',
						'{{WRAPPER}} .ova-contact-info-box:hover .contact-btn .button-mask:after' 	=> 'background-color : {{VALUE}};',
						'{{WRAPPER}} .ova-contact-info-box:hover .contact-btn .button-mask' 		=> 'border-top-color : {{VALUE}};',
					],
				]
			);

		$this->end_controls_section(); 
		// End GENERAL Style Tab

		/**
		 * Icon Style Tab
		 */
		$this->start_controls_section(
			'section_icon_style',
			[
				'label' => esc_html__( 'Icon', 'auntri' ),
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'icon_fontsize',
				[
					'label' 	=> esc_html__( 'Font Size', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' 	=> [
						'px' => [
							'min' => 1,
							'max' => 200,
							'step' => 1,
						]
					],
					'selectors' => [
						'{{WRAPPER}} .ova-contact-info-box .icon' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'icon_color',
				[
					'label' 	=> esc_html__( 'Color', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-contact-info-box .icon' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'icon_margin',
				[
					'label' 	=> esc_html__( 'Margin', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-contact-info-box .icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section(); // End Icon Style Tab

		/**
		 * Label Style Tab
		 */
		$this->start_controls_section(
			'section_label_style',
			[
				'label' => esc_html__( 'Label', 'auntri' ),
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			
			$this->add_control(
				'label_color',
				[
					'label' 	=> esc_html__( 'Color', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-contact-info-box .contact .label' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'label_typography',
					'selector' 	=> '{{WRAPPER}} .ova-contact-info-box .contact .label',
				]
			);

			$this->add_responsive_control(
				'label_margin',
				[
					'label' => esc_html__( 'Margin', 'auntri' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-contact-info-box .contact .label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section(); // End Label Style Tab

		/**
		 * Info Style Tab
		 */
		$this->start_controls_section(
			'section_info_style',
			[
				'label' => esc_html__( 'Info', 'auntri' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			

			$this->add_control(
				'info_color',
				[
					'label' => esc_html__( 'Color', 'auntri' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-contact-info-box .contact .info .item' 	=> 'color : {{VALUE}};',
						'{{WRAPPER}} .ova-contact-info-box .contact .info .item a' 	=> 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'info_color_hover',
				[
					'label' 	=> esc_html__( 'Link Color hover', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-contact-info-box .contact .info .item a:hover' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'info_typography',
					'selector' 	=> '{{WRAPPER}} .ova-contact-info-box .contact .info .item, {{WRAPPER}} .ova-contact-info-box .contact .info .item a',
				]
			);

			$this->add_responsive_control(
				'info_margin',
				[
					'label' 	=> esc_html__( 'Margin', 'auntri' ),
					'type' 		=> Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-contact-info-box .contact .info .item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section(); // End Label Style Tab

		/**
		 * button Style Tab
		 */
		$this->start_controls_section(
			'section_button_style',
			[
				'label' => esc_html__( 'Button', 'auntri' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'button_typography',
					'selector' 	=> '{{WRAPPER}} .ova-contact-info-box .contact-btn .btn-contact .text',
				]
			);

			$this->add_control(
				'button_color',
				[
					'label' 	=> esc_html__( 'Color', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-contact-info-box .contact-btn .btn-contact .text' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'button_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-contact-info-box:hover .contact-btn .btn-contact .text' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'button_bg_color',
				[
					'label' 	=> esc_html__( 'Background', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-contact-info-box .contact-btn .btn-contact' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'button_bg_color_hover',
				[
					'label' 	=> esc_html__( 'Background Hover', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-contact-info-box:hover .contact-btn .btn-contact:before' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'button_margin',
				[
					'label' 	=> esc_html__( 'Margin', 'auntri' ),
					'type' 		=> Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-contact-info-box .contact-btn .btn-contact' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'button_padding',
				[
					'label' 	=> esc_html__( 'Padding', 'auntri' ),
					'type' 		=> Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-contact-info-box .contact-btn .btn-contact' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);


		$this->end_controls_section(); // End Button Style Tab
	}

	protected function render() {

		$settings 		= 	$this->get_settings();

		$icon 			= 	$settings['icon'] ? $settings['icon'] : '';
		$label 			= 	$settings['label'] ? $settings['label'] : '';
		$items_info 	= 	$settings['items_info'];
		
		$text_btn 		= 	$settings['text_btn'];
		$btn_url    	= 	$settings['btn_link']['url'] ? $settings['btn_link']['url'] : '#';
        $btn_target 	= 	$settings['btn_link']['is_external'] ? ' target="_blank"' : '';
		?>
			<div class="ova-contact-info-box ">
				
					<?php if( $icon['value']){ ?>
						<div class="icon">
				   			<?php 
						        \Elementor\Icons_Manager::render_icon( $icon, [ 'aria-hidden' => 'true' ] );
						    ?>
				   		</div>
			   		<?php } ?>
				
				<div class="contact">
					
					<?php if( $label ){ ?>
						<div class="label">
							<?php echo esc_html( $label ); ?>
						</div>
					<?php } ?>

					<ul class="info">
						<?php foreach( $items_info as $item ):

							$type 	= $item['type'];
							
							?>

								<li class="item">

									<?php switch ( $type ) {

										case 'email':

											$email_address = $item['email_address'];
											$email_label = $item['email_label'];
											if( $email_address && $email_label ){
											?>
												<a href="mailto:<?php echo esc_attr( $email_address ); ?> ">
													<?php echo esc_html( $email_label ); ?>
												</a>
											<?php
											}
											break;

										case 'phone':

											$phone_address = $item['phone_address'];
											$phone_label = $item['phone_label'];
											if( $phone_address && $phone_label ){
											?>
												<a href="tel:<?php echo esc_attr( $phone_address ); ?> ">
													<?php echo esc_html( $phone_label ); ?>
												</a>
											<?php
											}
											break;

										case 'link':

											$this->add_render_attribute( 'title' );

											$link_address = $item['link_address']['url'];
											$link_label = $item['link_label'];

											$title = $item['link_label'] ? $item['link_label'] : '';

											if ( ! empty( $item['link_address']['url'] ) ) {

												$this->add_link_attributes( 'url', $item['link_address'] );

												echo sprintf( '<a %1$s>%2$s</a>', $this->get_render_attribute_string( 'url' ), $title );

											}else{

												echo esc_html( $title );

											}
											
											break;

										case 'text':
											$text = $item['text'];
											?>
												<?php echo esc_html( $text ); ?>
											<?php
											break;
										default:
											break;
									} ?>
								</li>
							
						<?php endforeach; ?>
					</ul>

				</div>
				<div class="contact-btn">
					<div class="button-mask"></div>
					<?php

						if ( ! empty( $btn_url ) ) { ?>

							<a class="btn btn-contact" href="<?php echo esc_url( $btn_url ); ?>"<?php printf( $btn_target ); ?>>
								<span class="text">
									<?php echo esc_html( $text_btn ); ?> 
								</span>
							</a>
							
					<?php	}
					?>

				</div>
			</div>

		<?php
	}
// end render
}

$widgets_manager->register( new Auntri_Elementor_Contact_Info_Box() );