<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Box_Shadow;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Auntri_Elementor_Counter extends Widget_Base {

	
	public function get_name() {
		return 'auntri_elementor_counter';
	}

	
	public function get_title() {
		return esc_html__( 'Ova Counter', 'auntri' );
	}

	
	public function get_icon() {
		return 'eicon-counter';
	}

	
	public function get_categories() {
		return [ 'auntri' ];
	}

	public function get_script_depends() {
		// appear js
		wp_enqueue_script( 'auntri-counter-appear', get_theme_file_uri('/assets/libs/appear/appear.js'), array('jquery'), false, true);
		// Odometer for counter
		wp_enqueue_style( 'odometer', get_template_directory_uri().'/assets/libs/odometer/odometer.min.css' );
		wp_enqueue_script( 'odometer', get_template_directory_uri().'/assets/libs/odometer/odometer.min.js', array('jquery'), false, true );
		return [ 'auntri-elementor-counter' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Ova Counter', 'auntri' ),
			]
		);	
			
			// Add Class control

		    $this->add_control(
				'template',
				[
					'label' => esc_html__( 'Template', 'auntri' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'template1',
					'options' => [
						'template1' => esc_html__('Template 1', 'auntri'),
						'template2' => esc_html__('Template 2', 'auntri'),
						'template3' => esc_html__('Template 3', 'auntri'),
						'template4' => esc_html__('Template 4', 'auntri'),
						'template5' => esc_html__('Template 5', 'auntri'),
					]
				]
			);

		    $this->add_control(
				'icon',
				[
					'label' => esc_html__( 'Icon', 'auntri' ),
					'type' => Controls_Manager::ICONS,
					'default' 	=> [
						'value' 	=> 'flaticon flaticon-office',
						'library' 	=> 'flaticon',
					],
				]
			);

		    $this->add_control(
				'number',
				[
					'label' 	=> esc_html__( 'Number', 'auntri' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => '800'
				]
			);

			$this->add_control(
				'suffix',
				[
					'label'  => esc_html__( 'Suffix', 'auntri' ),
					'type'   => Controls_Manager::TEXT,
					'placeholder' => esc_html__( 'Plus', 'auntri' ),
				]
			);

			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'auntri' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> 'Projects Completed',
					'description' => esc_html__( 'Using <br> tag to insert line breaks', 'auntri' ),
				]
			);

			$this->add_control(
				'description',
				[
					'label' 	=> esc_html__( 'Description', 'auntri' ),
					'type' 	=> Controls_Manager::TEXTAREA,
					'default' => 'Lorem ipsum is simply free text available.',
					'condition' => [
						'template' => 'template5'
					]
				]
			);
			
		$this->end_controls_section();

		/* Begin Counter Style */
		$this->start_controls_section(
            'counter_style',
            [
               'label' => esc_html__( 'Ova Counter', 'auntri' ),
               'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );
            

            $this->add_responsive_control(
				'counter_max_width',
				[
					'label' 		=> esc_html__( 'Max Width', 'auntri' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> ['px', '%'],
					'range' => [
						'px' => [
							'min' => 150,
							'max' => 500,
							'step' => 1,
						],
						'%' => [
							'min' => 30,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-counter' => 'max-width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'counter_width',
				[
					'label' 		=> esc_html__( 'Width', 'auntri' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> ['px', '%'],
					'range' => [
						'px' => [
							'min' => 150,
							'max' => 500,
							'step' => 1,
						],
						'%' => [
							'min' => 30,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-counter' => 'width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'counter_height',
				[
					'label' 		=> esc_html__( 'Height', 'auntri' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> ['px', '%'],
					'range' => [
						'px' => [
							'min' => 150,
							'max' => 500,
							'step' => 1,
						],
						'%' => [
							'min' => 30,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-counter' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Background::get_type(),
				[
					'name' => 'counter_background',
					'label' => esc_html__( 'Background', 'auntri' ),
					'types' => [ 'classic', 'gradient' ],
					'selector' => '{{WRAPPER}} .ova-counter',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'counter_border',
					'label' => esc_html__( 'Border', 'auntri' ),
					'selector' => '{{WRAPPER}} .ova-counter',
					'separator' => 'before'
				]
			);


			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'counter_box_shadow',
					'label' => esc_html__( 'Box Shadow', 'auntri' ),
					'selector' => '{{WRAPPER}} .ova-counter',
				]
			);

		    $this->add_responsive_control(
	            'counter_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-counter' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_responsive_control(
	            'counter_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border Radius', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-counter' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_responsive_control(
				'text_align',
				[
					'label' 	=> esc_html__( 'Alignment', 'auntri' ),
					'type' 		=> Controls_Manager::CHOOSE,
					'options' 	=> [
						'left' 	=> [
							'title' => esc_html__( 'Left', 'auntri' ),
							'icon' 	=> 'eicon-text-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'auntri' ),
							'icon' 	=> 'eicon-text-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'auntri' ),
							'icon' 	=> 'eicon-text-align-right',
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-counter' => 'text-align: {{VALUE}};',
					],
				]
			);
            
            // Clip Path
			$this->add_responsive_control(
	            'clip_path_heading',
	            [
	                'label' 		=> esc_html__( 'Clip Path', 'auntri' ),
	                'type' 			=> Controls_Manager::HEADING,
					'separator' => 'before'
	            ]
	        );

				$this->add_control(
					'clip_path',
					[
						'label' => esc_html__( 'Clip Path', 'auntri' ),
						'type' => Controls_Manager::SELECT,
						'default' => 'path_none',
						'description' => esc_html__( 'Using clip path can affect triangle position', 'auntri' ),
						'options' => [
							'path_none' => esc_html__('None', 'auntri'),
							'path1' => esc_html__('Path 1', 'auntri'),
							'path2' => esc_html__('Path 2', 'auntri'),
							'path3' => esc_html__('Path 3', 'auntri'),
							'path4' => esc_html__('Path 4', 'auntri'),
						],
					]
				);

		    // Triangle Background
	        $this->add_responsive_control(
	            'triangle_heading',
	            [
	                'label' 		=> esc_html__( 'Triangle', 'auntri' ),
	                'type' 			=> Controls_Manager::HEADING,
					'separator' => 'before'
	            ]
	        );

	            $this->add_control(
					'triangle_position',
					[
						'label' => esc_html__( 'Position', 'auntri' ),
						'type' => Controls_Manager::SELECT,
						'default' => 'triangle_none',
						'options' => [
							'triangle_none'  => esc_html__('None', 'auntri'),
							'position1' 	=> esc_html__('Position 1', 'auntri'),
							'position2'	 	=> esc_html__('Position 2', 'auntri'),
							'position3' 	=> esc_html__('Position 3', 'auntri'),
							'position4'	 	=> esc_html__('Position 4', 'auntri'),
							'position5' 	=> esc_html__('Position 5', 'auntri'),
						]
					]
				);

	            $this->add_control(
					'triangle_color',
					[
						'label' 	=> esc_html__( 'Color', 'auntri' ),
						'type' 		=> Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-counter.position1:before' => 'background-color: {{VALUE}};',
							'{{WRAPPER}} .ova-counter.position2:before' => 'border-right-color: {{VALUE}};',
							'{{WRAPPER}} .ova-counter.position3:before' => 'border-top-color: {{VALUE}};',
							'{{WRAPPER}} .ova-counter.position4:before' => 'background-color: {{VALUE}};',
							'{{WRAPPER}} .ova-counter.position5:before' => 'background-color: {{VALUE}};'
						],
						'condition' => [
							'triangle_position!' => 'triangle_none'
						]
					]
				);

        $this->end_controls_section();
		/* End counter style */

		/* Begin icon Style */
		$this->start_controls_section(
            'icon_style',
            [
                'label' => esc_html__( 'Icon', 'auntri' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );
            
			$this->add_responsive_control(
				'size_icon',
				[
					'label' 		=> esc_html__( 'Size', 'auntri' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px'],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-counter .icon i' => 'font-size: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}} .ova-counter .icon svg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					],
				]
			);

            $this->add_control(
				'icon_color',
				[
					'label' 	=> esc_html__( 'Color', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-counter .icon i' => 'color: {{VALUE}};',
						'{{WRAPPER}} .ova-counter .icon svg path' => 'fill : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'icon_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-counter:hover .icon i' => 'color: {{VALUE}};',
						'{{WRAPPER}} .ova-counter:hover .icon svg path' => 'fill : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'icon_settings_color',
				[
					'label' 	=> esc_html__( 'Settings Color', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-counter .icon i.icon-settings' => 'color: {{VALUE}}!important;',
						'{{WRAPPER}} .ova-counter .icon:before' => 'background-color: {{VALUE}};',
					],
					'condition' => [
						'template' => 'template1'
					]
				]
			);

			$this->add_control(
				'icon_settings_color_hover',
				[
					'label' 	=> esc_html__( 'Settings Color Hover', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-counter:hover .icon i.icon-settings' => 'color: {{VALUE}}!important;',
						'{{WRAPPER}} .ova-counter:hover .icon:before' => 'background-color: {{VALUE}};',
					],
					'condition' => [
						'template' => 'template1'
					]
				]
			);

			$this->add_responsive_control(
	            'icon_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-counter .icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );
		
        $this->end_controls_section();
		/* End icon style */

		/* Begin number (odometer) Style */
		$this->start_controls_section(
            'number_style',
            [
                'label' => esc_html__( 'Number', 'auntri' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

			 $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'number_typography',
					'selector' 	=> '{{WRAPPER}} .ova-counter .odometer',
				]
			);

			$this->add_control(
				'number_color',
				[
					'label' 	=> esc_html__( 'Color', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-counter .odometer' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'number_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-counter:hover .odometer' => 'color: {{VALUE}};',
					],
				]
			);

        $this->end_controls_section();
		/* End number style */

		/* Begin suffix Style */
		$this->start_controls_section(
            'suffix_style',
            [
                'label' => esc_html__( 'Suffix', 'auntri' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'suffix_typography',
					'selector' 	=> '{{WRAPPER}} .ova-counter .suffix',
				]
			);

			$this->add_control(
				'suffix_color',
				[
					'label' 	=> esc_html__( 'Color', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-counter .suffix' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'suffix_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-counter:hover .suffix' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
	            'suffix_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-counter .suffix' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
		/* End suffix style */

		/* Begin title Style */
		$this->start_controls_section(
            'title_style',
            [
                'label' => esc_html__( 'Title', 'auntri' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'title_typography',
					'selector' 	=> '{{WRAPPER}} .ova-counter .title',
				]
			);

			$this->add_control(
				'title_color',
				[
					'label' 	=> esc_html__( 'Color', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-counter .title' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'title_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-counter:hover .title' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
	            'title_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-counter .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'title_border',
					'label' => esc_html__( 'Border', 'auntri' ),
					'selector' => '{{WRAPPER}} .ova-counter .title',
				]
			);

        $this->end_controls_section();
		/* End title style */

		/* Begin description Style */
		$this->start_controls_section(
            'description_style',
            [
                'label' => esc_html__( 'Description', 'auntri' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
                'condition' => [
					'template' => 'template5'
				]
            ]
        );

            $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'description_typography',
					'selector' 	=> '{{WRAPPER}} .ova-counter .description',
				]
			);

			$this->add_control(
				'description_color',
				[
					'label' 	=> esc_html__( 'Color', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-counter .description' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'description_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-counter:hover .description' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
	            'description_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-counter .description' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
		/* End description style */

		
	}

	// Render Template Here
	protected function render() {

		$settings 		= $this->get_settings();

        $template   	= $settings['template'];
        $icon  			= $settings['icon'];
        $clip_path   	= isset( $settings['clip_path'] ) ? $settings['clip_path'] : '';
		$number    	 	= isset( $settings['number'] ) ? $settings['number'] : '100';
		$suffix     	= $settings['suffix'];
		$title      	= $settings['title'];
		$description  	= $settings['description'];
		$triangle   	= $settings['triangle_position'];

		 ?>
           
           <div class="ova-counter ova-counter-<?php echo esc_attr( $template ); ?> <?php echo esc_attr( $triangle ); ?> <?php echo esc_attr( $clip_path ); ?>" 
               data-count="<?php echo esc_attr( $number ); ?>">

               <?php if (!empty( $icon['value'] )): ?>

               		<?php if( $template === 'template1') : ?>

               			<div class="icon">
		            	    <?php 
							    \Elementor\Icons_Manager::render_icon( $settings['icon'], [ 'aria-hidden' => 'true' ] );
							?>	
							<i aria-hidden="true" class="icon-settings flaticon flaticon-settings"></i>
		            	</div>

		            <?php else: ?>

	                	<div class="icon">
		            	    <?php 
							    \Elementor\Icons_Manager::render_icon( $settings['icon'], [ 'aria-hidden' => 'true' ] );
							?>	
		            	</div>

		            <?php endif;?>

	            <?php endif;?>

	            <div class="odometer-wrapper">

	            	<?php if( $template === 'template3') : ?>

	            		<?php if (!empty( $title )): ?>
							<h4 class="title">
								<?php printf( $title ); ?>
							</h4>
						<?php endif;?>

						<span class="odometer">0</span><span class="suffix"><?php echo esc_html( $suffix ); ?></span>

					<?php else: ?>

						<span class="odometer">0</span><span class="suffix"><?php echo esc_html( $suffix ); ?></span>
				
			      	    <?php if (!empty( $title )): ?>
							<h4 class="title">
								<?php printf( $title ); ?>
							</h4>
						<?php endif;?>
                        
						<?php if ( (!empty( $description )) && ( $template === 'template5' ) ) : ?>
							<p class="description">
								<?php echo esc_html( $description ); ?>
							</p>
						<?php endif;?>

	            	<?php endif;?>    	

	            </div>
 
           </div>
		 	
		<?php
	}

	
}
$widgets_manager->register( new Auntri_Elementor_Counter() );