<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Auntri_Elementor_Heading extends Widget_Base {

	
	public function get_name() {
		return 'auntri_elementor_heading';
	}

	
	public function get_title() {
		return esc_html__( 'Ova Heading', 'auntri' );
	}

	
	public function get_icon() {
		return 'eicon-heading';
	}

	
	public function get_categories() {
		return [ 'auntri' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

	$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'auntri' ),
			]
		);
			
			$this->add_control(
				'sub_title',
				[
					'label' 	=> esc_html__( 'Sub Title', 'auntri' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> 'Sub title',
				]
			);

			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'auntri' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> 'Title',
				]
			);

			$this->add_control(
				'description',
				[
					'label' 	=> esc_html__( 'Description', 'auntri' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> ''
				]
			);

			$this->add_control(
				'link_address',
				[
					'label'   		=> esc_html__( 'Link', 'auntri' ),
					'type'    		=> \Elementor\Controls_Manager::URL,
					'show_external' => false,
					'default' 		=> [
						'url' 			=> '',
						'is_external' 	=> false,
						'nofollow' 		=> false,
					],
				]
			);
			
			$this->add_control(
				'html_tag',
				[
					'label' 	=> esc_html__( 'HTML Tag', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::SELECT,
					'default' 	=> 'h2',
					'options' 	=> [
						'h1' 		=> esc_html__( 'H1', 'auntri' ),
						'h2'  		=> esc_html__( 'H2', 'auntri' ),
						'h3'  		=> esc_html__( 'H3', 'auntri' ),
						'h4' 		=> esc_html__( 'H4', 'auntri' ),
						'h5' 		=> esc_html__( 'H5', 'auntri' ),
						'h6' 		=> esc_html__( 'H6', 'auntri' ),
						'div' 		=> esc_html__( 'Div', 'auntri' ),
						'span' 		=> esc_html__( 'span', 'auntri' ),
						'p' 		=> esc_html__( 'p', 'auntri' ),
					],
				]
			);

			$this->add_responsive_control(
				'align_heading',
				[
					'label' 	=> esc_html__( 'Alignment', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::CHOOSE,
					'options' 	=> [
						'left' => [
							'title' => esc_html__( 'Left', 'auntri' ),
							'icon' 	=> 'eicon-text-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'auntri' ),
							'icon' 	=> 'eicon-text-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'auntri' ),
							'icon' 	=> 'eicon-text-align-right',
						],
					],
					'default' 	=> 'center',
					'toggle' 	=> true,
					'selectors' => [
						'{{WRAPPER}} .ova-title' => 'text-align: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'show_line',
				[
					'label' 		=> esc_html__( 'Show Line', 'auntri' ),
					'type' 			=> \Elementor\Controls_Manager::SWITCHER,
					'label_on' 		=> esc_html__( 'Show', 'auntri' ),
					'label_off' 	=> esc_html__( 'Hide', 'auntri' ),
					'return_value'	=> 'yes',
					'default' 		=> 'yes',
				]
			);

			$this->add_control(
				'show_line_secondary',
				[
					'label' 		=> esc_html__( 'Show Line Secondary', 'auntri' ),
					'type' 			=> \Elementor\Controls_Manager::SWITCHER,
					'label_on' 		=> esc_html__( 'Show', 'auntri' ),
					'label_off' 	=> esc_html__( 'Hide', 'auntri' ),
					'return_value' 	=> 'yes',
					'default' 		=> 'no',
				]
			);

			$this->add_control(
				'number_text',
				[
					'label' => esc_html__( 'Number Text', 'auntri' ),
					'type'	=> \Elementor\Controls_Manager::NUMBER,
					'min' 	=> 0,
					'max' 	=> 100,
					'step' 	=> 1,
					'description' => esc_html__( '( Word position in title use background line )', 'auntri' ),
					'condition' => [
						'show_line_secondary' => 'yes'
					]
				]
			);


			$this->add_responsive_control(
				'align_line',
				[
					'label' 	=> esc_html__( 'Alignment Line', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::CHOOSE,
					'options' 	=> [

						'left: 0%;right:unset;transform: translate( 0 , -50%);' => [
							'title' => esc_html__( 'Left', 'auntri' ),
							'icon' 	=> 'eicon-text-align-left',
						],
						
						'right: unset; left: 50%; transform: translate( -50% , -50%);' => [
							'title' => esc_html__( 'Center', 'auntri' ),
							'icon' 	=> 'eicon-text-align-center',
						],

						'left: unset; right: 0; transform: translate(0, -50%);' => [
							'title' => esc_html__( 'Right', 'auntri' ),
							'icon' 	=> 'eicon-text-align-right',
						],
					],
				
					'toggle' 	=> true,
					'selectors' => [
						'{{WRAPPER}} .ova-title .box-title .line-top' => '{{VALUE}}',

					],
					'condition' => [
						'show_line' => 'yes',
					]
				]
			);

		$this->end_controls_section();
		
		//SECTION TAB STYLE TITLE
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'auntri' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'content_typography_title',
					'label' 	=> esc_html__( 'Typography', 'auntri' ),
					'selector' 	=> '{{WRAPPER}} .ova-title .title',
				]
			);

			$this->add_control(
				'color_title',
				[
					'label' 	=> esc_html__( 'Color', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-title .title, {{WRAPPER}} .ova-title .title a' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'color_title_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-title .title:hover, {{WRAPPER}} .ova-title .title:hover a' => 'color : {{VALUE}};'
					],
					
				]
			);

			$this->add_responsive_control(
				'padding_title',
				[
					'label' 	 => esc_html__( 'Padding', 'auntri' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-title .title ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'margin_title',
				[
					'label' 	 => esc_html__( 'Margin', 'auntri' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-title .title ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		//END SECTION TAB STYLE TITLE

		//SECTION TAB STYLE SUB TITLE
		$this->start_controls_section(
			'section_sub_title',
			[
				'label' => esc_html__( 'Sub Title', 'auntri' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'content_typography_sub_title',
					'label' 	=> esc_html__( 'Typography', 'auntri' ),
					'selector' 	=> '{{WRAPPER}} .ova-title h3.sub-title',
				]
			);

			$this->add_control(
				'color_sub_title',
				[
					'label'	 	=> esc_html__( 'Color', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-title h3.sub-title' => 'color : {{VALUE}};'
						
						
					],
				]
			);

			$this->add_responsive_control(
				'padding_sub_title',
				[
					'label' 	 => esc_html__( 'Padding', 'auntri' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-title h3.sub-title ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'margin_sub_title',
				[
					'label' 	 => esc_html__( 'Margin', 'auntri' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-title h3.sub-title ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
			
		$this->end_controls_section();
		//END SECTION TAB STYLE SUB TITLE

		//SECTION TAB STYLE DESCRIPTION
		$this->start_controls_section(
			'section_description',
			[
				'label' => esc_html__( 'Description', 'auntri' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'content_typography_description',
					'label' 	=> esc_html__( 'Typography', 'auntri' ),
					'selector' 	=> '{{WRAPPER}} .ova-title .description',
				]
			);

			$this->add_control(
				'color_description',
				[
					'label'	 	=> esc_html__( 'Color', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-title .description' => 'color : {{VALUE}};'		
					],
				]
			);

			$this->add_responsive_control(
				'padding_description',
				[
					'label' 	 => esc_html__( 'Padding', 'auntri' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-title .description ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'margin_description',
				[
					'label' 	 => esc_html__( 'Margin', 'auntri' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-title .description ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
			
		$this->end_controls_section();
		//END SECTION TAB STYLE DESCRIPTION
		
		//SECTION TAB STYLE LINE
		$this->start_controls_section(
			'section_line',
			[
				'label' 	=> esc_html__( 'Line', 'auntri' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
				'condition' => [
					'show_line' => 'yes',
				],
			]
		);

			$this->add_control(
				'color_bg_line',
				[
					'label'	 	=> esc_html__( 'Background', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-title .box-title .line-top' => 'background-color : {{VALUE}};'		
					],
				]
			);

			$this->add_responsive_control(
				'color_bg_line_width',
				[
					'label' 		=> esc_html__( 'Width', 'auntri' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px' ],
					'range' 		=> [
						'px' => [
							'min' => 50,
							'max' => 150,
							'step' => 1,
						]
					],
					'selectors' => [
						'{{WRAPPER}} .ova-title .box-title .line-top' => 'width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'color_bg_line_height',
				[
					'label' 	=> esc_html__( 'Height', 'auntri' ),
					'type' 		=> Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 1,
							'max' => 5,
							'step' => 1,
						]
					],
					'selectors' => [
						'{{WRAPPER}} .ova-title .box-title .line-top' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		//END SECTION TAB STYLE LINE		
		

		//SECTION TAB STYLE LINE BACKGROUND SECONDARY
		$this->start_controls_section(
			'section_line_background_secondary',
			[
				'label' 	=> esc_html__( 'Background Line', 'auntri' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
				'condition' => [
					'show_line_secondary' => 'yes',
				],
			]
		);

			$this->add_control(
				'color_bg_secondary_line',
				[
					'label'	 	=> esc_html__( 'Background', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-title .title span:before, {{WRAPPER}} .ova-title .title span:after' => 'border-color : {{VALUE}};',		
					],
				]
			);

		$this->end_controls_section();
		//END SECTION TAB STYLE LINE BACKGROUND
		
	}

	// Render Template Here
	protected function render() {

		$settings 		= 	$this->get_settings();

		$title     		= 	$settings['title'];
		$sub_title 		= 	$settings['sub_title'];
		$description	= 	$settings['description']; 
		$link      		= 	$settings['link_address']['url'];
		$target    		= 	$settings['link_address']['is_external'] ? ' target="_blank"' : '';
		$html_tag  		= 	$settings['html_tag'];
		$show_line 		= 	$settings['show_line'];
		$show_line_se 	= 	$settings['show_line_secondary'];
		$number_text 	= 	$settings['number_text'] ? ( (int)$settings['number_text'] - 1 ) : 0;

		if($show_line_se == 'yes') {
			$explode_fullname 	= 	explode(' ', $title);
			$replace 			= 	'<span>' . $explode_fullname[$number_text] . '</span>';
			$title     			= 	str_replace( $explode_fullname[$number_text], $replace, $title );
		}
		

		?>

		<div class="ova-title">

			<?php if( $sub_title ): ?>
				<h3 class="sub-title"><?php echo esc_html( $sub_title ); ?></h3>
			<?php endif; ?>

			<?php if( $title) : ?>
				
				<?php if( $show_line == 'yes' ): ?>
					<div class="box-title">
						<div class="line-top"></div>
				<?php endif; ?>

					<?php if( $link ) { ?>
					
						<<?php echo esc_attr($html_tag); ?> class="title"><a href="<?php echo esc_url( $link ); ?>"<?php printf( $target ); ?>><?php printf($title);?></a></<?php echo esc_attr( $html_tag ); ?>>

					<?php } else { ?>

						<<?php echo esc_attr($html_tag); ?> class="title"><?php printf($title); ?></<?php echo esc_attr( $html_tag ); ?>>

					<?php } ?>

				<?php if( $show_line == 'yes' ): ?>
					</div>
				<?php endif; ?>

			<?php endif; ?>

			<?php if( $description ): ?>
				<p class="description"><?php echo esc_html( $description ); ?></p>
			<?php endif; ?>

		</div>
		 	
		<?php
	}
	
}
$widgets_manager->register( new Auntri_Elementor_Heading() );