<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Auntri_Elementor_Images_Slider extends Widget_Base {

	
	public function get_name() {
		return 'auntri_elementor_images_slider';
	}

	
	public function get_title() {
		return esc_html__( 'Ova Images Slider', 'auntri' );
	}

	
	public function get_icon() {
		return 'eicon-slides';
	}

	
	public function get_categories() {
		return [ 'auntri' ];
	}

	public function get_script_depends() {
		wp_enqueue_style( 'image-slider-owl-carousel', get_template_directory_uri().'/assets/libs/carousel/assets/owl.carousel.min.css' );
		wp_enqueue_script( 'image-slider-owl-carousel', get_template_directory_uri().'/assets/libs/carousel/owl.carousel.min.js', array('jquery'), false, true );
		return [ 'auntri-elementor-images-slider' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'auntri' ),
			]
		);	
			
			// Add Class control
			$this->add_control(
				'ova_image_slider',
				[
					'label' => esc_html__( 'Add Images', 'auntri' ),
					'type' => \Elementor\Controls_Manager::GALLERY,
					'default' => [],
				]
			);

		$this->end_controls_section();

		/*****************************************************************
						START SECTION ADDITIONAL
		******************************************************************/

		$this->start_controls_section(
			'section_additional_options',
			[
				'label' => esc_html__( 'Additional Options', 'auntri' ),
			]
		);

		/***************************  VERSION  ***********************/
			$this->add_control(
				'margin_items',
				[
					'label'   => esc_html__( 'Margin Right Items', 'auntri' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 30,	
				]
				
			);

			$this->add_control(
				'item_number',
				[
					'label'       => esc_html__( 'Item Number', 'auntri' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Number Item', 'auntri' ),
					'default'     => 5,
				]
			);

			$this->add_control(
				'slides_to_scroll',
				[
					'label'       => esc_html__( 'Slides to Scroll', 'auntri' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Set how many slides are scrolled per swipe.', 'auntri' ),
					'default'     => 1,
				]
			);

			$this->add_control(
				'pause_on_hover',
				[
					'label'   => esc_html__( 'Pause on Hover', 'auntri' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'auntri' ),
						'no'  => esc_html__( 'No', 'auntri' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'infinite',
				[
					'label'   => esc_html__( 'Infinite Loop', 'auntri' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'auntri' ),
						'no'  => esc_html__( 'No', 'auntri' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay',
				[
					'label'   => esc_html__( 'Autoplay', 'auntri' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'auntri' ),
						'no'  => esc_html__( 'No', 'auntri' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay_speed',
				[
					'label'     => esc_html__( 'Autoplay Speed', 'auntri' ),
					'type'      => Controls_Manager::NUMBER,
					'default'   => 3000,
					'step'      => 500,
					'condition' => [
						'autoplay' => 'yes',
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'smartspeed',
				[
					'label'   => esc_html__( 'Smart Speed', 'auntri' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 500,
				]
			);

			$this->add_control(
				'dot_control',
				[
					'label'   => esc_html__( 'Show Dots', 'auntri' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'auntri' ),
						'no'  => esc_html__( 'No', 'auntri' ),
					],
					'frontend_available' => true,
				]
			);
			$this->add_control(
				'nav_control',
				[
					'label'   => esc_html__( 'Show Nav', 'auntri' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'no',
					'options' => [
						'yes' => esc_html__( 'Yes', 'auntri' ),
						'no'  => esc_html__( 'No', 'auntri' ),
					],
					'frontend_available' => true,
				]
			);

		$this->end_controls_section();

		/****************************  END SECTION ADDITIONAL *********************/
		

		/*************  STYLE SECTION GENERAL  *******************/
		$this->start_controls_section(
			'section_style_general',
			[
				'label' => esc_html__( 'General', 'auntri' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'image_width',
				[
					'label' 		=> esc_html__( 'Max Width Image', 'auntri' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px' ],
					'range' => [
						'px' => [
							'min' 	=> 100,
							'max' 	=> 300,
							'step' 	=> 1,
						]
					],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-image-slider.owl-carousel img' => 'max-width:{{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'general_image_opacity',
				[
					'label' => esc_html__( ' Image Opacity', 'auntri' ),
					'type' 	=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'max' => 1,
							'step' => 0.01,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-image-slider.owl-carousel img' => 'opacity: {{SIZE}};',
					],
				]
			);

			$this->add_control(
				'general_image__hover_opacity',
				[
					'label' => esc_html__( ' Image Hover Opacity', 'auntri' ),
					'type' 	=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'max' => 1,
							'step' => 0.01,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-image-slider.owl-carousel .owl-item:hover img' => 'opacity: {{SIZE}};',
					],
				]
			);

			$this->add_control(
				'background',
				[
					'label' => esc_html__( 'Background', 'auntri' ),
					'type' => Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .ova-image-slider.owl-carousel .owl-item' => 'background: {{VALUE}};',
					],
					'separator' => 'before'
				]
			);

			$this->add_control(
				'background_hover',
				[
					'label' => esc_html__( 'Background Hover', 'auntri' ),
					'type' => Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .ova-image-slider.owl-carousel .owl-item:hover' => 'background: {{VALUE}};',
					],
				]
			);

		$this->end_controls_section();
		###############  end section GENERAL  ###############
		
		/*************  SECTION DOTs. *******************/
		$this->start_controls_section(
			'section_dot',
			[
				'label' => esc_html__( 'Dots', 'auntri' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'dot_control' => 'yes',
				]
			]
		);

			$this->add_control(
				'dot_color',
				[
					'label'     => esc_html__( 'Dot Color', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-image-slider.owl-carousel .owl-dots button' => 'background-color : {{VALUE}};',
						
					],
				]
			);

			$this->add_control(
				'dot_active_color',
				[
					'label'     => esc_html__( 'Dot Active Color', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-image-slider.owl-carousel .owl-dots button.active' => 'background-color : {{VALUE}};',
						
					],
				]
			);

			$this->add_control(
				'dot_width',
				[
					'label' 		=> esc_html__( 'Size', 'auntri' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px' ],
					'range' => [
						'px' => [
							'min' 	=> 1,
							'max' 	=> 300,
							'step' 	=> 1,
						]
					],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-image-slider.owl-carousel .owl-dots button' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'dots_margin',
				[
					'label'      => esc_html__( 'Margin', 'auntri' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-image-slider.owl-carousel .owl-dots button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		###############  end section dot  ###############
		
		
		/*************  SECTION NAV.  *******************/
		$this->start_controls_section(
			'section_nav',
			[
				'label' => esc_html__( 'Nav', 'auntri' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'nav_control' => 'yes',
				]
			]
		);

			$this->add_responsive_control(
				'nav_top',
				[
					'label' => esc_html__( 'Top', 'auntri' ),
					'type' 	=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-image-slider.owl-carousel .owl-nav' => 'bottom: calc(100% + {{SIZE}}{{UNIT}})',
					],
				]
			);

			$this->add_control(
				'nav_width',
				[
					'label' 		=> esc_html__( 'Size', 'auntri' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px' ],
					'range' => [
						'px' => [
							'min' 	=> 1,
							'max' 	=> 300,
							'step' 	=> 1,
						]
					],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-image-slider.owl-carousel .owl-nav button' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					],
				]
			);
			
			$this->add_control(
				'icon_size_nav',
				[
					'label' 		=> esc_html__( 'Icon Size', 'auntri' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px' ],
					'range' => [
						'px' => [
							'min' 	=> 1,
							'max' 	=> 300,
							'step' 	=> 1,
						]
					],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-image-slider.owl-carousel .owl-nav button i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);	
			
				$this->add_control(
					'nav__bg_color_',
					[
						'label'     => esc_html__( 'Background', 'auntri' ),
						'type'      => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-image-slider.owl-carousel .owl-nav button' => 'background-color : {{VALUE}};',
						],
					]
				);	

				$this->add_control(
					'nav__bg_color_hover',
					[
						'label'     => esc_html__( 'Background Hover', 'auntri' ),
						'type'      => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-image-slider.owl-carousel .owl-nav button:hover' => 'background-color : {{VALUE}};',
						],
					]
				);

				$this->add_control(
					'bg_icon_color',
					[
						'label'     => esc_html__( 'Icon', 'auntri' ),
						'type'      => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-image-slider.owl-carousel .owl-nav button i' => 'color : {{VALUE}};',
						],
					]
				);			

				$this->add_control(
					'nav__bg_icon_color_hover',
					[
						'label'     => esc_html__( 'Icon Hover', 'auntri' ),
						'type'      => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-image-slider.owl-carousel .owl-nav button:hover i' => 'color : {{VALUE}};',
						],
					]
				);

		$this->end_controls_section();
		###############  end section nav  ###############
	}

	// Render Template Here
	protected function render() {

		$settings 							= 	$this->get_settings();
		$list_image 						= 	$settings['ova_image_slider'];

		$data_options['items']              = 	$settings['item_number'] ? $settings['item_number'] : 6;
		$data_options['slideBy']            = 	$settings['slides_to_scroll'];
		$data_options['margin']             = 	$settings['margin_items'] ? $settings['margin_items'] : 0;
		$data_options['autoplayHoverPause'] = 	$settings['pause_on_hover'] === 'yes' ? true : false;
		$data_options['loop']               = 	$settings['infinite'] === 'yes' ? true : false;
		$data_options['autoplay']           = 	$settings['autoplay'] === 'yes' ? true : false;
		$data_options['autoplayTimeout']    = 	$settings['autoplay_speed'] ? $settings['autoplay_speed'] : '3000';
		$data_options['smartSpeed']         = 	$settings['smartspeed'] ? $settings['smartspeed'] : '500';
		$data_options['dots']               = 	$settings['dot_control'] === 'yes' ? true : false;
		$data_options['nav']               	= 	$settings['nav_control'] === 'yes' ? true : false;
		$data_options['rtl']				= 	is_rtl() ? true: false;

		?>

		<div class="ova-image-slider owl-carousel owl-theme " data-options="<?php echo esc_attr(json_encode($data_options)); ?>" >
			<?php foreach( $list_image as $item): ?>
				<?php 
					$caption = wp_get_attachment_caption($item['id']);
					$alt     = get_post_meta( $item['id'], '_wp_attachment_image_alt', true);
				?>
					<img src="<?php echo esc_url( $item['url'] ); ?>" alt="<?php echo esc_attr( $alt ); ?>">
					
			<?php endforeach; ?>
		</div> 	
		 	
		<?php
	}

	
}
$widgets_manager->register( new Auntri_Elementor_Images_Slider() );