<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Border;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Auntri_Elementor_Ova_Image extends Widget_Base {

	
	public function get_name() {
		return 'auntri_elementor_ova_image';
	}

	
	public function get_title() {
		return esc_html__( 'Ova Image', 'auntri' );
	}

	
	public function get_icon() {
		return 'eicon-image';
	}

	
	public function get_categories() {
		return [ 'auntri' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'auntri' ),
			]
		);	
			
			$this->add_control(
				'version',
				[
					'label' 	=> esc_html__( 'Version', 'auntri' ),
					'type' 		=> Controls_Manager::SELECT,
					'default' 	=> 'version_1',
					'options' 	=> [
						'version_1' => esc_html__( 'Version 1', 'auntri' ),
						'version_2' => esc_html__( 'Version 2', 'auntri' ),
						'version_3' => esc_html__( 'Version 3', 'auntri' ),
					]
				]
			);

			$this->add_control(
				 'text_content',
				[
					'label' 	=> esc_html__( 'Text', 'auntri' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Auntri  Construction', 'auntri'),
					'condition' => [
						'version' => 'version_1'
					]
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name'     	=> 'text_content_typography_V1',
					'selector' 	=> '{{WRAPPER}} .ova-image.version_1 .text-content',
					'condition' => [
						'version' => 'version_1',
						'text_content!' => '',
					]
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name'     	=> 'text_content_typography_v2',
					'selector' 	=> '{{WRAPPER}} .ova-image.version_2 .text-content',
					'condition' => [
						'version' => 'version_2'
					]
				]
			);

			$this->add_control(
				 'text_content_v2',
				[
					'label'		=> esc_html__( 'Text', 'auntri' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Auntri', 'auntri'),
					'condition' => [
						'version' => 'version_2'
					]
				]
			);

			$this->add_control(
				'text_color',
				[
					'label'     => esc_html__( 'Color', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-image .text-content' => 'color : {{VALUE}};',
					],
					'condition' => [
						'version!' 		=> 'version_3',
						'text_content!' => '',
					]
				]
			);

			$this->add_control(
				'text_color_bg',
				[
					'label'     => esc_html__( 'Background', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-image .text-content' => 'background-color: {{VALUE}};',
					],
					'condition' => [
						'version!' 		=> 'version_3',
						'text_content!' => '',
					]
				]
			);

			$this->add_responsive_control(
				'text_padding',
				[
					'label'      => esc_html__( 'Padding', 'auntri' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-image .text-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
					'condition' => [
						'version!' 		=> 'version_3',
						'text_content!' => '',
					]
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'text_border',
					'label'     => esc_html__( 'Border', 'auntri' ),
					'selector'  => '{{WRAPPER}} .ova-image .text-content',
					'condition' => [
						'version!' 		=> 'version_3',
						'text_content!' => '',
					]
				]
			);

			//secondary text
			$this->add_control(
				'text_secondary',
				[
					'label' 	=> esc_html__( 'Text Secondary', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
						'version' => 'version_2'
					]
				]
			);

			$this->add_control(
				 'text_content_secondary_v2',
				[
					'label' 	=> esc_html__( 'Text Secondary', 'auntri' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Skill', 'auntri'),
					'condition' => [
						'version' => 'version_2'
					]
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name'     	=> 'text_secondary_typography_v2',
					'selector' 	=> '{{WRAPPER}} .ova-image.version_2 .text-content-2',
					'condition' => [
						'version' => 'version_2'
					]
				]
			);

			$this->add_control(
				'text_secondary_color',
				[
					'label'     => esc_html__( 'Color', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-image.version_2 .text-content-2' => 'color : {{VALUE}};',
					],
					'condition' => [
						'version' => 'version_2'
					]
				]
			);


			$this->add_responsive_control(
				'text_secondary_margin',
				[
					'label'      => esc_html__( 'Margin', 'auntri' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-image.version_2 .text-content-2' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
					'condition' => [
						'version' => 'version_2'
					]
				]
			);

			$this->add_responsive_control(
				'text_secondary_top',
				[
					'label' 	=> esc_html__( 'Bottom(px)', 'auntri' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' 	=> [
						'px' 	=> [
							'min' => 50,
							'max' => 500,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-image.version_2 .text-content-2 ' 	=> 'top: calc(100% - {{SIZE}}{{UNIT}});',
					],
					'condition' => [
						'version' => 'version_2'
					]	
				]
			);

			// IMAGE
			$this->add_control(
				'heading_image',
				[
					'label' 	=> esc_html__( 'Image', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_control(
				'ova_image',
				[
					'label' 	=> esc_html__( 'Choose Image', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::MEDIA,
					'default' 	=> [
						'url' => \Elementor\Utils::get_placeholder_image_src(),
					],
				]
			);

			$this->add_responsive_control(
	            'ova_image_display',
	            [
	                'label' 	=> esc_html__( 'Display', 'auntri' ),
	                'type' 		=> \Elementor\Controls_Manager::CHOOSE,
	                'options' 	=> [
	                    'flex' => [
	                        'title' => esc_html__( 'Flex', 'auntri' ),
	                        'icon' 	=> 'eicon-h-align-left',
	                    ],
	                    'inline-flex' => [
	                        'title' => esc_html__( 'Inline Flex', 'auntri' ),
	                        'icon' 	=> 'eicon-h-align-center',
	                    ],
	                ],
	                'selectors' => [
	                    '{{WRAPPER}} .ova-image.version_1' => 'display: {{VALUE}}',
	                ],
	                'condition' => [
						'version' => 'version_1',
					]
	            ]
	        );

			$this->add_responsive_control(
				'image_min-height',
				[
					'label' 	=> esc_html__( 'Min Height(px)', 'auntri' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' 	=> [
						'px' => [
							'min' => 100,
							'max' => 300,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-image' 	=> 'min-height: {{SIZE}}{{UNIT}}',
					],
				]
			);

			$this->add_responsive_control(
				'image_max-height',
				[
					'label' 	=> esc_html__( 'Max Height(px)', 'auntri' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' 	=> [
						'px' => [
							'min' => 100,
							'max' => 800,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-image' 	=> 'max-height: {{SIZE}}{{UNIT}}',
					],
				]
			);

			$this->add_control(
				'show_line_right',
				[
					'label'   => esc_html__( 'Show Line Right', 'auntri' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'no',
					'options' => [
						'yes' => esc_html__( 'Yes', 'auntri' ),
						'no'  => esc_html__( 'No', 'auntri' ),
					],
					'frontend_available' => true,
					'condition' => [
						'version' => 'version_1',
					]
				]
			);

			$this->add_control(
				'show_line_top',
				[
					'label'   => esc_html__( 'Show Line Top', 'auntri' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'no',
					'options' => [
						'yes' => esc_html__( 'Yes', 'auntri' ),
						'no'  => esc_html__( 'No', 'auntri' ),
					],
					'frontend_available' => true,
					'condition' => [
						'version' => 'version_1',
					]
				]
			);

			$this->add_control(
				'show_shape_top',
				[
					'label'   => esc_html__( 'Show Shape Top Right', 'auntri' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'no',
					'options' => [
						'yes' => esc_html__( 'Yes', 'auntri' ),
						'no'  => esc_html__( 'No', 'auntri' ),
					],
					'frontend_available' => true,
					'condition' => [
						'version' => 'version_1',
					]
				]
			);

			$this->add_responsive_control(
				'line-height-width',
				[
					'label' 	=> esc_html__( 'Width(px)', 'auntri' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' 	=> [
						'px' => [
							'min' => 10,
							'max' => 50,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-image.version_1 .line-right' 	=> 'width: {{SIZE}}{{UNIT}}',
					],
					'condition' => [
						'version' 			=> 	'version_1',
						'show_line_right' 	=> 	'yes'
					]
				]
			);

			$this->add_control(
				'line_right_color',
				[
					'label'     => esc_html__( 'Line Color', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-image.version_1 .line-right' => 'background-color: {{VALUE}};',
						
					],
					'condition' => [
						'version' 			=> 	'version_1',
						'show_line_right' 	=> 	'yes'
					]
				]
			);

			$this->add_control(
				'image_background_color',
				[
					'label'     => esc_html__( 'Background Image Color', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-image.version_2:before' => 'background-color: {{VALUE}};',
						
					],
					'condition' => [
						'version' => 'version_2'
					]
				]
			);

			$this->add_control(
				'shape_top_background_color',
				[
					'label'     => esc_html__( 'Background Shape Color', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-image.version_1 .shape_top_right' => 'background-color: {{VALUE}};',
						
					],
					'condition' => [
						'version' 			=> 	'version_1',
						'show_shape_top' 	=> 	'yes',

					]
				]
			);

		$this->end_controls_section();

		
	}

	// Render Template Here
	protected function render() {
		$settings 		= 	$this->get_settings();
		$version 		= 	$settings['version'];

		$image 			= 	$settings['ova_image'];
		$img_alt 		= 	isset( $settings['image']['alt'] ) ? $settings['image']['alt'] : '';
		$line_right 	= 	$settings['show_line_right'];
		$line_top 		= 	$settings['show_line_top'];
		$shape_top		= 	$settings['show_shape_top'];

			if( $version == 'version_1' ) {

				$text_content 	= 	$settings['text_content'];

			}elseif( $version == 'version_2' ) {

				$text_content 	= 	$settings['text_content_v2'];
				$text_content_2 = 	$settings['text_content_secondary_v2'];

			}
		?>

		<?php if( $image['url'] ) : ?>
			<div class="ova-image <?php echo esc_attr( $version ); ?>">
				<?php if( $version == 'version_2' || $version == 'version_1' ) { ?>
					<?php if( $text_content != '' ) { ?>
						<span class="text-content"> 
							<?php echo esc_html( $text_content ); ?>
						</span>
					<?php } ?>

					<?php if( $version == 'version_2' ) { ?>
					<span  class="text-content-2">
						<?php echo esc_html( $text_content_2 ); ?>
					</span>
				<?php } 

				}?>

				<img src="<?php echo esc_url( $image['url'] ); ?>" alt="<?php echo esc_attr( $img_alt ); ?>">

				<?php if( $version == 'version_1' && $line_right == 'yes' ) { ?>
					<div class="line-right"></div>
				<?php } ?>

				<?php if( $version == 'version_1' && $line_top == 'yes' ) { ?>
					<div class="line-top"></div>
				<?php } ?>

				<?php if( $version == 'version_1' && $shape_top == 'yes' ) { ?>
					<div class="shape_top_right"></div>
				<?php } ?>

			</div>
		<?php endif; ?>
		 	
		<?php
	}
	
}
$widgets_manager->register( new Auntri_Elementor_Ova_Image() );