<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Auntri_Elementor_Progress_Circle extends Widget_Base {

	
	public function get_name() {
		return 'auntri_elementor_progress_circle';
	}

	
	public function get_title() {
		return esc_html__( 'Progress Circle', 'auntri' );
	}

	
	public function get_icon() {
		return 'eicon-spinner';
	}

	
	public function get_categories() {
		return [ 'auntri' ];
	}

	public function get_script_depends() {
		wp_enqueue_script( 'progress-circle-appear', get_theme_file_uri('/assets/libs/appear/appear.js'), array('jquery'), false, true);
		wp_enqueue_script( 'progress-circle', get_template_directory_uri().'/assets/libs/circle-progress/circle-progress.min.js', array('jquery'), false, true );
		return [ 'auntri-elementor-progress-circle' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'auntri' ),
			]
		);	
			
			
			$this->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'auntri' ),
					'type' => Controls_Manager::TEXT,
					'default' => esc_html__( 'Building Construction', 'auntri' ),
				]
			);

			$this->add_control(
				'percent',
				[
					'label' => esc_html__( 'Percent', 'auntri' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px'],
					'default' => [
						'size' => 90,
					],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
							'step' => 1,
						],
					],
				]
			);

			$this->add_control(
				'unit',
				[
					'label' => esc_html__( 'Unit', 'auntri' ),
					'type' => Controls_Manager::TEXT,
					'default' => esc_html__( '%', 'auntri' ),
				]
			);

			$this->add_control(
				'circle_heading',
				[
					'label' => esc_html__( 'Circle', 'auntri' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_group_control(
			  \Elementor\Group_Control_Typography::get_type(),
			  [
				  'name' => 'circle_typography',
				  'selector' => '{{WRAPPER}} .ova-progress-circle-wrapper .title',
				  
			  ]
		  );

		    $this->add_control(
				'linecap',
				[
					'label' => esc_html__( 'LineCap', 'auntri' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'default',
					'options' => [
						'default' => esc_html__('Default', 'auntri'),
						'round'   => esc_html__('Round', 'auntri'),
					]
				]
			);

			$this->add_control(
				'circle_size',
				[
					'label' => esc_html__( 'Size (px)', 'auntri' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px'],
					'default' => [
						'size' => 120,
					],
					'range' => [
						'px' => [
							'min' => 100,
							'max' => 400,
							'step' => 1,
						],
					],
				]
			);

			$this->add_control(
				'circle_thickness',
				[
					'label' => esc_html__( 'Thickness', 'auntri' ),
					'type' => Controls_Manager::NUMBER,
					'min' => 2,
					'max' => 50,
					'step' => 1,
					'default' => 3		
				]
			);

			$this->add_control(
				'color_circle',
				[
					'label' => esc_html__( 'Color', 'auntri' ),
					'type' => Controls_Manager::COLOR,
					'default' => '#fc811b'
				]
			);

			$this->add_responsive_control(
				'align',
				[
					'label' => esc_html__( 'Alignment', 'auntri' ),
					'type' 	=> Controls_Manager::CHOOSE,
					'options' => [
						'left' => [
							'title' => esc_html__( 'Left', 'auntri' ),
							'icon' 	=> 'eicon-text-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'auntri' ),
							'icon' 	=> 'eicon-text-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'auntri' ),
							'icon' 	=> 'eicon-text-align-right',
						],
					],
					'default' => 'center',
					'selectors' => [
						'{{WRAPPER}} .ova-progress-circle-wrapper' => 'text-align: {{VALUE}};',
					],
				]
		   );

		$this->end_controls_section();

		
	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

		$title          =    $settings['title'];
		$unit           =    $settings['unit'];
		$percent        =    is_numeric( $settings['percent']['size'] ) ? $settings['percent']['size'] : '0';
		$percentage     =    $percent / 100;
		$size           =    is_numeric( $settings['circle_size']['size'] ) ? $settings['circle_size']['size'] : '144';
		$color          =    ( isset( $settings['color_circle'] ) && $settings['color_circle'] !== '' ) ?  $settings['color_circle'] : '#5f2dee' ;
		$thickness      =    $settings['circle_thickness'];
	    $linecap        =    $settings['linecap'];
		
		?>

		<div class="ova-progress-circle-wrapper">
            	
    	    <div class="ova-progress-circle"  
                data-thickness="<?php echo esc_attr( $thickness ); ?>" 
                data-size="<?php echo esc_attr( $size ); ?>"
                data-value="<?php echo esc_attr( $percentage ); ?>"
                data-color="<?php echo esc_attr( $color ); ?>"
                data-linecap="<?php echo esc_attr( $linecap ); ?>"
            >
                
                <div class="percent">
                	<strong></strong>
            	    <i><?php echo esc_html( $unit ) ; ?></i>
                </div>
            </div>

            <?php if( !empty( $title ) ) : ?>
        	    <div class="title">
        	    	<?php echo esc_html( $title ) ; ?>	
        	    </div>
        	<?php endif; ?>

        </div>
		 	
		<?php
	}

	
}
$widgets_manager->register( new Auntri_Elementor_Progress_Circle() );