<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Repeater;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Auntri_Elementor_Team_Slider extends Widget_Base {

	public function get_name() {
		return 'auntri_elementor_team_slider';
	}

	public function get_title() {
		return esc_html__( 'Team Slider', 'auntri' );
	}

	public function get_icon() {
		return 'eicon-slider-album';
	}

	public function get_categories() {
		return [ 'auntri' ];
	}

	public function get_script_depends() {
		wp_enqueue_style( 'owl-carousel', get_theme_file_uri('/assets/libs/carousel/assets/owl.carousel.min.css') );
		wp_enqueue_script( 'owl-carousel', get_theme_file_uri('/assets/libs/carousel/owl.carousel.min.js'), array('jquery'), false, true );
		return [ 'auntri-elementor-team-slider' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_team_slider',
			[
				'label' => esc_html__( 'Team Slider', 'auntri' ),
			]
		);
			
			$repeater = new \Elementor\Repeater();

				$repeater->add_control(
					'avatar',
					[
						'label' 	=> esc_html__( 'Choose Avatar', 'auntri' ),
						'type' 		=> Controls_Manager::MEDIA,
						'default' 	=> [
							'url' 	=> Utils::get_placeholder_image_src(),
						],
					]
				);

				$repeater->add_control(
					'link_team',
					[
						'label' 		=> esc_html__( 'Link', 'auntri' ),
						'type' 			=> Controls_Manager::URL,
						'placeholder' 	=> esc_html__( 'https://your-link.com', 'auntri' ),
					]
				);

				$repeater->add_control(
					'name',
					[
						'label' 		=> esc_html__( 'Name', 'auntri' ),
						'type' 			=> Controls_Manager::TEXT,
						'default' 		=> esc_html__('Add Your Name', 'auntri' ),
					]
				);

				$repeater->add_control(
					'job',
					[
						'label' 		=> esc_html__( 'Job', 'auntri' ),
						'type' 			=> Controls_Manager::TEXT,
						'default' 		=> esc_html__('Add Your Job', 'auntri' ),
					]
				);

				$repeater->add_control(
					'icon_1',
					[
						'label' 		=> esc_html__( 'Icon 1', 'auntri' ),
						'type' 			=> Controls_Manager::TEXT,
						'default' 		=> esc_html__('ovaicon-twitter', 'auntri' ),
					]
				);

				$repeater->add_control(
					'link_1',
					[
						'label' 		=> esc_html__( 'Link 1', 'auntri' ),
						'type' 			=> Controls_Manager::URL,
						'placeholder' 	=> esc_html__( 'https://your-link.com', 'auntri' ),
						'show_external' => true,
						'default' 		=> [
							'url' 		=> 'https://twitter.com',
						],
					]
				);

				$repeater->add_control(
					'icon_2',
					[
						'label' 		=> esc_html__( 'Icon 2', 'auntri' ),
						'type' 			=> Controls_Manager::TEXT,
						'default' 		=> esc_html__('ovaicon ovaicon-facebook-logo', 'auntri' ),
					]
				);

				$repeater->add_control(
					'link_2',
					[
						'label' 		=> esc_html__( 'Link 2', 'auntri' ),
						'type' 			=> Controls_Manager::URL,
						'placeholder' 	=> esc_html__( 'https://your-link.com', 'auntri' ),
						'show_external' => true,
						'default' 		=> [
							'url' 		=> 'https://facebook.com',
						],
					]
				);

				$repeater->add_control(
					'icon_3',
					[
						'label' 		=> esc_html__( 'Icon 3', 'auntri' ),
						'type' 			=> Controls_Manager::TEXT,
						'default' 		=> esc_html__('fab fa-pinterest-p', 'auntri' ),
					]
				);

				$repeater->add_control(
					'link_3',
					[
						'label' 		=> esc_html__( 'Link 3', 'auntri' ),
						'type' 			=> Controls_Manager::URL,
						'placeholder' 	=> esc_html__( 'https://your-link.com', 'auntri' ),
						'show_external' => true,
						'default' 		=> [
							'url' 		=> 'https://pinterest.com',
						],
					]
				);

				$repeater->add_control(
					'icon_4',
					[
						'label' 		=> esc_html__( 'Icon 4', 'auntri' ),
						'type' 			=> Controls_Manager::TEXT,
						'default' 		=> esc_html__('ovaicon ovaicon-instagram', 'auntri' ),
					]
				);

				$repeater->add_control(
					'link_4',
					[
						'label' 		=> esc_html__( 'Link 4', 'auntri' ),
						'type' 			=> Controls_Manager::URL,
						'placeholder' 	=> esc_html__( 'https://your-link.com', 'auntri' ),
						'show_external' => true,
						'default' 		=> [
							'url' 		=> 'https://instagram.com',
						],
					]
				);

			$this->add_control(
				'team_slider_items',
				[
					'label' 	=> esc_html__( 'Items', 'auntri' ),
					'type' 		=> Controls_Manager::REPEATER,
					'fields' 	=> $repeater->get_controls(),
					'default' 	=> [
						[
							'name' 			=> esc_html__('Kevin Martin', 'auntri' ),
							'job' 			=> esc_html__('CO founder', 'auntri' ),		
						],
						[
							'name' 			=> esc_html__('Sarah Albert', 'auntri' ),
							'job' 			=> esc_html__('Manager', 'auntri' ),
						],
						[
							'name' 			=> esc_html__('Mike Hardson', 'auntri' ),
							'job' 			=> esc_html__('Contractor', 'auntri' ),
						],
						[
							'name' 			=> esc_html__('Aleesha Brown', 'auntri' ),
							'job' 			=> esc_html__('Co founder', 'auntri' ),
						],
						[
							'name' 			=> esc_html__('John Smith', 'auntri' ),
							'job' 			=> esc_html__('Manager', 'auntri' ),		
						],
						[
							'name' 			=> esc_html__('Contractor', 'auntri' ),
							'job' 			=> esc_html__('Christine Eve', 'auntri' ),
						],
					],
					'title_field' => '{{{ name }}}',
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_additional_options',
			[
				'label' => esc_html__( 'Additional Options', 'auntri' ),
			]
		);

			$this->add_control(
				'margin_items',
				[
					'label'   => esc_html__( 'Margin Right Items', 'auntri' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 30,
				]
				
			);

			$this->add_control(
				'item_number',
				[
					'label'       => esc_html__( 'Item Number', 'auntri' ),
					'type'        => Controls_Manager::NUMBER,
					'default'     => 3,
				]
			);

			$this->add_control(
				'slides_to_scroll',
				[
					'label'       => esc_html__( 'Slides to Scroll', 'auntri' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Set how many slides are scrolled per swipe.', 'auntri' ),
					'default'     => 1,
				]
			);

			$this->add_control(
				'pause_on_hover',
				[
					'label'   => esc_html__( 'Pause on Hover', 'auntri' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'auntri' ),
						'no'  => esc_html__( 'No', 'auntri' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'infinite',
				[
					'label'   => esc_html__( 'Infinite Loop', 'auntri' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'no',
					'options' => [
						'yes' => esc_html__( 'Yes', 'auntri' ),
						'no'  => esc_html__( 'No', 'auntri' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay',
				[
					'label'   => esc_html__( 'Autoplay', 'auntri' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'auntri' ),
						'no'  => esc_html__( 'No', 'auntri' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay_speed',
				[
					'label'     => esc_html__( 'Autoplay Speed', 'auntri' ),
					'type'      => Controls_Manager::NUMBER,
					'default'   => 3000,
					'step'      => 500,
					'condition' => [
						'autoplay' => 'yes',
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'smartspeed',
				[
					'label'   => esc_html__( 'Smart Speed', 'auntri' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 500,
				]
			);

			$this->add_control(
				'nav_control',
				[
					'label'   => esc_html__( 'Show Nav', 'auntri' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'auntri' ),
						'no'  => esc_html__( 'No', 'auntri' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'nav_left',
				[
					'label'       	=> esc_html__( 'Icon Left', 'auntri' ),
					'type'        	=> Controls_Manager::TEXT,
					'default'     	=> esc_html__( 'fas fa-angle-left', 'auntri' ),
					'condition' 	=> [
						'nav_control' => 'yes',
					],
				]
			);

			$this->add_control(
				'nav_right',
				[
					'label'       	=> esc_html__( 'Icon Right', 'auntri' ),
					'type'        	=> Controls_Manager::TEXT,
					'default'     	=> esc_html__( 'fas fa-angle-right', 'auntri' ),
					'condition' 	=> [
						'nav_control' => 'yes',
					],
				]
			);

		$this->end_controls_section();
        
        // Section Style
		$this->start_controls_section(
			'section_info_style',
			[
				'label' 	=> esc_html__( 'Info', 'auntri' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);

        	$this->add_control(
	            'info_background_normal',
	            [
	                'label' 	=> esc_html__( 'Background Color', 'auntri' ),
	                'type' 		=> Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .ova-team-slider .item-team .info' => 'background-color: {{VALUE}};',
	                    '{{WRAPPER}} .ova-team-slider .item-team .avatar .trapezoid' => ' border-bottom-color: {{VALUE}};',
	                ],
	            ]
	        );

	        $this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
				[
					'name' 		=> 'info_box_shadow_normal',
					'label' 	=> esc_html__( 'Box Shadow', 'auntri' ),
					'selector' 	=> '{{WRAPPER}} .ova-team-slider .item-team .info',
				]
			);		  

			$this->add_responsive_control(
	            'info_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team-slider .item-team .info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                 
	                ],
	            ]
	        );

		$this->end_controls_section();

		/* Begin Name Style */
		$this->start_controls_section(
            'name_style',
            [
                'label' => esc_html__( 'Name', 'auntri' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'name_typography',
					'selector' 	=> '{{WRAPPER}} .ova-team-slider .item-team .info .name',
				]
			);

			$this->start_controls_tabs( 'tabs_title_style' );

				$this->start_controls_tab(
		            'tab_name_normal',
		            [
		                'label' => esc_html__( 'Normal', 'auntri' ),
		            ]
		        );

					$this->add_control(
			            'name_color_normal',
			            [
			                'label' 	=> esc_html__( 'Color', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider .item-team .info .name' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

				$this->end_controls_tab();

				$this->start_controls_tab(
		            'tab_name_hover',
		            [
		                'label' => esc_html__( 'Hover', 'auntri' ),
		            ]
		        );

					$this->add_control(
			            'name_color_hover',
			            [
			                'label' 	=> esc_html__( 'Color', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider .item-team:hover .info .name' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

				$this->end_controls_tab();
			$this->end_controls_tabs();

	        $this->add_responsive_control(
	            'name_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team-slider .item-team .info .name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();

        /* Begin Job Style */
		$this->start_controls_section(
            'job_style',
            [
                'label' => esc_html__( 'Job', 'auntri' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'job_typography',
					'selector' 	=> '{{WRAPPER}} .ova-team-slider .item-team .info .job',
				]
			);

			$this->start_controls_tabs( 'tabs_job_style' );

				$this->start_controls_tab(
		            'tab_job_normal',
		            [
		                'label' => esc_html__( 'Normal', 'auntri' ),
		            ]
		        );

					$this->add_control(
			            'job_color_normal',
			            [
			                'label' 	=> esc_html__( 'Color', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider .item-team .info .job' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

			        $this->add_control(
			            'job_bgcolor_normal',
			            [
			                'label' 	=> esc_html__( 'Background Color', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider .item-team .info .job' => 'background-color: {{VALUE}}',
			                ],	      
			            ]
			        );

				$this->end_controls_tab();

				$this->start_controls_tab(
		            'tab_job_hover',
		            [
		                'label' => esc_html__( 'Hover', 'auntri' ),
		            ]
		        );

					$this->add_control(
			            'job_color_hover',
			            [
			                'label' 	=> esc_html__( 'Color', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider .item-team:hover .info .job' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

				$this->end_controls_tab();
			$this->end_controls_tabs();

	        $this->add_responsive_control(
	            'job_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team-slider .item-team .info .job' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();

        /* Begin Social Style */
		$this->start_controls_section(
            'social_style',
            [
                'label' => esc_html__( 'Social', 'auntri' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

        	$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'social_typography',
					'selector' 	=> '{{WRAPPER}} .ova-team-slider .item-team .social-list .social i',
				]
			);

			$this->add_control(
	            'social_background',
	            [
	                'label' 	=> esc_html__( 'Background', 'auntri' ),
	                'type' 		=> Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .ova-team-slider .item-team .social-list' => 'background-color: {{VALUE}};',
	                ],
	            ]
	        );

        	$this->start_controls_tabs( 'tabs_social_style' );
				
				$this->start_controls_tab(
		            'tab_social_normal',
		            [
		                'label' => esc_html__( 'Normal', 'auntri' ),
		            ]
		        );

		        	$this->add_control(
			            'social_color_normal',
			            [
			                'label' 	=> esc_html__( 'Color', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider .item-team .social-list .social i' => 'color: {{VALUE}};',
			                ],
			            ]
			        );

		        	$this->add_control(
			            'social_background_normal',
			            [
			                'label' 	=> esc_html__( 'Background', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider .item-team .social-list .social' => 'background-color: {{VALUE}};',
			                ],
			            ]
			        );

		        $this->end_controls_tab();

		        $this->start_controls_tab(
		            'tab_social_hover',
		            [
		                'label' => esc_html__( 'Hover', 'auntri' ),
		            ]
		        );

		        	$this->add_control(
			            'social_color_hover',
			            [
			                'label' 	=> esc_html__( 'Color', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider .item-team .social-list .social:hover i' => 'color: {{VALUE}};',
			                ],
			            ]
			        );

		        	$this->add_control(
			            'social_background_hover',
			            [
			                'label' 	=> esc_html__( 'Background', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider .item-team .social-list .social:hover' => 'background-color: {{VALUE}} !important;',
			                ],
			            ]
			        );

		        $this->end_controls_tab();
			$this->end_controls_tabs();

			$this->add_responsive_control(
				'social_size',
				[
					'label' 	=> esc_html__( 'Size', 'auntri' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
						],
					],
					'size_units' 	=> [ 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-team-slider .item-team .social-list .social' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};min-width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'icon_social_size',
				[
					'label' 	=> esc_html__( 'Icon Size', 'auntri' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
						],
					],
					'size_units' 	=> [ 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-team-slider .item-team .social-list .social i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

	        $this->add_control(
	            'social_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border Radius', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team-slider .item-team .social-list .social' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_responsive_control(
	            'social_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team-slider .item-team .social-list .social' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();

        /* Begin Nav Style */
		$this->start_controls_section(
            'nav_style',
            [
                'label' => esc_html__( 'Nav', 'auntri' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

        	$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'nav_typography',
					'selector' 	=> '{{WRAPPER}} .ova-team-slider .team-slider-wrapper.owl-carousel .owl-nav button i',
				]
			);

			$this->add_responsive_control(
				'nav_size',
				[
					'label' 	=> esc_html__( 'Size', 'auntri' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' 	=> [ 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-team-slider .team-slider-wrapper.owl-carousel .owl-nav button' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};min-width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->start_controls_tabs( 'tabs_nav_style' );

				$this->start_controls_tab(
		            'tab_nav_normal',
		            [
		                'label' => esc_html__( 'Normal', 'auntri' ),
		            ]
		        );

					$this->add_control(
			            'nav_color_normal',
			            [
			                'label' 	=> esc_html__( 'Color', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider .team-slider-wrapper.owl-carousel .owl-nav button i' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

			        $this->add_group_control(
						Group_Control_Background::get_type(),
						[
							'name' 		=> 'nav_background_normal',
							'label' 	=> esc_html__( 'Background', 'auntri' ),
							'types' 	=> [ 'classic', 'gradient' ],
							'exclude' 	=> [ 'image' ],
							'selector' 	=> '{{WRAPPER}} .ova-team-slider .team-slider-wrapper.owl-carousel .owl-nav button',
						]
					);

					$this->add_control(
						'nav_opacity_normal',
						[
							'label' 		=> esc_html__( 'Opacity', 'auntri' ),
							'type' 			=> Controls_Manager::SLIDER,
							'range' => [
								'px' => [
									'min' 	=> 0,
									'max' 	=> 1,
									'step' 	=> 0.1,
								],
							],
							'selectors' => [
								'{{WRAPPER}} .ova-team-slider .team-slider-wrapper.owl-carousel .owl-nav button' => 'opacity: {{SIZE}}',
							],
						]
					);

				$this->end_controls_tab();

				$this->start_controls_tab(
		            'tab_nav_hover',
		            [
		                'label' => esc_html__( 'Hover', 'auntri' ),
		            ]
		        );

					$this->add_control(
			            'nav_color_hover',
			            [
			                'label' 	=> esc_html__( 'Color', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider .team-slider-wrapper.owl-carousel .owl-nav button:hover i' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

			        $this->add_group_control(
						Group_Control_Background::get_type(),
						[
							'name' 		=> 'nav_background_hover',
							'label' 	=> esc_html__( 'Background', 'auntri' ),
							'types' 	=> [ 'classic', 'gradient' ],
							'exclude' 	=> [ 'image' ],
							'selector' 	=> '{{WRAPPER}} .ova-team-slider .team-slider-wrapper.owl-carousel .owl-nav button:hover',
						]
					);

					$this->add_control(
			            'nav_border_color_hover',
			            [
			                'label' 	=> esc_html__( 'Border Color Hover', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider .team-slider-wrapper.owl-carousel .owl-nav button:hover' => 'border-color: {{VALUE}}',
			                ],
			            ]
			        );

					$this->add_control(
						'nav_opacity_hover',
						[
							'label' 		=> esc_html__( 'Opacity', 'auntri' ),
							'type' 			=> Controls_Manager::SLIDER,
							'range' => [
								'px' => [
									'min' 	=> 0,
									'max' 	=> 1,
									'step' 	=> 0.1,
								],
							],
							'selectors' => [
								'{{WRAPPER}} .ova-team-slider .team-slider-wrapper.owl-carousel .owl-nav button:hover' => 'opacity: {{SIZE}}',
							],
						]
					);

				$this->end_controls_tab();
			$this->end_controls_tabs();

			$this->add_group_control(
	            Group_Control_Border::get_type(), [
	                'name' 		=> 'nav_border',
	                'selector' 	=> '{{WRAPPER}} .ova-team-slider .team-slider-wrapper.owl-carousel .owl-nav button',
	                'separator' => 'before',
	            ]
	        );

	        $this->add_control(
	            'nav_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border Radius', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team-slider .team-slider-wrapper.owl-carousel .owl-nav button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_responsive_control(
	            'nav_margin_prev',
	            [
	                'label' 		=> esc_html__( 'Margin Prev', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team-slider .team-slider-wrapper.owl-carousel .owl-nav button.owl-prev' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_responsive_control(
	            'nav_margin_next',
	            [
	                'label' 		=> esc_html__( 'Margin Next', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team-slider .team-slider-wrapper.owl-carousel .owl-nav button.owl-next' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_responsive_control(
	            'nav_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team-slider .team-slider-wrapper.owl-carousel .owl-nav' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
        /* End Nav_v1 Style */
	}

	// Render Template Here
	protected function render() {

		$settings 	= $this->get_settings();

		$items 		= $settings['team_slider_items'];

		$data_options['items']              = $settings['item_number'];
		$data_options['slideBy']            = $settings['slides_to_scroll'];
		$data_options['margin']             = $settings['margin_items'];
		$data_options['autoplayHoverPause'] = $settings['pause_on_hover'] === 'yes' ? true : false;
		$data_options['loop']               = $settings['infinite'] === 'yes' ? true : false;
		$data_options['autoplay']           = $settings['autoplay'] === 'yes' ? true : false;
		$data_options['autoplayTimeout']    = $settings['autoplay_speed'];
		$data_options['smartSpeed']         = $settings['smartspeed'];
		$data_options['nav']                = $settings['nav_control'] === 'yes' ? true : false;
		$data_options['nav_left']           = $settings['nav_left'];
		$data_options['nav_right']          = $settings['nav_right'];

		?>

		<?php if ( $items && is_array( $items ) ): ?>
		 	<div class="ova-team-slider">
		 		<div class="team-slider-wrapper owl-carousel owl-theme" data-options="<?php echo esc_attr( json_encode( $data_options ) ); ?>">
		 			<?php foreach ( $items as $item ): 
		 				$avatar_url = $item['avatar']['url'];
		 				$alt 		= isset( $item['avatar']['alt'] ) ? $item['avatar']['alt'] : esc_html__( 'Avatar', 'auntri' );
		 				$link_team 	= $item['link_team']['url'];
						$target 	= ( 'on' == $item['link_team']['is_external'] ) ? ' target="_blank"' : '';
		 			?>
		 				<div class="item-team item-team-1">

		 					<div class="avatar">

		 						<?php if ( $link_team ): ?>
									<a href="<?php echo esc_url( $link_team ); ?>"<?php printf( $target ); ?>>
				 						<div class="decor-geometry">
				 							<i aria-hidden="true" class="flaticon flaticon-right-arrow"></i>
				 						</div>
									</a>
								<?php else : ?>
									<div class="decor-geometry"></div>
							    <?php endif;?>

		 						<div class="trapezoid"></div>
                                
                                <?php if ( $link_team ): ?>
									<a href="<?php echo esc_url( $link_team ); ?>"<?php printf( $target ); ?>>
								<?php endif; ?>
		 							<img src="<?php echo esc_url( $avatar_url ); ?>" alt="<?php echo esc_html( $alt ); ?>">
		 						<?php if ( $link_team ): ?>
									</a>
								<?php endif; ?>

		 						<!-- Social -->
		 						<?php if ( $item['icon_1'] || $item['icon_2'] || $item['icon_3'] || $item['icon_4']  ): ?>
		 							<ul class="social-list">
		 								<!-- Icon 1 -->
		 								<?php if ( $item['icon_1'] ): 
		 									$target_1 = ( 'on' == $item['link_1']['is_external'] ) ? ' target="_blank"' : '';
		 								?>
			 								<li>
			 									<a class="social" href="<?php echo esc_url( $item['link_1']['url'] ); ?>"<?php printf( $target_1 ); ?>>
		 											<i class="<?php echo esc_attr( $item['icon_1'] ); ?>"></i>
		 										</a>
			 								</li>	
		 								<?php endif; ?>

		 								<!-- Icon 2 -->
		 								<?php if ( $item['icon_2'] ): 
		 									$target_2 = ( 'on' == $item['link_2']['is_external'] ) ? ' target="_blank"' : '';
		 								?>  
		 								    <li>
		 										<a class="social" href="<?php echo esc_url( $item['link_2']['url'] ); ?>"<?php printf( $target_2 ); ?>>
		 											<i class="<?php echo esc_attr( $item['icon_2'] ); ?>"></i>
		 										</a>
		 									</li>
		 								<?php endif; ?>

		 								<!-- Icon 3 -->
		 								<?php if ( $item['icon_3'] ): 
		 									$target_3 = ( 'on' == $item['link_3']['is_external'] ) ? ' target="_blank"' : '';
		 								?>
		 								    <li>
		 										<a class="social" href="<?php echo esc_url( $item['link_3']['url'] ); ?>"<?php printf( $target_3 ); ?>>
		 											<i class="<?php echo esc_attr( $item['icon_3'] ); ?>"></i>
		 										</a>
		 									</li>
		 								<?php endif; ?>

		 								<!-- Icon 4 -->
		 								<?php if ( $item['icon_4'] ): 
		 									$target_4 = ( 'on' == $item['link_4']['is_external'] ) ? ' target="_blank"' : '';
		 								?>
		 								    <li>
		 										<a class="social" href="<?php echo esc_url( $item['link_4']['url'] ); ?>"<?php printf( $target_4 ); ?>>
		 											<i class="<?php echo esc_attr( $item['icon_4'] ); ?>"></i>
		 										</a>
		 									</li>
		 								<?php endif; ?>
		 							</ul>
	 							<?php endif; ?>
		 					</div>
                            
                            <div class="info">
                            	
                            	<!-- Job -->
			 					<?php if ( $item['job'] ): ?>
			 						<p class="job"><?php echo esc_html( $item['job'] ); ?></p>
		 						<?php endif; ?>

                            	<!-- Name -->
			 					<?php if ( $item['name'] ): ?>

			 						<?php if ( $link_team ): ?>
										<a href="<?php echo esc_url( $link_team ); ?>"<?php printf( $target ); ?>>
									<?php endif; ?>
			 							<h3 class="name"><?php echo esc_html( $item['name'] ); ?></h3>
			 						<?php if ( $link_team ): ?>
										</a>
									<?php endif; ?>

			 					<?php endif; ?>
			 					
                            </div>	

		 				</div>
		 			<?php endforeach; ?>
		 			
		 		</div>
		 	</div>
		<?php
		endif;
	}

	
}
$widgets_manager->register( new Auntri_Elementor_Team_Slider() );