<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Auntri_Elementor_Team extends Widget_Base {
	
	public function get_name() {
		return 'auntri_elementor_team';
	}

	public function get_title() {
		return esc_html__( 'Team', 'auntri' );
	}

	public function get_icon() {
		return 'eicon-user-circle-o';
	}

	public function get_categories() {
		return [ 'auntri' ];
	}

	public function get_keywords() {
		return [ 'social', 'icon', 'link' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'auntri' ),
			]
		);

		$this->add_control(
			'template',
			[
				'label' => esc_html__( 'Template', 'auntri' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'template1',
				'options' => [
					'template1' => esc_html__('Template 1', 'auntri'),
					'template2' => esc_html__('Template 2', 'auntri'),
					'template3' => esc_html__('Template 3', 'auntri'),
					'template4' => esc_html__('Template 4', 'auntri'),
					'template5' => esc_html__('Template 5', 'auntri'),
				]
			]
		);

	     	// Add Class control
		    $this->add_control(
				'image',
				[
					'label' 	=> esc_html__( 'Image Team', 'auntri' ),
					'type' 		=> Controls_Manager::MEDIA,
					'dynamic' 	=> [
						'active' 	=> true,
					],
					'default' 	=> [
						'url' 	=> Utils::get_placeholder_image_src(),
					],
				]
			);

			$this->add_control(
				'link_team',
				[
					'label' 		=> esc_html__( 'Link', 'auntri' ),
					'type' 			=> Controls_Manager::URL,
					'placeholder' 	=> esc_html__( 'https://your-link.com', 'auntri' ),
				]
			);

			$this->add_control(
				'job',
				[
					'label' 	=> esc_html__( 'Job', 'auntri' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__( 'Manager', 'auntri' ),
				]
			);
				
			$this->add_control(
				'name',
				[
					'label' 	=> esc_html__( 'Name', 'auntri' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__( 'Sarah Albert', 'auntri' ),
				]
			);

			$this->add_control(
				'description',
				[
					'label' 		=> esc_html__( 'Description', 'auntri' ),
					'type' 			=> Controls_Manager::TEXTAREA,
					'default' 		=> esc_html__('Lorem ipsum dolor sit am adipi sicing elit, sed do consulting firms.', 'auntri' ),
					'condition' => [
						'template' => 'template5'
					]
				]
			);
            
			// list icons control
			$repeater = new \Elementor\Repeater();

			$repeater->add_control(
				'class_icon',
				[
					'label' 	=> esc_html__( 'Class Icon', 'auntri' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=>  esc_html__( 'ovaicon-twitter', 'auntri' ),
					
				]
			);
			 
			$repeater->add_control(
				'link',
				[
					'label' 	=> esc_html__( 'Link', 'auntri' ),
					'type' 		=> Controls_Manager::URL,
					'dynamic' => [
						'active' => true,
					],
					'default' => [
						'is_external' => true,
						'nofollow' => true,
					],
					'placeholder' => esc_html__( 'https://your-link.com', 'auntri' ),
				]
			);

			$repeater->add_control(
				'list_title', 
				[
					'label' 		=> esc_html__( 'List Title', 'auntri' ),
					'type' 			=> Controls_Manager::TEXT,
					'default' 		=> esc_html__( 'Item' , 'auntri' ),
					'label_block' 	=> true,
				]
			);
			
            $this->add_control(
				'icons',
				[
					'label' 	=> esc_html__( 'Social Icons', 'auntri' ),
					'type' 		=> Controls_Manager::REPEATER,
					'fields' 	=> $repeater->get_controls(),
					'default' 	=> [
						[	
							'list_title' 		=> esc_html__( 'Twitter', 'auntri' ),
							'class_icon' 		=> esc_html__( 'ovaicon-twitter', 'auntri' ),
							'link' 				=> [ 'url' => 'https://twitter.com' ],
						],
						[	
							'list_title' 		=> esc_html__( 'Facebook', 'auntri' ),
							'class_icon' 		=> esc_html__( 'ovaicon ovaicon-facebook-logo', 'auntri' ),
							'link' 				=> [ 'url' => 'https://facebook.com' ],
						],
						[	
							'list_title' 		=> esc_html__( 'Pinterest', 'auntri' ),
							'class_icon' 		=> esc_html__( 'fab fa-pinterest-p', 'auntri' ),
							'link' 				=> [ 'url' => 'https://pinterest.com' ],
						],
						[	
							'list_title' 		=> esc_html__( 'Instagram', 'auntri' ),
							'class_icon' 		=> esc_html__( 'ovaicon ovaicon-instagram', 'auntri' ),
							'link' 				=> [ 'url' => 'https://instagram.com' ],
						],
	
					],
					'title_field' => '{{{ list_title }}}',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Background::get_type(),
				[
					'name' => 'team_background',
					'label' => esc_html__( 'Background', 'auntri' ),
					'types' => [ 'classic', 'gradient', 'video' ],
					'selector' => '{{WRAPPER}} .ova-team .item-team',
					'separator' => 'before',
					'condition' => [
						'template' => 'template4'
					]
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_info_style',
			[
				'label' 	=> esc_html__( 'Info', 'auntri' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);

        	$this->add_control(
	            'info_background_normal',
	            [
	                'label' 	=> esc_html__( 'Background Color', 'auntri' ),
	                'type' 		=> Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .ova-team .item-team .info' => 'background-color: {{VALUE}};',
	                    '{{WRAPPER}} .ova-team .item-team .avatar .trapezoid' => ' border-bottom-color: {{VALUE}};',
	                ],
	            ]
	        );

	        $this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
				[
					'name' 		=> 'info_box_shadow_normal',
					'label' 	=> esc_html__( 'Box Shadow', 'auntri' ),
					'selector' 	=> '{{WRAPPER}} .ova-team .item-team .info',
				]
			);		  

			$this->add_responsive_control(
	            'info_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team .item-team .info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                 
	                ],
	            ]
	        );

		$this->end_controls_section();

		/* Begin Name Style */
		$this->start_controls_section(
            'name_style',
            [
                'label' => esc_html__( 'Name', 'auntri' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'name_typography',
					'selector' 	=> '{{WRAPPER}} .ova-team .item-team .info .name',
				]
			);

			$this->start_controls_tabs( 'tabs_title_style' );

				$this->start_controls_tab(
		            'tab_name_normal',
		            [
		                'label' => esc_html__( 'Normal', 'auntri' ),
		            ]
		        );

					$this->add_control(
			            'name_color_normal',
			            [
			                'label' 	=> esc_html__( 'Color', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team .item-team .info .name' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

				$this->end_controls_tab();

				$this->start_controls_tab(
		            'tab_name_hover',
		            [
		                'label' => esc_html__( 'Hover', 'auntri' ),
		            ]
		        );

					$this->add_control(
			            'name_color_hover',
			            [
			                'label' 	=> esc_html__( 'Color', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team:hover .item-team .info .name' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

				$this->end_controls_tab();
			$this->end_controls_tabs();

	        $this->add_responsive_control(
	            'name_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team .item-team .info .name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();

        /* Begin Job Style */
		$this->start_controls_section(
            'job_style',
            [
                'label' => esc_html__( 'Job', 'auntri' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'job_typography',
					'selector' 	=> '{{WRAPPER}} .ova-team .item-team .info .job',
				]
			);

			$this->start_controls_tabs( 'tabs_job_style' );

				$this->start_controls_tab(
		            'tab_job_normal',
		            [
		                'label' => esc_html__( 'Normal', 'auntri' ),
		            ]
		        );

					$this->add_control(
			            'job_color_normal',
			            [
			                'label' 	=> esc_html__( 'Color', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team .item-team .info .job' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

			        $this->add_control(
			            'job_bgcolor_normal',
			            [
			                'label' 	=> esc_html__( 'Background Color', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team .item-team .info .job' => 'background-color: {{VALUE}}',
			                ],
			                'condition' => [
			                	'template' => 'template4'
			                ]
			            ]
			        );

				$this->end_controls_tab();

				$this->start_controls_tab(
		            'tab_job_hover',
		            [
		                'label' => esc_html__( 'Hover', 'auntri' ),
		            ]
		        );

					$this->add_control(
			            'job_color_hover',
			            [
			                'label' 	=> esc_html__( 'Color', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team:hover .item-team .info .job' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

				$this->end_controls_tab();
			$this->end_controls_tabs();

	        $this->add_responsive_control(
	            'job_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team .item-team .info .job' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();

        /* Begin Description Style */
		$this->start_controls_section(
            'description_style',
            [
                'label' => esc_html__( 'Description', 'auntri' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
                'condition' => [
                	'template' => 'template5'
                ]
            ]
        );

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'description_typography',
					'selector' 	=> '{{WRAPPER}} .ova-team .item-team .info .description',
				]
			);

			$this->start_controls_tabs( 'tabs_description_style' );

				$this->start_controls_tab(
		            'tab_description_normal',
		            [
		                'label' => esc_html__( 'Normal', 'auntri' ),
		            ]
		        );

					$this->add_control(
			            'description_color_normal',
			            [
			                'label' 	=> esc_html__( 'Color', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team .item-team .info .description' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

				$this->end_controls_tab();

				$this->start_controls_tab(
		            'tab_description_hover',
		            [
		                'label' => esc_html__( 'Hover', 'auntri' ),
		            ]
		        );

					$this->add_control(
			            'description_color_hover',
			            [
			                'label' 	=> esc_html__( 'Color', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team:hover .item-team .info .description' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

				$this->end_controls_tab();
			$this->end_controls_tabs();

	        $this->add_responsive_control(
	            'description_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team .item-team .info .description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();

        /* Begin Social Style */
		$this->start_controls_section(
            'social_style',
            [
                'label' => esc_html__( 'Social', 'auntri' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

        	$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'social_typography',
					'selector' 	=> '{{WRAPPER}} .ova-team .item-team .social-list .social i',
				]
			);

			$this->add_control(
	            'social_background',
	            [
	                'label' 	=> esc_html__( 'Background', 'auntri' ),
	                'type' 		=> Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .ova-team .item-team .social-list, {{WRAPPER}} .ova-team .item-team .info .share-button' => 'background-color: {{VALUE}};',
	                ],
	            ]
	        );

        	$this->start_controls_tabs( 'tabs_social_style' );
				
				$this->start_controls_tab(
		            'tab_social_normal',
		            [
		                'label' => esc_html__( 'Normal', 'auntri' ),
		            ]
		        );

		        	$this->add_control(
			            'social_color_normal',
			            [
			                'label' 	=> esc_html__( 'Color', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team .item-team .social-list .social i' => 'color: {{VALUE}};',
			                ],
			            ]
			        );

		        	$this->add_control(
			            'social_background_normal',
			            [
			                'label' 	=> esc_html__( 'Background', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team .item-team .social-list .social' => 'background-color: {{VALUE}};',
			                ],
			            ]
			        );

		        $this->end_controls_tab();

		        $this->start_controls_tab(
		            'tab_social_hover',
		            [
		                'label' => esc_html__( 'Hover', 'auntri' ),
		            ]
		        );

		        	$this->add_control(
			            'social_color_hover',
			            [
			                'label' 	=> esc_html__( 'Color', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team .item-team .social-list .social:hover i' => 'color: {{VALUE}};',
			                ],
			            ]
			        );

		        	$this->add_control(
			            'social_background_hover',
			            [
			                'label' 	=> esc_html__( 'Background', 'auntri' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team .item-team .social-list .social:hover' => 'background-color: {{VALUE}} !important;',
			                ],
			            ]
			        );

		        $this->end_controls_tab();
			$this->end_controls_tabs();

			$this->add_responsive_control(
				'social_size',
				[
					'label' 	=> esc_html__( 'Size', 'auntri' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
						],
					],
					'size_units' 	=> [ 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-team .item-team .social-list .social' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};min-width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'icon_social_size',
				[
					'label' 	=> esc_html__( 'Icon Size', 'auntri' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
						],
					],
					'size_units' 	=> [ 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-team .item-team .social-list .social i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

	        $this->add_control(
	            'social_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border Radius', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team .item-team .social-list .social' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_responsive_control(
	            'social_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'auntri' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team .item-team .social-list .social' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();
		
		$template = $settings['template'];

		?> 

		<div class="ova-team">

			<?php ob_start();

				if( $template === 'template1' ) {
		        		get_template_part( 'template-parts/elementor/item-team-1', null, $settings );

			        } elseif( $template === 'template2' ) {
			        	get_template_part( 'template-parts/elementor/item-team-2', null, $settings );

			        } elseif( $template === 'template3' ) {
			        	get_template_part( 'template-parts/elementor/item-team-3', null, $settings );
			        	
			        } elseif( $template === 'template4' ) {
			        	get_template_part( 'template-parts/elementor/item-team-4', null, $settings );

			        } elseif( $template === 'template5' ) {
			        	get_template_part( 'template-parts/elementor/item-team-5', null, $settings );

			        } else {
			        	get_template_part( 'template-parts/elementor/item-team-1', null, $settings );
			    } 

			echo ob_get_clean(); ?>

		</div>

	    <?php
		
	}

	
}
$widgets_manager->register( new Auntri_Elementor_Team() );