<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Color;
use Elementor\Utils;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Auntri_Elementor_Testimonial extends Widget_Base {

	public function get_name() {
		return 'auntri_elementor_testimonial';
	}

	public function get_title() {
		return esc_html__( 'Testimonial', 'auntri' );
	}

	public function get_icon() {
		return 'eicon-testimonial';
	}

	public function get_categories() {
		return [ 'auntri' ];
	}

	public function get_script_depends() {
		// Carousel
		wp_enqueue_style( 'owl-carousel', get_template_directory_uri().'/assets/libs/carousel/assets/owl.carousel.min.css' );
		wp_enqueue_script( 'owl-carousel', get_template_directory_uri().'/assets/libs/carousel/owl.carousel.min.js', array('jquery'), false, true );
		return [ 'auntri-elementor-testimonial' ];
	}

	protected function register_controls() {


		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'auntri' ),
			]
		);

			$this->add_control(
				'version',
				[
					'label' 	=> esc_html__( 'Version', 'auntri' ),
					'type' 		=> Controls_Manager::SELECT,
					'default' 	=> 'version_1',
					'options' 	=> [
						'version_1' => esc_html__( 'Version 1', 'auntri' ),
						'version_2' => esc_html__( 'Version 2', 'auntri' ),
						'version_3' => esc_html__( 'Version 3', 'auntri' ),
						
					]
				]
			);

			$this->add_control(
				'icon_quote_v1',
				[
					'label' 	=> esc_html__( 'Icon', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::ICONS,
					'default' 	=> [
						'value' 	=> 'fas fa-quote-left',
						'library' 	=> 'all',	
					],
					'condition' => [
						'version' => 'version_1',
					]
				]
			);

			$this->add_control(
				'icon_quote_v2',
				[
					'label' 	=> esc_html__( 'Icon', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::ICONS,
					'default' 	=> [
						'value' 	=> 'flaticon flaticon-quotation',
						'library' 	=> 'all',	
					],
					'condition' => [
						'version' => 'version_2',
					]
				]
			);

			$this->add_control(
				'icon_quote_v3',
				[
					'label' 	=> esc_html__( 'Icon', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::ICONS,
					'default' 	=> [
						'value' 	=> 'fas fa-quote-left',
						'library' 	=> 'all',	
					],
					'condition' => [
						'version' => 'version_3',
					]
				]
			);


			$repeater = new \Elementor\Repeater();

				$repeater->add_control(
					'name_author',
					[
						'label'   => esc_html__( 'Author Name', 'auntri' ),
						'type'    => \Elementor\Controls_Manager::TEXT,
					]
				);

				$repeater->add_control(
					'job',
					[
						'label'   => esc_html__( 'Job', 'auntri' ),
						'type'    => \Elementor\Controls_Manager::TEXT,

					]
				);

				$repeater->add_control(
					'image_author',
					[
						'label'   => esc_html__( 'Author Image', 'auntri' ),
						'type'    => \Elementor\Controls_Manager::MEDIA,
						'default' => [
							'url' => Utils::get_placeholder_image_src(),
						],
					]
				);

				$repeater->add_control(
					'testimonial',
					[
						'label'   => esc_html__( 'Testimonial ', 'auntri' ),
						'type'    => \Elementor\Controls_Manager::TEXTAREA,
						'default' => esc_html__( '"Sed ullamcorper morbi tincidunt or massa eget egestas purus. Non nisi est sit amet facilisis magna etiam."', 'auntri' ),
					]
				);

				$repeater->add_control(
					'rating',
					[
						'label' 	=> esc_html__( 'Rating', 'auntri' ),
						'type' 		=> Controls_Manager::NUMBER,
						'min' 		=> 0,
						'max' 		=> 10,
						'step' 		=> 0.1,
						'default' 	=> 5,
						'dynamic' 	=> [
							'active' => true,
						],
					]
				);
		
				$repeater->add_control(
					'star_style',
					[
						'label' 	=> esc_html__( 'Icon', 'auntri' ),
						'type' 		=> Controls_Manager::SELECT,
						'options' 	=> [
							'star_fontawesome' 	=> 'Font Awesome',
							'star_unicode' 		=> 'Unicode',
						],
						'default' 		=> 'star_fontawesome',
						'render_type' 	=> 'template',
						'prefix_class'	=> 'elementor--star-style-',
						'separator' 	=> 'before',
					]
				);
		
				$repeater->add_control(
					'unmarked_star_style',
					[
						'label' 	=> esc_html__( 'Unmarked Style', 'auntri' ),
						'type' 		=> Controls_Manager::CHOOSE,
						'options' 	=> [
							'solid' 	=> [
								'title' 	=> esc_html__( 'Solid', 'auntri' ),
								'icon' 		=> 'eicon-star',
							],
							'outline' 	=> [
								'title' 	=> esc_html__( 'Outline', 'auntri' ),
								'icon' 		=> 'eicon-star-o',
							],
						],
						'default' => 'outline',
					]
				);

				$this->add_control(
					'tab_item',
					[
						'label'       => esc_html__( 'Items Testimonial', 'auntri' ),
						'type'        => Controls_Manager::REPEATER,
						'fields'      => $repeater->get_controls(),
						'default' => [
							[
								'name_author' 	=> esc_html__('Donald Hardson', 'auntri'),
								'job' 			=> esc_html__('CEO - CO Founder', 'auntri'),
								'testimonial' 	=> esc_html__('Leverage agile frameworks to provide a robust synopsis for high level overviews. Iterative approaches to corporate strategy data foster to collaborative thinking.', 'auntri'),
							],
							[
								'name_author' 	=> esc_html__('Christine Eve', 'auntri'),
								'job' 	=> esc_html__('CEO - CO Founder', 'auntri'),
								'testimonial' 	=> esc_html__('Leverage agile frameworks to provide a robust synopsis for high level overviews. Iterative approaches to corporate strategy data foster to collaborative thinking.', 'auntri'),
							],
							[
								'name_author' 	=> esc_html__('Aleesha Brown', 'auntri'),
								'job' 			=> esc_html__('CEO - CO Founder', 'auntri'),
								'testimonial' 	=> esc_html__('Leverage agile frameworks to provide a robust synopsis for high level overviews. Iterative approaches to corporate strategy data foster to collaborative thinking.', 'auntri'),
							],
						],
						'title_field' 	=> '{{{ name_author }}}',
						'condition' 	=> [
							'version' 	=> 'version_1'
						]
					]
				);

				$this->add_control(
					'tab_item_v2',
					[
						'label'       => esc_html__( 'Items Testimonial', 'auntri' ),
						'type'        => Controls_Manager::REPEATER,
						'fields'      => $repeater->get_controls(),
						'default' => [
							[
								'name_author' 	=> esc_html__('Jon D. William', 'auntri'),
								'job' 			=> esc_html__('CO Founder', 'auntri'),
								'testimonial' 	=> esc_html__('Promptitude is not only a duty, it is favorable to fortune, reputation, influence, a little attention and energy will form the habit, so as to make it easy and delightful.', 'auntri'),
							],
							[
								'name_author' 	=> esc_html__(' Aleesha Brown', 'auntri'),
								'job' 			=> esc_html__('CO Founder', 'auntri'),
								'testimonial' 	=> esc_html__('Promptitude is not only a duty, it is favorable to fortune, reputation, influence, a little attention and energy will form the habit, so as to make it easy and delightful.', 'auntri'),
							],
							[
								'name_author' 	=> esc_html__('Christine Eve', 'auntri'),
								'job' 			=> esc_html__('CEO - CO Founder', 'auntri'),
								'testimonial' 	=> esc_html__('Promptitude is not only a duty, it is favorable to fortune, reputation, influence, a little attention and energy will form the habit, so as to make it easy and delightful.', 'auntri'),
							],
						],
						'title_field' 	=> '{{{ name_author }}}',
						'condition' 	=> [
							'version' 	=> 'version_2'
						]
					]
				);

				$this->add_control(
					'tab_item_v3',
					[
						'label'       => esc_html__( 'Items Testimonial', 'auntri' ),
						'type'        => Controls_Manager::REPEATER,
						'fields'      => $repeater->get_controls(),
						'default' => [
							[
								'name_author' 	=> esc_html__('Aleesha Brown', 'auntri'),
								'job' 			=> esc_html__('Doctor', 'auntri'),
								'testimonial' 	=> esc_html__('Installation went very smoothly; there were no hidden costs & all paperwork was completed seamlessly. The design fit very well with the house. We recommend energo.', 'auntri'),
							],
							[
								'name_author' 	=> esc_html__('Jon D. William', 'auntri'),
								'job' 			=> esc_html__('Doctor', 'auntri'),
								'testimonial' 	=> esc_html__('Installation went very smoothly; there were no hidden costs & all paperwork was completed seamlessly. The design fit very well with the house. We recommend energo.', 'auntri'),
							],
							[
								'name_author' 	=> esc_html__('Christine Eve', 'auntri'),
								'job' 			=> esc_html__('CEO - CO Founder', 'auntri'),
								'testimonial' 	=> esc_html__('Installation went very smoothly; there were no hidden costs & all paperwork was completed seamlessly. The design fit very well with the house. We recommend energo.', 'auntri'),
							],
						],
						'title_field' 	=> '{{{ name_author }}}',
						'condition' 	=> [
							'version' 	=> 'version_3'
						]
					]
				);
			

		$this->end_controls_section();

		/*****************  END SECTION CONTENT ******************/


		/*****************************************************************
						START SECTION ADDITIONAL
		******************************************************************/

		$this->start_controls_section(
			'section_additional_options',
			[
				'label' => esc_html__( 'Additional Options', 'auntri' ),
			]
		);


		/***************************  VERSION 1 ***********************/
			$this->add_control(
				'margin_items',
				[
					'label'   => esc_html__( 'Margin Right Items', 'auntri' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 30,
				]
				
			);

			$this->add_control(
				'item_number_v1',
				[
					'label'       => esc_html__( 'Item Number', 'auntri' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Number Item', 'auntri' ),
					'default'     => 1.8,
					'condition'   => [
						'version' => 'version_1'
					],
				]
			);

			$this->add_control(
				'item_number_v2',
				[
					'label'       => esc_html__( 'Item Number', 'auntri' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Number Item', 'auntri' ),
					'default'     => 1.9,
					'condition'   => [
						'version' => 'version_2'
					],
				]
			);

			$this->add_control(
				'item_number_v3',
				[
					'label'       => esc_html__( 'Item Number', 'auntri' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Number Item', 'auntri' ),
					'default'     => 1,
					'condition'   => [
						'version' => 'version_3'
					],
				]
			);
	

			$this->add_control(
				'slides_to_scroll',
				[
					'label'       => esc_html__( 'Slides to Scroll', 'auntri' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Set how many slides are scrolled per swipe.', 'auntri' ),
					'default'     => 1,
				]
			);

			$this->add_control(
				'pause_on_hover',
				[
					'label'   => esc_html__( 'Pause on Hover', 'auntri' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'auntri' ),
						'no'  => esc_html__( 'No', 'auntri' ),
					],
					'frontend_available' => true,
				]
			);


			$this->add_control(
				'infinite',
				[
					'label'   => esc_html__( 'Infinite Loop', 'auntri' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'auntri' ),
						'no'  => esc_html__( 'No', 'auntri' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay',
				[
					'label'   => esc_html__( 'Autoplay', 'auntri' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'auntri' ),
						'no'  => esc_html__( 'No', 'auntri' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay_speed',
				[
					'label'     => esc_html__( 'Autoplay Speed', 'auntri' ),
					'type'      => Controls_Manager::NUMBER,
					'default'   => 3000,
					'step'      => 500,
					'condition' => [
						'autoplay' => 'yes',
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'smartspeed',
				[
					'label'   => esc_html__( 'Smart Speed', 'auntri' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 500,
				]
			);

			$this->add_control(
				'nav_control',
				[
					'label'   => esc_html__( 'Show Nav', 'auntri' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'auntri' ),
						'no'  => esc_html__( 'No', 'auntri' ),
					],
					'frontend_available' => true,
					'condition' => [
						'version' => 'version_3',
					]
				]
			);

			$this->add_control(
				'dot_control',
				[
					'label'   => esc_html__( 'Show Dots(Mobile)', 'auntri' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'auntri' ),
						'no'  => esc_html__( 'No', 'auntri' ),
					],
					'frontend_available' => true,
				]
			);

		$this->end_controls_section();

		/****************************  END SECTION ADDITIONAL *********************/

		/*************  SECTION NAME JOB. *******************/
		$this->start_controls_section(
			'section_general',
			[
				'label' => esc_html__( 'General', 'auntri' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'quote_color',
				[
					'label'     => esc_html__( 'Quote Job', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial.version_1 .item .client_info .info .client .icon-quote' => 'color : {{VALUE}};',
						'{{WRAPPER}} .ova-testimonial.version_3 .item .client_info .quote-box .icon-quote i' => 'color : {{VALUE}};',
						
					],
					'condition' => [
						'version!' => 'version_2' 
					]
				]
			);

			$this->add_responsive_control(
				'_quote_width',
				[
					'label' 	=> esc_html__( 'Quote Width', 'auntri' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' 	=> [
						'px' => [
							'min' => 10,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial.version_1 .item .client_info .info .client .icon-quote' 	=> 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}}',
					],
						'condition' => [
						'version' 	=> 'version_1' 
					]
				]
			);


			$this->add_responsive_control(
				'icon_quote_size',
				[
					'label' 	=> esc_html__( 'Size Icon', 'auntri' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' 	=> [
						'px' 	=> [
							'min' => 10,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial.version_1 .item .client_info .info .client .icon-quote i' 	=> 'font-size: {{SIZE}}{{UNIT}}',
						'{{WRAPPER}} .ova-testimonial.version_3 .item .client_info .quote-box .icon-quote i' 	=> 'font-size: {{SIZE}}{{UNIT}}',
					],
						'condition' => [
						'version!' 	=> 'version_2' 
					]
				]
			);

			$this->add_control(
				'quote_background_color',
				[
					'label'     => esc_html__( 'Quote Background', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial.version_1 .item .client_info .info .client .icon-quote' => 'background-color : {{VALUE}};',
						
					],
					'condition' => [
						'version' => 'version_1' 
					]
				]
			);

			$this->add_control(
				'quote_background_secondary_color',
				[
					'label'     => esc_html__( 'Quote Secondary Background', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial.version_1 .item .client_info .info .client .icon-quote:after' => 'background : {{VALUE}};',
						
					],
					'condition' => [
						'version' => 'version_1' 
					]
				]
			);

			$this->add_control(
				'dot_color',
				[
					'label'     => esc_html__( 'Dot Color', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial.version_2 .slide-testimonials .owl-dots .owl-dot span' => 'background : {{VALUE}};',
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-dots .owl-dot span' => 'background : {{VALUE}};',
						
					],
				]
			);

			$this->add_control(
				'dot_active_color',
				[
					'label'     => esc_html__( 'Dot Active Color', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial.version_2 .slide-testimonials .owl-dots .owl-dot.active span' => 'background : {{VALUE}};',
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-dots .owl-dot.active span' => 'background : {{VALUE}};',
						
					],
				]
			);



			$this->add_control(
				'general_background_1_color',
				[
					'label'     => esc_html__( 'Background Primary', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial.version_1 .slide-testimonials .owl-item .client_info:before' => 'background-color : {{VALUE}};',
						
					],
					'condition' => [
						'version' => 'version_1' 
					]
				]
			);

			$this->add_control(
				'general_background_1_opacity',
				[
					'label' => esc_html__( ' Background Primary Opacity', 'auntri' ),
					'type'  => Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'max' => 1,
							'step' => 0.01,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial.version_1 .slide-testimonials .owl-item .client_info:before' => 'opacity: {{SIZE}};',
					],
					'condition' => [
						'version' => 'version_1' 
					]
				]
			);

			$this->add_control(
				'general_background_2_color',
				[
					'label'     => esc_html__( 'Background Secondary', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial.version_1 .slide-testimonials .owl-item .client_info:after' => 'background-color : {{VALUE}};',
						
					],
					'condition' => [
						'version' => 'version_1' 
					]
				]
			);

			$this->add_control(
				'general_background_2_opacity',
				[
					'label' => esc_html__( ' Background Secondary Opacity', 'auntri' ),
					'type'  => Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'max' => 1,
							'step' => 0.01,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial.version_1 .slide-testimonials .owl-item .client_info:after' => 'opacity: {{SIZE}};',
					],
					'condition' => [
						'version' => 'version_1' 
					]
				]
			);

			$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
				[
					'name' 		=> 'border_item_Version_2',
					'label' 	=> esc_html__( 'Border', 'auntri' ),
					'selector' 	=> '{{WRAPPER}} .ova-testimonial.version_2 .slide-testimonials .owl-stage-outer .owl-stage .active .client_info',
					'condition' => [
						'version' => 'version_2' 
					]
				]
			);


			$this->add_control(
				'image_background_color',
				[
					'label'     => esc_html__( 'Background Image ', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial.version_2 .slide-testimonials .client_info .info .client:after' => 'background-color : {{VALUE}};',
						
					],
					'condition' => [
						'version' => 'version_2' 
					]
				]
			);

			$this->add_control(
				'general_background_image_v3',
				[
					'label'     => esc_html__( 'Background Image ', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial.version_3 .item .client_info .info .client:after' => 'background-color : {{VALUE}};',
						
					],
					'condition' => [
						'version' => 'version_3' 
					]
				]
			);

		$this->end_controls_section();
		###############  end section job  ###############

		/*************  SECTION Item. *******************/
		$this->start_controls_section(
			'section_item',
			[
				'label' => esc_html__( 'Item', 'auntri' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_responsive_control(
				'section_item_padding',
				[
					'label'      => esc_html__( 'Padding', 'auntri' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial.version_1 .item .client_info' 					=> 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						'{{WRAPPER}} .ova-testimonial.version_2 .slide-testimonials .client_info' 		=> 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						'{{WRAPPER}} .ova-testimonial.version_3 .slide-testimonials .owl-stage-outer' 	=> 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

					],
				]
			);

		$this->end_controls_section();
		###############  end section Item V1  ###############

		/*************  SECTION content testimonial  *******************/
		$this->start_controls_section(
			'section_content_testimonial',
			[
				'label' => esc_html__( 'Content Testimonial', 'auntri' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name'     => 'content_testimonial_typography',
					'selector' => '{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info p.evaluate',
					'scheme'   => Typography::TYPOGRAPHY_1,
				]
			);

			$this->add_control(
				'content_color',
				[
					'label'     => esc_html__( 'Color', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info p.evaluate' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'content_margin',
				[
					'label'      => esc_html__( 'Margin', 'auntri' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info p.evaluate' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'content_padding',
				[
					'label'      => esc_html__( 'Padding', 'auntri' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info p.evaluate' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		###############  end section content testimonial  ###############


		/*************  SECTION NAME AUTHOR. *******************/
		$this->start_controls_section(
			'section_author_name',
			[
				'label' => esc_html__( 'Author Name', 'auntri' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name'     => 'author_name_typography',
					'selector' => '{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .name-job .name',
					'scheme'   => Typography::TYPOGRAPHY_1,
				]
			);

			$this->add_control(
				'author_name_color',
				[
					'label'     => esc_html__( 'Color Author', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'
						{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .name-job .name' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'author_name_margin',
				[
					'label'      => esc_html__( 'Margin', 'auntri' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .name-job .name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'author_name_padding',
				[
					'label'      => esc_html__( 'Padding', 'auntri' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .name-job .name' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		###############  end section author  ###############


		/*************  SECTION NAME JOB. *******************/
		$this->start_controls_section(
			'section_job',
			[
				'label' => esc_html__( 'Job', 'auntri' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name'     => 'job_typography',
					'selector' => '{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .name-job .job',
					'scheme'   => Typography::TYPOGRAPHY_1,
				]
			);

			$this->add_control(
				'job_color',
				[
					'label'     => esc_html__( 'Color Job', 'auntri' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'
						{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .name-job .job' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'job_margin',
				[
					'label'      => esc_html__( 'Margin', 'auntri' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .name-job .job' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'job_padding',
				[
					'label'      => esc_html__( 'Padding', 'auntri' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .name-job .job' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);


		$this->end_controls_section();
		###############  end section job  ###############
		
		$this->start_controls_section(
			'section_stars_style',
			[
				'label' => esc_html__( 'Rating Stars', 'auntri' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
				
			]
		);

			$this->add_responsive_control(
				'icon_size',
				[
					'label' 	=> esc_html__( 'Size', 'auntri' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' 	=> [
						'px' 	=> [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .client_info .info .ova-rating .elementor-star-rating' => 'font-size: {{SIZE}}{{UNIT}}',
					],
				]
			);

			$this->add_responsive_control(
				'icon_space',
				[
					'label' 	=> esc_html__( 'Spacing', 'auntri' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' 	=> [
						'px' 	=> [
							'min' => 0,
							'max' => 50,
						],
					],
					'selectors' => [
						'body:not(.rtl) {{WRAPPER}} .elementor-star-rating i:not(:last-of-type)' => 'margin-right: {{SIZE}}{{UNIT}}',
						'body.rtl {{WRAPPER}} .elementor-star-rating i:not(:last-of-type)' => 'margin-left: {{SIZE}}{{UNIT}}',
					],
				]
			);

			$this->add_control(
				'stars_color',
				[
					'label' 	=> esc_html__( 'Color', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-item .item .client_info .ova-rating .elementor-star-rating i::before' => 'color: {{VALUE}}',
						
					],
					'separator' => 'before',
				]
			);

			$this->add_control(
				'stars_unmarked_color',
				[
					'label' 	=> esc_html__( 'Unmarked Color', 'auntri' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .elementor-star-rating i' => 'color: {{VALUE}}',
					],
				]
			);

		$this->end_controls_section();

		/* Begin Nav Arrow Style */
		$this->start_controls_section(
            'nav_style',
            [
                'label' 	=> esc_html__( 'Arrows Control', 'auntri' ),
                'tab' 		=> Controls_Manager::TAB_STYLE,
                'condition' => [
                	'version' 		=> 	[
                		'version_3',
                	]
                ]
            ]
        );
            
            $this->add_responsive_control(
				'size_nav_icon',
				[
					'label' 		=> esc_html__( 'Icon Size', 'auntri' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px'],
					'range' 		=> [
						'px' 		=> [
							'min' 		=> 0,
							'max' 		=> 30,
							'step' 		=> 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial.version_3 .slide-testimonials .owl-nav button i' 	=> 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'nav_width_height',
				[
					'label' 	=> esc_html__( 'Width', 'auntri' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' 	=> [
						'px' 	=> [
							'min' => 10,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial.version_3 .slide-testimonials .owl-nav button ' 	=> 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}}',
					],
						
				]
			);
			
			$this->add_responsive_control(
				'arrow_border_radius',
				[
					'label'      => esc_html__( 'Border Radius', 'auntri' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial.version_3 .slide-testimonials .owl-nav button' 	=> 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->start_controls_tabs( 'tabs_nav_style' );
				
				$this->start_controls_tab(
		            'tab_nav_normal',
		            [
		                'label' => esc_html__( 'Normal', 'auntri' ),
		            ]
		        );

		            $this->add_control(
						'color_nav_icon',
						[
							'label' 	=> esc_html__( 'Color', 'auntri' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-testimonial.version_3 .slide-testimonials .owl-nav button i' 	=> 'color : {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'color_nav_bg_prev',
						[
							'label' 	=> esc_html__( ' Background Prev', 'auntri' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-testimonial.version_3 .slide-testimonials .owl-nav button.owl-prev' 	=> 'background-color : {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'color_nav_bg_next',
						[
							'label' 	=> esc_html__( ' Background Next', 'auntri' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-testimonial.version_3 .slide-testimonials .owl-nav button.owl-next' 	=> 'background-color : {{VALUE}};',	
							],
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Border::get_type(),
						[
							'name' 		=> 'border_nav_version_v3',
							'label' 	=> esc_html__( 'Border', 'auntri' ),
							'selector' 	=> '{{WRAPPER}} .ova-testimonial.version_3 .slide-testimonials .owl-nav button',
						]
					);
					

		        $this->end_controls_tab();

		        $this->start_controls_tab(
		            'tab_icon_hover',
		            [
		                'label' => esc_html__( 'Hover', 'auntri' ),
		            ]
		        );

		            $this->add_control(
						'color_nav_icon_hover',
						[
							'label' 	=> esc_html__( 'Color Hover', 'auntri' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-testimonial.version_3 .slide-testimonials .owl-nav button:hover i' 	=> 'color : {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'color_nav_bg_hover',
						[
							'label' 	=> esc_html__( 'Background Hover', 'auntri' ),
							'type'		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-testimonial.version_3 .slide-testimonials .owl-nav button:before' => 'background-color : {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'color_nav_icon_border_hover',
						[
							'label' 	=> esc_html__( 'Border Hover', 'auntri' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-testimonial.version_3 .slide-testimonials .owl-nav button:hover ' => 'border-color : {{VALUE}};',
							],
						]
					);


		        $this->end_controls_tab();

		    $this->end_controls_tabs();

        $this->end_controls_section();
        /* End Nav Arrow Style */

        //SECTION TAB STYLE DOTS
		$this->start_controls_section(
			'section_dots',
			[
				'label' 	=> esc_html__( 'Dots', 'auntri' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
				'condition' => [
					'dot_control' => 'yes',
				],
			]
		);

			$this->add_responsive_control(
				'dots_padding',
				[
					'label'      => esc_html__( 'Padding', 'auntri' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-dots' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'dots_margrin',
				[
					'label'      => esc_html__( 'Margin', 'auntri' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-dots' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
 
			$this->start_controls_tabs(
					'style_tabs_dots'
				);

					$this->start_controls_tab(
						'style_dots_tab',
						[
						'label' => esc_html__( 'Normal', 'auntri' ),
						]
					);

						$this->add_control(
							'style_dots',
							[
								'label' 	=> esc_html__( 'Dots', 'auntri' ),
								'type' 		=> \Elementor\Controls_Manager::HEADING,
								'separator' => 'before',
								
							]
						);

						$this->add_control(
							'dot_color_b',
							[
								'label'     => esc_html__( 'Dot Color', 'auntri' ),
								'type'      => Controls_Manager::COLOR,
								'selectors' => [
									'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-dots .owl-dot span' => 'background-color : {{VALUE}};',
									
								]
								
							]
						);

						$this->add_control(
							'dot_width',
							[
								'label' 		=> esc_html__( 'Dots Width', 'auntri' ),
								'type' 			=> Controls_Manager::SLIDER,
								'size_units' 	=> [ 'px' ],
								'range' => [
									'px' => [
										'min' 	=> 0,
										'max' 	=> 20,
										'step' 	=> 1,
									]
								],
								'selectors' 	=> [
									'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-dots .owl-dot span' => 'width: {{SIZE}}{{UNIT}};',
								],
							]
						);

						$this->add_control(
							'dot_height',
							[
								'label' 		=> esc_html__( 'Dots Height', 'auntri' ),
								'type' 			=> Controls_Manager::SLIDER,
								'size_units' 	=> [ 'px' ],
								'range' => [
									'px' => [
										'min' 	=> 0,
										'max' 	=> 10,
										'step' 	=> 1,
									]
								],
								'selectors' 	=> [
									'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-dots .owl-dot span' => 'height: {{SIZE}}{{UNIT}};',
								],
							]
						);

						$this->add_responsive_control(
							'border_radius_dot',
							array(
								'label'      => esc_html__( 'Border Radius', 'auntri' ),
								'type'       => Controls_Manager::DIMENSIONS,
								'size_units' => array( 'px', '%' ),
								'selectors'  => array(
									'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-dots .owl-dot span' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
								),
							)
						);

						$this->add_responsive_control(
							'item_dot_margrin',
							[
								'label'      => esc_html__( 'Margin', 'auntri' ),
								'type'       => Controls_Manager::DIMENSIONS,
								'size_units' => [ 'px', 'em', '%' ],
								'selectors'  => [
									'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-dots .owl-dot span' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
								],
							]
						);

					$this->end_controls_tab();

					$this->start_controls_tab(
						'style_dots_active_tab',
						[
						'label' => esc_html__( 'Active', 'auntri' ),
						]
					);
						$this->add_control(
							'style_dot_active',
							[
								'label' 	=> esc_html__( 'Dots Active', 'auntri' ),
								'type' 		=> \Elementor\Controls_Manager::HEADING,
								'separator' => 'before',
								
							]
						);

						$this->add_control(
							'dot_color_active',
							[
								'label'     => esc_html__( 'Dot Color Active', 'auntri' ),
								'type'      => Controls_Manager::COLOR,
								'selectors' => [
									'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-dots .owl-dot.active span' => 'background-color : {{VALUE}};',
									
								],
								
							]
						);

						$this->add_control(
							'dot_width_active',
							[
								'label' 		=> esc_html__( 'Dots width active', 'auntri' ),
								'type' 			=> Controls_Manager::SLIDER,
								'size_units' 	=> [ 'px' ],
								'range' => [
									'px' => [
										'min' 	=> 0,
										'max' 	=> 30,
										'step' 	=> 1,
									]
								],
								'selectors' 	=> [
									'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-dots .owl-dot.active span' => 'width: {{SIZE}}{{UNIT}};',
								],
							]
						);
					$this->end_controls_tab();
				$this->end_controls_tabs();


		$this->end_controls_section();
		//END SECTION TAB STYLE DOTS
	}

	protected function get_rating($rating) {

		$settings 		= $this->get_settings();
		$rating_scale 	= 5;

		return [ $rating, $rating_scale ];
	}

	protected function render_stars( $icon, $rating ) {
		$rating_data 	= $this->get_rating($rating);
		$rating 		= (float) $rating_data[0];
		$floored_rating = floor( $rating );
		$stars_html 	= '';

		for ( $stars = 1.0; $stars <= $rating_data[1]; $stars++ ) {
			if ( $stars <= $floored_rating ) {
				$stars_html .= '<i class="elementor-star-full">' . $icon . '</i>';
			} elseif ( $floored_rating + 1 === $stars && $rating !== $floored_rating ) {
				$stars_html .= '<i class="elementor-star-' . ( $rating - $floored_rating ) * 10 . '">' . $icon . '</i>';
			} else {
				$stars_html .= '<i class="elementor-star-empty">' . $icon . '</i>';
			}
		}

		return $stars_html;
	}

	protected function render() {

		$settings = $this->get_settings();
		$version  = $settings['version'];

		$data_options['slideBy']            = $settings['slides_to_scroll'];
		$data_options['margin']             = $settings['margin_items'];
		$data_options['autoplayHoverPause'] = $settings['pause_on_hover'] === 'yes' ? true : false;
		$data_options['loop']               = $settings['infinite'] === 'yes' ? true : false;
		$data_options['autoplay']           = $settings['autoplay'] === 'yes' ? true : false;
		$data_options['autoplayTimeout']    = $settings['autoplay_speed'];
		$data_options['smartSpeed']         = $settings['smartspeed'];
		$data_options['dots']               = $settings['dot_control'] === 'yes' ? true : false;
		$data_options['rtl']				= is_rtl() ? true: false;

		if( $version == 'version_1' ) {
			$tab_item 					= $settings['tab_item'];
			$icon_quote 				= $settings['icon_quote_v1'];
			$data_options['items']      = $settings['item_number_v1'];
			$data_options['navCon']     = ".testimonial_version_1 .custom-nav";

		}elseif( $version == 'version_2' ) {
			
			$tab_item 					= $settings['tab_item_v2'];
			$icon_quote 				= $settings['icon_quote_v2'];
			$data_options['items']      = $settings['item_number_v2'];
			$data_options['navCon']		= false;

		} elseif( $version == 'version_3' ) {
			$tab_item 					= $settings['tab_item_v3'];
			$icon_quote 				= $settings['icon_quote_v3'];
			$data_options['items']      = $settings['item_number_v3'];
			$data_options['nav']       	= $settings['nav_control'] === 'yes' ? true : false;
			$data_options['navCon']		= false;
		}	

		?>

		

			<div class="ova-testimonial <?php echo esc_attr($version); ?>">

					<div class="slide-testimonials owl-carousel owl-theme testimonial-<?php echo esc_attr($version); ?> " data-options="<?php echo esc_attr(json_encode($data_options)) ?>">
						<?php if(!empty($tab_item)) : foreach ($tab_item as $item) : ?>
							<div class="item">
								<div class="client_info">

								<?php if($version == 'version_1'): ?>
									<div class="decor-geometry"></div>
									<div class="info">

										<div class="client">
											<?php if( $item['image_author'] != '' ) { ?>
												<?php $alt = isset($item['name_author']) && $item['name_author'] ? $item['name_author'] : esc_html__( 'testimonial','auntri' ); ?>
												<img src="<?php echo esc_attr($item['image_author']['url']) ?>" alt="<?php echo esc_attr( $alt ); ?>" >
											<?php } ?>

											
											<?php if( $icon_quote['value']){ ?>
												<div class="icon-quote">
										   			<?php 
												        \Elementor\Icons_Manager::render_icon( $icon_quote, [ 'aria-hidden' => 'true' ] );
												    ?>
										   		</div>
									   		<?php } ?>
											
										</div>

										<div class="name-job">
											
											<!-- rating -->
											<?php 
												$icon = '&#xE934;';
												$rating_data = $this->get_rating($item['rating']);
												$textual_rating = $rating_data[0] . '/' . $rating_data[1];
												$rating = (float) $item['rating'];
												$unmarked_star_style = $item['unmarked_star_style'];
												$star_style = $item['star_style'];
												
												if ( 'star_fontawesome' === $star_style ) {
													if ( 'outline' === $unmarked_star_style ) {
														$icon = '&#xE933;';
													}
												} elseif ( 'star_unicode' === $star_style ) {
													$icon = '&#9733;';
										
													if ( 'outline' === $unmarked_star_style ) {
														$icon = '&#9734;';
													}
												}

												$stars_element = '<div class="elementor-star-rating" title="'.$textual_rating.'">' . $this->render_stars( $icon, $item['rating'] ) . ' </div>';
												
												?>
												<?php if($rating != 0) : ?>
													<div class="ova-rating <?php echo esc_html( $star_style ); ?>">
														<?php print_r ( $stars_element ); ?>
													</div>
												<?php endif; ?>
											
												<?php
											?>
											<!-- end rating -->

											<?php if( $item['name_author'] != '' ) { ?>
												<p class="name second_font">
													<?php echo esc_html($item['name_author']) ?>
												</p>
											<?php } ?>

											<?php if( $item['job'] != '' ) { ?>
												<p class="job">
													<?php echo esc_html($item['job']) ?>
												</p>
											<?php } ?>
										</div>
									</div>
									<!-- end info -->
								<?php endif; ?>

								<?php if($version == 'version_2'): ?>
									<div class="info">

										<div class="name-job">
											<!-- rating -->
											<?php 
												$icon = '&#xE934;';
												$rating_data = $this->get_rating($item['rating']);
												$textual_rating = $rating_data[0] . '/' . $rating_data[1];
												$rating = (float) $item['rating'];
												$unmarked_star_style = $item['unmarked_star_style'];
												$star_style = $item['star_style'];
												
												if ( 'star_fontawesome' === $star_style ) {
													if ( 'outline' === $unmarked_star_style ) {
														$icon = '&#xE933;';
													}
												} elseif ( 'star_unicode' === $star_style ) {
													$icon = '&#9733;';
										
													if ( 'outline' === $unmarked_star_style ) {
														$icon = '&#9734;';
													}
												}

												$stars_element = '<div class="elementor-star-rating" title="'.$textual_rating.'">' . $this->render_stars( $icon, $item['rating'] ) . ' </div>';
												
												?>
												<?php if($rating != 0) : ?>
													<div class="ova-rating <?php echo esc_html( $star_style ); ?>">
														<?php print_r ( $stars_element ); ?>
													</div>
												<?php endif; ?>
											
												<?php
											?>
											<!-- end rating -->

											<?php if( $item['name_author'] != '' ) { ?>
												<p class="name second_font">
													<?php echo esc_html($item['name_author']); ?>
												</p>
											<?php } ?>

											<?php if( $item['job'] != '' ) { ?>
												<p class="job">
													<?php echo esc_html($item['job']); ?>
												</p>
											<?php } ?>
										</div>
										<div class="client">
											<?php if( $item['image_author'] != '' ) { ?>
												<?php $alt = isset($item['name_author']) && $item['name_author'] ? $item['name_author'] : esc_html__( 'testimonial','auntri' ); ?>
												<img src="<?php echo esc_attr($item['image_author']['url']); ?>" alt="<?php echo esc_attr( $alt ); ?>" >
											<?php } ?>
										</div>
									</div><!-- end info -->
									<?php if( $icon_quote['value']){ ?>
										<div class="icon-quote">
											<?php 
												\Elementor\Icons_Manager::render_icon( $icon_quote, [ 'aria-hidden' => 'true' ] );
											?>
										</div>
									<?php } ?>
								<?php endif; ?>

									<?php if($version == 'version_3'): ?>
										<div class="quote-box">
										<?php if( $icon_quote['value']){ ?>
											<div class="icon-quote">
									   			<?php 
											        \Elementor\Icons_Manager::render_icon( $icon_quote, [ 'aria-hidden' => 'true' ] );
											    ?>
									   		</div>
								   		<?php } ?>
									<?php endif; ?>

									<?php if( $item['testimonial'] != '' ) : ?>
										<p class="evaluate">
											<?php echo esc_html($item['testimonial']); ?>
										</p>
									<?php endif; ?>
									
									<!-- //version 3  -->
									<?php if($version == 'version_3'): ?>
									</div>
									<div class="info">

										<div class="client">
											<?php if( $item['image_author'] != '' ) { ?>
												<?php $alt = isset($item['name_author']) && $item['name_author'] ? $item['name_author'] : esc_html__( 'testimonial','auntri' ); ?>
												<img src="<?php echo esc_attr($item['image_author']['url']); ?>" alt="<?php echo esc_attr( $alt ); ?>" >
											<?php } ?>
										</div>
										<div class="name-job">
											<!-- rating -->
											<?php 
												$icon 					= '&#xE934;';
												$rating_data 			= $this->get_rating($item['rating']);
												$textual_rating 		= $rating_data[0] . '/' . $rating_data[1];
												$rating 				= (float) $item['rating'];
												$unmarked_star_style 	= $item['unmarked_star_style'];
												$star_style 			= $item['star_style'];
												
												if ( 'star_fontawesome' === $star_style ) {
													if ( 'outline' === $unmarked_star_style ) {
														$icon = '&#xE933;';
													}
												} elseif ( 'star_unicode' === $star_style ) {
													$icon = '&#9733;';
										
													if ( 'outline' === $unmarked_star_style ) {
														$icon = '&#9734;';
													}
												}

												$stars_element = '<div class="elementor-star-rating" title="'.$textual_rating.'">' . $this->render_stars( $icon, $item['rating'] ) . ' </div>';
												
												?>
												<?php if($rating != 0) : ?>
													<div class="ova-rating <?php echo esc_html( $star_style ); ?>">
														<?php print_r ( $stars_element ); ?>
													</div>
												<?php endif; ?>
											
												<?php
											?>
											<!-- end rating -->
											<?php if( $item['name_author'] != '' ) { ?>
												<p class="name second_font">
													<?php echo esc_html($item['name_author']); ?>
												</p>
											<?php } ?>

											<?php if( $item['job'] != '' ) { ?>
												<p class="job">
													<?php echo esc_html($item['job']); ?>
												</p>
											<?php } ?>
										</div>
									</div><!-- end info -->
									<?php endif; ?>
									
									
								</div>
							</div>
						<?php endforeach; endif; ?>
					</div>
					<?php if($version == 'version_1'): ?>
						<div class="owl-theme">
					        <div class="owl-controls">
					            <div class="custom-nav owl-nav"></div>
					        </div>
					    </div>
					<?php endif; ?>
			</div>
		
		<?php
	}
	// end render
}

$widgets_manager->register( new Auntri_Elementor_Testimonial() );