<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Auntri_Elementor_Video extends Widget_Base {

	
	public function get_name() {
		return 'auntri_elementor_video';
	}

	
	public function get_title() {
		return esc_html__( 'Video', 'auntri' );
	}

	
	public function get_icon() {
		return 'eicon-play-o';
	}

	
	public function get_categories() {
		return [ 'auntri' ];
	}

	public function get_script_depends() {
		return [ 'auntri-elementor-video' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'auntri' ),
			]
		);	
			
			$this->add_control(
				'version',
				[
					'label' 	=> esc_html__( 'Version', 'auntri' ),
					'type' 		=> Controls_Manager::SELECT,
					'default' 	=> 'version_1',
					'options' 	=> [
						'version_1' => esc_html__( 'Version 1', 'auntri' ),
						'version_2' => esc_html__( 'Version 2', 'auntri' ),
						'version_3' => esc_html__( 'Version 3', 'auntri' ),
					]
				]
			);
				$this->add_control(
				'image',
				[
					'label'   => esc_html__( 'Image', 'auntri' ),
					'type'    => \Elementor\Controls_Manager::MEDIA,
					'default' => [
						'url' => \Elementor\Utils::get_placeholder_image_src(),
					],
					'condition' => [
	                	'version' => 'version_1',
	                ],
					
				]
			);

			$this->add_control(
				'icon_class',
				[
					'label' 	=> esc_html__( 'Icon Class', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::TEXT,
					'default' 	=> 'flaticon flaticon-play-button',
					'condition' => [
	                	'version!' => 'version_3',
	                ],
				]
			);

			$this->add_control(
				'icon_class_v3',
				[
					'label' 	=> esc_html__( 'Icon Class', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::TEXT,
					'default' 	=> 'fas fa-play',
					'condition' => [
	                	'version' => 'version_3',
	                ],
				]
			);


			$this->add_control(
				'icon_url_video',
				[
					'label' 	=> esc_html__( 'URL Video', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::TEXT,
					'placeholder' 	=> esc_html__( 'Enter your URL', 'auntri' ) . ' (YouTube)',
					'default' 		=> 'https://www.youtube.com/watch?v=XHOmBV4js_E',
				]
			);

			$this->add_control(
	            'link',
	            [
	                'label' 	=> esc_html__( 'Link', 'auntri' ),
	                'type' 		=> \Elementor\Controls_Manager::URL,
	                'dynamic' 	=> [
	                    'active' => true,
	                ],
	                'condition' => [
	                	'icon_url_video' => '',
	                ],
	            ]
	        );

	        $this->add_control(
				'video_options',
				[
					'label' 	=> esc_html__( 'Video Options', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
						'icon_url_video!' => '',
					],
				]
			);

			$this->add_control(
				'autoplay_video',
				[
					'label' 	=> esc_html__( 'Autoplay', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::SWITCHER,
					'label_on' 	=> esc_html__( 'Yes', 'auntri' ),
					'label_off' => esc_html__( 'No', 'auntri' ),
					'default' 	=> 'yes',
					'condition' => [
						'icon_url_video!' => '',
					],
				]
			);

			$this->add_control(
				'mute_video',
				[
					'label' 	=> esc_html__( 'Mute', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::SWITCHER,
					'label_on' 	=> esc_html__( 'Yes', 'auntri' ),
					'label_off' => esc_html__( 'No', 'auntri' ),
					'default' 	=> 'no',
					'condition' => [
						'icon_url_video!' => '',
					],
				]
			);

			$this->add_control(
				'loop_video',
				[
					'label' 	=> esc_html__( 'Loop', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::SWITCHER,
					'label_on' 	=> esc_html__( 'Yes', 'auntri' ),
					'label_off' => esc_html__( 'No', 'auntri' ),
					'default' 	=> 'yes',
					'condition' => [
						'icon_url_video!' => '',
					],
				]
			);

			$this->add_control(
				'player_controls_video',
				[
					'label' 	=> esc_html__( 'Player Controls', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::SWITCHER,
					'label_on' 	=> esc_html__( 'Yes', 'auntri' ),
					'label_off' => esc_html__( 'No', 'auntri' ),
					'default' 	=> 'yes',
					'condition' => [
						'icon_url_video!' => '',
					],
				]
			);

			$this->add_control(
				'modest_branding_video',
				[
					'label' 	=> esc_html__( 'Modest Branding', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::SWITCHER,
					'label_on' 	=> esc_html__( 'Yes', 'auntri' ),
					'label_off' => esc_html__( 'No', 'auntri' ),
					'default' 	=> 'yes',
					'condition' => [
						'icon_url_video!' => '',
					],
				]
			);

			$this->add_control(
				'show_info_video',
				[
					'label' 	=> esc_html__( 'Show Info', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::SWITCHER,
					'label_on' 	=> esc_html__( 'Yes', 'auntri' ),
					'label_off' => esc_html__( 'No', 'auntri' ),
					'default' 	=> 'no',
					'condition' => [
						'icon_url_video!' => '',
					],
				]
			);

		$this->end_controls_section();
		/* End section icon */

		/* Begin section icon style */
		$this->start_controls_section(
			'section_icon_style',
			[
				'label' => esc_html__( 'Icon', 'auntri' ),
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
			]
		);	

			$this->start_controls_tabs( 'tabs_icon_style' );
				$this->start_controls_tab(
		            'tab_icon_normal',
		            [
		                'label' => esc_html__( 'Normal', 'auntri' ),
		            ]
		        );

		        	$this->add_control(
			            'icon_color_normal',
			            [
			                'label' 	=> esc_html__( 'Color', 'auntri' ),
			                'type' 		=> \Elementor\Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-video .icon-content-view .content i' => 'color: {{VALUE}};',
			                ],
			            ]
			        );

			        $this->add_control(
			            'icon_background_normal',
			            [
			                'label' 	=> esc_html__( 'Background', 'auntri' ),
			                'type' 		=> \Elementor\Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-video .icon-content-view .content' => 'background-color: {{VALUE}};',
			                ],
			            ]
			        );

			        $this->add_control(
			            'icon_background_secondary_normal',
			            [
			                'label' 	=> esc_html__( 'Background Secondary', 'auntri' ),
			                'type' 		=> \Elementor\Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-video.version_2.video-image .icon-content-view.video_active:after' => 'background-color: {{VALUE}};',
			                ],
			                'condition' => [
			                	'version' => 'version_2',
			                ],
			            ]
			        );

			        $this->add_group_control(
						Group_Control_Background::get_type(),
						[
							'name' 		=> 'icon_bg_gradient_normal',
							'label' 	=> esc_html__( 'Background Gradient', 'auntri' ),
							'types' 	=> [ 'gradient' ],
							'selector' 	=> '{{WRAPPER}} .ova-video .icon-content-view .content',
						]
					);


			        //version 2
					$this->add_responsive_control(
						'align_icon',
						[
							'label' => esc_html__( 'Alignment', 'auntri' ),
							'type' 	=> Controls_Manager::CHOOSE,
							'options' => [
								'flex-start' => [
									'title' => esc_html__( 'Left', 'auntri' ),
									'icon' 	=> 'eicon-text-align-left',
								],
								'center' => [
									'title' => esc_html__( 'Center', 'auntri' ),
									'icon' 	=> 'eicon-text-align-center',
								],
								'flex-end' => [
									'title' => esc_html__( 'Right', 'auntri' ),
									'icon' 	=> 'eicon-text-align-right',
								],
							],
							'selectors' => [
								'{{WRAPPER}} .ova-video.version_2 ' => 'justify-content: {{VALUE}};',
								'{{WRAPPER}} .ova-video.version_3 ' => 'justify-content: {{VALUE}};',
							],
							'condition' => [
			                	'version' => ['version_2','version_3']
			                ],
						]
				   	);
					
					$this->add_responsive_control(
						'iconbox_border_radius',
						[
							'label'      => esc_html__( 'Border Radius', 'auntri' ),
							'type'       => Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', 'em', '%' ],
							'selectors'  => [
								'{{WRAPPER}} .ova-video.version_2.video-image .icon-content-view.video_active .content' 	=> 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
							'condition' => [
			                	'version' => 'version_2',
			                ],
						]
					);

					$this->add_responsive_control(
						'iconbox_border_radius_sercondary',
						[
							'label'      => esc_html__( 'Border Radius Secondary', 'auntri' ),
							'type'       => Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', 'em', '%' ],
							'selectors'  => [
								'{{WRAPPER}} .ova-video.version_2.video-image .icon-content-view.video_active:after' 	=> 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
							'condition' => [
			                	'version' => 'version_2',
			                ],
						]
					);

					$this->add_responsive_control(
						'iconbox_border_radius_version_3',
						[
							'label'      => esc_html__( 'Border Radius', 'auntri' ),
							'type'       => Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', 'em', '%' ],
							'selectors'  => [
								'{{WRAPPER}} .ova-video.version_3.video-image .icon-content-view' 	=> 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
							'condition' => [
			                	'version' => 'version_3',
			                ],
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Border::get_type(),
						[
							'name' 		=> 'border_version_3',
							'label' 	=> esc_html__( 'Border', 'auntri' ),
							'selector' 	=> '{{WRAPPER}} .ova-video.version_3.video-image .icon-content-view',
						]
					);

		        $this->end_controls_tab();

		        $this->start_controls_tab(
		            'tab_icon_hover',
		            [
		                'label' => esc_html__( 'Hover', 'auntri' ),
		            ]
		        );

		        	$this->add_control(
			            'icon_color_hover',
			            [
			                'label' 	=> esc_html__( 'Color', 'auntri' ),
			                'type' 		=> \Elementor\Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-video .icon-content-view .content:hover i' => 'color: {{VALUE}};',
			                ],
			            ]
			        );

		        	$this->add_control(
			            'icon_background_hover_v1_v3',
			            [
			                'label' 	=> esc_html__( 'Background', 'auntri' ),
			                'type' 		=> \Elementor\Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-video .icon-content-view .content:hover:before' => 'background-color: {{VALUE}};',
			                ],    
			                'condition' => [
			                	'version' => ['version_1', 'version_3']
			                ], 
			            ]
			        );

			        $this->add_control(
			            'icon_background_hover_v2',
			            [
			                'label' 	=> esc_html__( 'Background', 'auntri' ),
			                'type' 		=> \Elementor\Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-video .icon-content-view .content:hover' => 'background-color: {{VALUE}};',
			                ],
			                'condition' => [
			                	'version' => 'version_2',
			                ],  
			            ]
			        ); 

			        $this->add_control(
			            'icon_border_hover_v3',
			            [
			                'label' 	=> esc_html__( 'Border Color', 'auntri' ),
			                'type' 		=> \Elementor\Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-video.version_3.video-image .icon-content-view:hover' => 'border-color: {{VALUE}};',
			                ],
			                'condition' => [
			                	'version' => 'version_3',
			                ],  
			            ]
			        );

			        $this->add_group_control(
						Group_Control_Background::get_type(),
						[
							'name' 		=> 'icon_bg_gradient_hover',
							'label' 	=> esc_html__( 'Background Gradient', 'auntri' ),
							'types' 	=> [ 'gradient' ],
							'selector' 	=> '{{WRAPPER}} .ova-video .icon-content-view .content:hover',
							'condition' => [
			                	'version!' => 'version_3',
			                ],
						]
					);

		        $this->end_controls_tab();
			$this->end_controls_tabs();

			$this->add_responsive_control(
				'icon_width',
				[
					'label' 	=> esc_html__( 'Width', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::SLIDER,
					'default' 	=> [
						'unit' 	=> 'px',
					],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 400,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' 	=> [ '%', 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-video .icon-content-view .content' => 'width: {{SIZE}}{{UNIT}}; min-width: {{SIZE}}{{UNIT}};',
					],
					'separator' => 'before'
				]
			);

			$this->add_responsive_control(
				'icon_height',
				[
					'label' 	=> esc_html__( 'Height', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::SLIDER,
					'default' 	=> [
						'unit' 	=> 'px',
					],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 400,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' 	=> [ '%', 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-video .icon-content-view .content' => 'height: {{SIZE}}{{UNIT}}; min-height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'icon_typography',
					'selector' 	=> '{{WRAPPER}} .ova-video .icon-content-view .content i',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' 		=> 'icon_box_shadow',
					'label' 	=> esc_html__( 'Box Shadow', 'auntri' ),
					'selector' 	=> '{{WRAPPER}} .ova-video .icon-content-view .content',
				]
			);

	        $this->add_responsive_control(
	            'content_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'auntri' ),
	                'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-video .icon-content-view .content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	    $this->end_controls_section();

		/* Begin image Style */
		$this->start_controls_section(
            'image_style',
            [
                'label' 	=> esc_html__( 'Image', 'auntri' ),
                'tab' 		=> \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
	            	'version' => 'version_1',
	            ],
            ]
        );
        //
        	$this->add_responsive_control(
				'image_width',
				[
					'label' 	=> esc_html__( 'Max Width', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::SLIDER,
					'default' 	=> [
						'unit' 	=> 'px',
					],
					'range' 	=> [
						'px' => [
							'min' => 0,
							'max' => 700,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' 	=> [ '%', 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-video.video-image .image' => 'max-width: {{SIZE}}{{UNIT}};',
					],
					'separator' 	=> 'before'
				]
			);

			$this->add_responsive_control(
				'image_height',
				[
					'label' 	=> esc_html__( 'Min Height', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::SLIDER,
					'default' 	=> [
						'unit' 	=> 'px',
					],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 700,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' 	=> [ '%', 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-video.video-image .image' => 'min-height: {{SIZE}}{{UNIT}};',
					],
				]
			);

	       $this->add_control(
	            'ova_image_video_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border Radius', 'auntri' ),
	                'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-video .image img' 		=> 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',  
	                ],
	            ]
	        );

        $this->end_controls_section();
		/* End image style */
		
		/* Begin triangle V3 Style */
		$this->start_controls_section(
            'triangle_v3_style',
            [
                'label' 	=> esc_html__( 'Triangle', 'auntri' ),
                'tab' 		=> \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
	            	'version' => 'version_3',
	            ],
            ]
        );

			$this->add_control(
	            'triangle_background',
	            [
	                'label' 	=> esc_html__( 'Background', 'auntri' ),
	                'type' 		=> \Elementor\Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .ova-video.version_3.video-image .icon-content-view:after' => 'background-color: {{VALUE}};',
	                ],
	            ]
	        );

	        $this->add_control(
	            'triangle_background:hover',
	            [
	                'label' 	=> esc_html__( 'Background Hover', 'auntri' ),
	                'type' 		=> \Elementor\Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .ova-video.version_3.video-image .icon-content-view:hover:after' => 'background-color: {{VALUE}};',
	                ],
	            ]
	        );

	        $this->add_responsive_control(
				'triangle_width',
				[
					'label' 	=> esc_html__( 'Width', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::SLIDER,
					'default' 	=> [
						'unit' 	=> 'px',
					],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 50,
						],
					],
					'size_units' 	=> [ 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-video.version_3.video-image .icon-content-view:after' => 'width:  {{SIZE}}{{UNIT}} ;',
					],
				]
			);

			$this->add_responsive_control(
				'triangle_height',
				[
					'label' 	=> esc_html__( 'Height', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::SLIDER,
					'default' 	=> [
						'unit' 	=> 'px',
					],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 50,
						],
					],
					'size_units' 	=> [ 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-video.version_3.video-image .icon-content-view:after' => 'height:  {{SIZE}}{{UNIT}} ;',
					],
				]
			);


			$this->add_responsive_control(
				'triangle_bottom',
				[
					'label' 	=> esc_html__( 'Bottom', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::SLIDER,
					'default' 	=> [
						'unit' 	=> 'px',
					],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 40,
						],
					],
					'size_units' 	=> [ 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-video.version_3.video-image .icon-content-view:after' => 'top: calc( 100% + {{SIZE}}{{UNIT}}) ;',
					],
				]
			);

			$this->add_responsive_control(
				'triangle_right',
				[
					'label' 	=> esc_html__( 'Right', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::SLIDER,
					'default' 	=> [
						'unit' 	=> 'px',
					],
					'range' => [
						'px' => [
							'min' => -50,
							'max' => 50,
						],
					],
					'size_units' 	=> [ 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-video.version_3.video-image .icon-content-view:after' => 'left: calc( 100% + {{SIZE}}{{UNIT}}) ;',
					],
				]
			);


        $this->end_controls_section();
		/* End Triangle style */
	}

	// Render Template Here
	protected function render() {

		$settings 	= $this->get_settings();
		$version 	= $settings['version'];

		$icon_class = $settings['icon_class'];
		$url_video 	= $settings['icon_url_video'];
		$link 		= $settings['link']['url'];
		$tg_blank 	= '';
		if ( $settings['link']['is_external'] == 'on' ) {
			$tg_blank = 'target="_blank"';
		}

		if ( ! $link ) {
			$url = $link;
		}

		if( $version === 'version_3' ) { 
			$icon_class = $settings['icon_class_v3'];
		}

		$autoplay 	= $settings['autoplay_video'];
		$mute 		= $settings['mute_video'];
		$loop 		= $settings['loop_video'];
		$controls 	= $settings['player_controls_video'];
		$modest 	= $settings['modest_branding_video'];
		$show_info 	= $settings['show_info_video'];

		 ?>
         
         <div class="ova-video video-image <?php echo esc_attr($version); ?>">
         	<?php if($settings['image']['url'] && $version == 'version_1'): ?>
     		<div class="image">
				<img src="<?php echo esc_url($settings['image']['url']) ?>" alt="" style="">
			</div>
			<?php endif; ?>
			<div class="icon-content-view video_active ">
				
				<?php if ( ! empty( $url_video ) ) : ?>
					<div class="content video-btn" 
							data-src="<?php echo esc_url( $url_video ); ?>" 
							data-autoplay="<?php echo esc_attr( $autoplay ); ?>" 
							data-mute="<?php echo esc_attr( $mute ); ?>" 
							data-loop="<?php echo esc_attr( $loop ); ?>" 
							data-controls="<?php echo esc_attr( $controls ); ?>" 
							data-modest="<?php echo esc_attr( $modest ); ?>" 
							data-show_info="<?php echo esc_attr( $show_info ); ?> 
							">
						<i class="<?php echo esc_attr( $icon_class ); ?>"></i>
					</div>
				<?php else: ?>
					<div class="content">
						<i class="<?php echo esc_attr( $icon_class ); ?>"></i>
					</div>
				<?php endif; ?>
			</div>
			<div class="modal-container">
				<div class="modal">
					<i class="ovaicon-cancel"></i>
					<iframe class="modal-video" allow="autoplay"></iframe>
				</div>
			</div>
		</div>
		 	
		<?php
	}

	
}
$widgets_manager->register( new Auntri_Elementor_Video() );