<?php

class Auntri_Elementor {
	
	function __construct() {
            
		// Register Header Footer Category in Pane
	    add_action( 'elementor/elements/categories_registered', array( $this, 'auntri_add_category' ) );

	    add_action( 'elementor/frontend/after_register_scripts', array( $this, 'auntri_enqueue_scripts' ) );
		
		add_action( 'elementor/widgets/register', array( $this, 'auntri_include_widgets' ) );
		
		add_filter( 'elementor/controls/animations/additional_animations', array( $this, 'auntri_add_animations'), 10 , 0 );

		add_action( 'wp_print_footer_scripts', array( $this, 'auntri_enqueue_footer_scripts' ) );

		// customize List icon
		add_action( 'elementor/element/icon-list/section_text_style/after_section_end', array( $this, 'auntri_list_icons_custom' ), 10, 2 );	

		// customize image Box
		add_action( 'elementor/element/image-box/section_style_content/after_section_end', array( $this, 'auntri_image_box_custom' ), 10, 2 );

		// customize social icon
		add_action( 'elementor/element/social-icons/section_social_hover/after_section_end', array( $this, 'auntri_social_icons_custom' ), 10, 2 );

		// customize icon box
		add_action( 'elementor/element/icon-box/section_style_content/after_section_end', array( $this, 'auntri_icons_box_customize' ), 10, 2 );

		// customize icon
		add_action( 'elementor/element/icon/section_style_icon/after_section_end', array( $this, 'auntri_icons_custom' ), 10, 2 );
        
        // customize button
		add_action( 'elementor/element/button/section_button/after_section_end', array( $this, 'auntri_button_custom' ), 10, 2 );

		// text editor custom control style
		add_action( 'elementor/element/text-editor/section_style/after_section_end', array( $this, 'auntri_text_editor_custom' ), 10, 2 );

		//Add accordion custom control style
		add_action( 'elementor/element/accordion/section_toggle_style_content/after_section_end', array( $this, 'auntri_accordion_custom' ), 10, 2 );

		// load icons
		add_filter( 'elementor/icons_manager/additional_tabs', array( $this, 'auntri_icons_filters_new' ), 9999999, 1 );

	}

	
	function auntri_add_category(  ) {

	    \Elementor\Plugin::instance()->elements_manager->add_category(
	        'hf',
	        [
	            'title' => __( 'Header Footer', 'auntri' ),
	            'icon' => 'fa fa-plug',
	        ]
	    );

	    \Elementor\Plugin::instance()->elements_manager->add_category(
	        'auntri',
	        [
	            'title' => __( 'Auntri', 'auntri' ),
	            'icon' => 'fa fa-plug',
	        ]
	    );

	}

	function auntri_enqueue_scripts(){
        
        $files = glob(get_theme_file_path('/assets/js/elementor/*.js'));
        
        foreach ($files as $file) {
            $file_name = wp_basename($file);
            $handle    = str_replace(".js", '', $file_name);
            $src       = get_theme_file_uri('/assets/js/elementor/' . $file_name);
            if (file_exists($file)) {
                wp_register_script( 'auntri-elementor-' . $handle, $src, ['jquery'], false, true );
            }
        }


	}

	function auntri_include_widgets( $widgets_manager ) {
        $files = glob(get_theme_file_path('elementor/widgets/*.php'));
        foreach ($files as $file) {
            $file = get_theme_file_path('elementor/widgets/' . wp_basename($file));
            if (file_exists($file)) {
                require_once $file;
            }
        }
    }

    function auntri_add_animations(){
    	$animations = array(
            'Auntri' => array(
                'ova-move-up' 		=> esc_html__('Move Up', 'auntri'),
                'ova-move-down' 	=> esc_html__( 'Move Down', 'auntri' ),
                'ova-move-left'     => esc_html__('Move Left', 'auntri'),
                'ova-move-right'    => esc_html__('Move Right', 'auntri'),
                'ova-scale-up'      => esc_html__('Scale Up', 'auntri'),
                'ova-flip'          => esc_html__('Flip', 'auntri'),
                'ova-helix'         => esc_html__('Helix', 'auntri'),
                'ova-popup'			=> esc_html__( 'PopUp','auntri' )
            ),
        );

        return $animations;
    }

   

	function auntri_enqueue_footer_scripts(){
		// Font Icon
	    wp_enqueue_style('ovaicon', AUNTRI_URI.'/assets/libs/ovaicon/font/ovaicon.css', array(), null);

	    // Flaticon
	    wp_enqueue_style('flaticon', AUNTRI_URI.'/assets/libs/flaticon/font/flaticon.css', array(), null);
	}
	
	

	public function auntri_icons_filters_new( $tabs = array() ) {
		$newicons = [];

		$font_data['json_url'] = AUNTRI_URI.'/assets/libs/ovaicon/ovaicon.json';
		$font_data['name'] = 'ovaicon';
		$newicons[ $font_data['name'] ] = [
			'name'          => $font_data['name'],
			'label'         => esc_html__( 'Default', 'auntri' ),
			'url'           => '',
			'enqueue'       => '',
			'prefix'        => 'ovaicon-',
			'displayPrefix' => '',
			'ver'           => '1.0',
			'fetchJson'     => $font_data['json_url'],
		];

		$flaticon_data['json_url'] = AUNTRI_URI.'/assets/libs/flaticon/flaticon.json';
		$flaticon_data['name'] = 'flaticon';
		$newicons[ $flaticon_data['name'] ] = [
			'name'          => $flaticon_data['name'],
			'label'         => esc_html__( 'Flaticon', 'auntri' ),
			'url'           => '',
			'enqueue'       => '',
			'prefix'        => 'flaticon-',
			'displayPrefix' => '',
			'ver'           => '1.0',
			'fetchJson'     => $flaticon_data['json_url'],
		];

		return array_merge( $tabs, $newicons );

	}

	function auntri_list_icons_custom ( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_social_icons',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova List Icon', 'auntri' ),
			]
		);

			$element->add_responsive_control(
				'icon_list_margin',
				[
					'label' 		=> esc_html__( 'Margin', 'auntri' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
					'{{WRAPPER}}  .elementor-icon-list-items .elementor-icon-list-item  ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
		$element->end_controls_section();
	}


	function auntri_image_box_custom ( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_image_box',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova Image Box', 'auntri' ),
			]
		);
			$element->add_control(
				'ova_image_box_title',
				[
					'label' => esc_html__( 'Title', 'auntri' ),
					'type' => Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$element->add_responsive_control(
				'image_box_margin',
				[
					'label' 		=> esc_html__( 'Margin', 'auntri' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
					'{{WRAPPER}}  .elementor-image-box-content .elementor-image-box-title ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$element->add_control(
				'ova_image_box_image',
				[
					'label' => esc_html__( 'Image', 'auntri' ),
					'type' => Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$element->add_control(
	            'ova_image_box_background',
	            [
	                'label' 	=> esc_html__( 'Background', 'auntri' ),
	                'type' 		=> \Elementor\Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .elementor-image-box-img img' => 'background-color: {{VALUE}};',
	                ],
	            ]
	        );

			$element->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'image_box_border',
					'label' => esc_html__( 'Border', 'auntri' ),
					'selector' => '{{WRAPPER}} .elementor-image-box-img img',
				]
			);

			$element->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'ova_image_box_shadow',
					'label' => esc_html__( 'Box Shadow', 'auntri' ),
					'selector' => '{{WRAPPER}} .elementor-image-box-img img',
				]
			);

		$element->end_controls_section();
	}

	function auntri_social_icons_custom ( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_social_icons',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova Social Icon', 'auntri' ),
			]
		);

			$element->add_responsive_control(
	            'ova_social_icons_display',
	            [
	                'label' 	=> esc_html__( 'Display', 'auntri' ),
	                'type' 		=> \Elementor\Controls_Manager::CHOOSE,
	                'options' 	=> [
	                    'inline-block' => [
	                        'title' => esc_html__( 'Block', 'auntri' ),
	                        'icon' 	=> 'eicon-h-align-left',
	                    ],
	                    'inline-flex' => [
	                        'title' => esc_html__( 'Flex', 'auntri' ),
	                        'icon' 	=> 'eicon-h-align-center',
	                    ],
	                ],
	                'selectors' => [
	                    '{{WRAPPER}} .elementor-icon.elementor-social-icon' => 'display: {{VALUE}}',
	                ],
	            ]
	        );

	        $element->add_control(
	            'social_icons_color_hover',
	            [
	                'label' 	=> esc_html__( 'Color Hover', 'auntri' ),
	                'type' 		=> \Elementor\Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .elementor-grid-item .elementor-social-icon:hover i' => 'color: {{VALUE}};',
	                ],
	            ]
	        );

			$element->add_control(
	            'social_icons_bg_hover',
	            [
	                'label' 	=> esc_html__( 'Background Hover', 'auntri' ),
	                'type' 		=> \Elementor\Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .elementor-grid-item .elementor-social-icon:before' => 'background-color: {{VALUE}};',
	                ],
	            ]
	        );

		$element->end_controls_section();
	}

	function auntri_icons_box_customize ( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_icons_box_customize',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova Icon Box', 'auntri' ),
			]
		);	
			$element->add_responsive_control(
	            'ova_vertical_align',
	            [
	                'label' 	=> esc_html__( 'Vetical Align', 'auntri' ),
	                'type' 		=> \Elementor\Controls_Manager::CHOOSE,
	                'options' 	=> [
	                    'start' => [
	                        'title' => esc_html__( 'Top', 'auntri' ),
	                        'icon' 	=> 'eicon-v-align-top',
	                    ],
	                    'center' => [
	                        'title' => esc_html__( 'Center', 'auntri' ),
	                        'icon' 	=> 'eicon-v-align-middle',
	                    ],
	                    'end' => [
	                        'title' => esc_html__( 'Bottom', 'auntri' ),
	                        'icon' 	=> 'eicon-v-align-bottom',
	                    ],
	                ],
	                'selectors' => [
	                    '{{WRAPPER}} .elementor-icon-box-wrapper' => 'align-items: {{VALUE}}',
	                ],
	            ]
	        );

			$element->add_control(
				'ova_icon_box_title',
				[
					'label' => esc_html__( 'Title', 'auntri' ),
					'type' => Elementor\Controls_Manager::HEADING,
				]
			);

			$element->add_responsive_control(
				'title_margin',
				[
					'label' 		=> esc_html__( 'Margin', 'auntri' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
					'{{WRAPPER}}  .elementor-icon-box-content .elementor-icon-box-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$element->end_controls_section();
	}

	function auntri_button_custom ( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_buton',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova Button', 'auntri' ),
			]
		);

			$element->add_responsive_control(
	            'button_display',
	            [
	                'label' 	=> esc_html__( 'Display', 'auntri' ),
	                'type' 		=> \Elementor\Controls_Manager::CHOOSE,
	                'options' 	=> [
	                    'block' => [
	                        'title' => esc_html__( 'Block', 'auntri' ),
	                        'icon' 	=> 'eicon-h-align-left',
	                    ],
	                    'flex' => [
	                        'title' => esc_html__( 'Flex', 'auntri' ),
	                        'icon' 	=> 'eicon-h-align-center',
	                    ],
	                ],
	                'selectors' => [
	                    '{{WRAPPER}} .elementor-button-wrapper' => 'display: {{VALUE}}',
	                ],
	            ]
	        );

	        $element->add_responsive_control(
				'button_width',
				[
					'label' => esc_html__( 'Width', 'auntri' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px','%' ],
					'range' => [
						'px' => [
							'min' => 50,
							'max' => 150,
							'step' => 1,
						]
					],
					'selectors' => [
						'{{WRAPPER}} .elementor-button-wrapper .elementor-button' => 'width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$element->add_control(
	            'button_bg_hover',
	            [
	                'label' 	=> esc_html__( 'Background Hover', 'auntri' ),
	                'type' 		=> \Elementor\Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .elementor-button-wrapper .elementor-button:before' => 'background-color: {{VALUE}};',
	                ],
	            ]
	        );

	        $element->add_control(
	            'button_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border Radius', 'auntri' ),
	                'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .elementor-button-wrapper .elementor-button:before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $element->add_responsive_control(
				'align_button',
				[
					'label' 	=> esc_html__( 'Alignment', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::CHOOSE,
					'options' 	=> [
						'left' => [
							'title' => esc_html__( 'Left', 'auntri' ),
							'icon' 	=> 'eicon-text-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'auntri' ),
							'icon' 	=> 'eicon-text-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'auntri' ),
							'icon' 	=> 'eicon-text-align-right',
						],
					],
					'default' 	=> 'center',
					'toggle' 	=> true,
					'selectors' => [
						'{{WRAPPER}} .elementor-button-wrapper .elementor-button' => 'text-align: {{VALUE}}',
					],
				]
			);

		$element->end_controls_section();
	}

	function auntri_icons_custom ( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_icon',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova Icon', 'auntri' ),
			]
		);

		$element->add_responsive_control(
            'icon_display',
            [
                'label' 	=> esc_html__( 'Display', 'auntri' ),
                'type' 		=> \Elementor\Controls_Manager::CHOOSE,
                'options' 	=> [
                    'block' => [
                        'title' => esc_html__( 'Block', 'auntri' ),
                        'icon' 	=> 'eicon-h-align-left',
                    ],
                    'flex' => [
                        'title' => esc_html__( 'Flex', 'auntri' ),
                        'icon' 	=> 'eicon-h-align-center',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-icon-wrapper' => 'display: {{VALUE}}',
                ],
            ]
        );

		$element->end_controls_section();
	}

	// Ova text-editor custom 
    function auntri_text_editor_custom( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_tabs',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova Text Editor', 'auntri' ),
			]
		);

			$element->add_control(
	            'text-link-color',
	            [
	                'label' 	=> esc_html__( 'Link color ', 'auntri' ),
	                'type' 		=> \Elementor\Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} a ' => 'color: {{VALUE}};',
	                ],
	            ]
	        );

	        $element->add_control(
	            'text-link-color_hover',
	            [
	                'label' 	=> esc_html__( 'Link color hover', 'auntri' ),
	                'type' 		=> \Elementor\Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} a:hover' => 'color: {{VALUE}};',
	                ],
	            ]
	        );

			$element->add_responsive_control(
				'text_margin',
				[
					'label' 		=> esc_html__( 'Margin', 'auntri' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
					'{{WRAPPER}}  p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$element->add_responsive_control(
		        'text_padding',
		        [
		            'label' 		=> esc_html__( 'Padding', 'auntri' ),
		            'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
		            'size_units' 	=> [ 'px', '%', 'em' ],
		            'selectors' 	=> [
		             '{{WRAPPER}}  p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		            ],
		         ]
		    );


		$element->end_controls_section();
	}

	// Ova accordion custom 
    function auntri_accordion_custom( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_accordion',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova Accordion', 'auntri' ),
			]
		);

		    $element->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'accordion_content_box_shadow',
					'label' => esc_html__( 'Box Shadow', 'auntri' ),
					'selector' => '{{WRAPPER}} .elementor-accordion .elementor-accordion-item',
				]
			);

		    $element->add_responsive_control(
				'accordion_title_heading',
				[
					'label' 		=> esc_html__( 'Title', 'auntri' ),
					'type' 			=> \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$element->add_responsive_control(
				'accordion_title_margin',
				[
					'label' 		=> esc_html__( 'Margin', 'auntri' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$element->add_responsive_control(
				'accordion_title_margin_active',
				[
					'label' 		=> esc_html__( 'Active Margin', 'auntri' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title.elementor-active' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

	        $element->add_control(
	            'accordion_title_background_active',
	            [
	                'label' 	=> esc_html__( 'Active Background ', 'auntri' ),
	                'type' 		=> \Elementor\Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .elementor-accordion .elementor-tab-title.elementor-active' => 'background-color: {{VALUE}};',
	                ],
	            ]
	        );

	        $element->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'accordion_title_border_active',
					'label' => esc_html__( 'Border Active', 'auntri' ),
					'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-title.elementor-active',
				]
			);

		    $element->add_responsive_control(
				'accordion_content_heading',
				[
					'label' 		=> esc_html__( 'Content', 'auntri' ),
					'type' 			=> \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$element->add_responsive_control(
				'accordion_content_margin',
				[
					'label' 		=> esc_html__( 'Margin', 'auntri' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$element->add_control(
	            'accordion_content_background_active',
	            [
	                'label' 	=> esc_html__( 'Active Background ', 'auntri' ),
	                'type' 		=> \Elementor\Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .elementor-accordion .elementor-tab-content.elementor-active' => 'background-color: {{VALUE}};',
	                ],
	            ]
	        );

			$element->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'accordion_content_border',
					'label' => esc_html__( 'Border', 'auntri' ),
					'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-content',
				]
			);

			// Icon options
		    $element->add_control(
				'icon_options',
				[
					'label' 	=> esc_html__( 'Icon Options', 'auntri' ),
					'type' 		=> \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

		    	$element->add_responsive_control(
		            'icon_display',
		            [
		                'label' 	=> esc_html__( 'Display', 'auntri' ),
		                'type' 		=> \Elementor\Controls_Manager::CHOOSE,
		                'options' 	=> [
		                    'flex' => [
		                        'title' => esc_html__( 'Center', 'auntri' ),
		                        'icon' 	=> 'eicon-h-align-center',
		                    ],
		                ],
		                'selectors' => [
		                    '{{WRAPPER}} .elementor-accordion .elementor-tab-title i' => 'display: {{VALUE}};align-items: center;justify-content: center;position: relative;',
		                ],  
		            ]
		        );

		        $element->add_group_control(
					\Elementor\Group_Control_Typography::get_type(),
					[
						'name' 		=> 'icon_typography',
						'selector' 	=> '{{WRAPPER}} .elementor-accordion .elementor-tab-title i',
						'condition' => [
							'icon_display!' => '',
						],
					]
				);

				$element->add_responsive_control(
					'icon_top',
					[
						'label' 	=> esc_html__( 'Top', 'auntri' ),
						'type' 		=> \Elementor\Controls_Manager::SLIDER,
						'default' 	=> [
							'unit' 	=> 'px',
						],
						'tablet_default' => [
							'unit' => 'px',
						],
						'mobile_default' => [
							'unit' => 'px',
						],
						'range' => [
							'px' => [
								'min' => -500,
								'max' => 500,
							],
						],
						'size_units' 	=> [ 'px' ],
						'selectors' 	=> [
							'{{WRAPPER}} .elementor-accordion .elementor-tab-title i' => 'top: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
						],
						'condition' => [
							'icon_display!' => '',
						],
					]
				);

				$element->add_responsive_control(
					'icon_right',
					[
						'label' 	=> esc_html__( 'Right', 'auntri' ),
						'type' 		=> \Elementor\Controls_Manager::SLIDER,
						'default' 	=> [
							'unit' 	=> 'px',
						],
						'tablet_default' => [
							'unit' => 'px',
						],
						'mobile_default' => [
							'unit' => 'px',
						],
						'range' => [
							'px' => [
								'min' => -500,
								'max' => 500,
							],
						],
						'size_units' 	=> [ 'px' ],
						'selectors' 	=> [
							'{{WRAPPER}} .elementor-accordion .elementor-tab-title i' => 'right: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
						],
						'condition' => [
							'icon_display!' => '',
						],
					]
				);


		    	$element->add_responsive_control(
					'icon_width',
					[
						'label' 	=> esc_html__( 'Width', 'auntri' ),
						'type' 		=> \Elementor\Controls_Manager::SLIDER,
						'default' 	=> [
							'unit' 	=> 'px',
						],
						'tablet_default' => [
							'unit' => 'px',
						],
						'mobile_default' => [
							'unit' => 'px',
						],
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'size_units' 	=> [ 'px' ],
						'selectors' 	=> [
							'{{WRAPPER}} .elementor-accordion .elementor-tab-title i' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
						],
						'condition' => [
							'icon_display!' => '',
						],
					]
				);

		        $element->add_control(
		            'icon_background',
		            [
		                'label' 	=> esc_html__( 'Background', 'auntri' ),
		                'type' 		=> \Elementor\Controls_Manager::COLOR,
		                'selectors' => [
		                    '{{WRAPPER}} .elementor-accordion .elementor-tab-title i' => 'background-color: {{VALUE}};',
		                ],
		                'condition' => [
							'icon_display!' => '',
						],
		            ]
		        );

		        $element->add_control(
		            'icon_active_background',
		            [
		                'label' 	=> esc_html__( 'Active Background ', 'auntri' ),
		                'type' 		=> \Elementor\Controls_Manager::COLOR,
		                'selectors' => [
		                    '{{WRAPPER}} .elementor-accordion .elementor-tab-title.elementor-active i' => 'background-color: {{VALUE}};',
		                ],
		                'condition' => [
							'icon_display!' => '',
						],
		            ]
		        );

		        $element->add_responsive_control(
		            'icon_border_radius',
		            [
		                'label' 		=> esc_html__( 'Border Radius', 'auntri' ),
		                'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
		                'size_units' 	=> [ 'px', '%', 'em' ],
		                'selectors' 	=> [
		                    '{{WRAPPER}} .elementor-accordion .elementor-tab-title i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		                ],
		                'condition' => [
							'icon_display!' => '',
						],
		            ]
		        );

		$element->end_controls_section();
	}    
    

}

return new Auntri_Elementor();