<?php
/**
 * @package    OVA Project by ovatheme
 * @author     Ovatheme
 * @copyright  Copyright (C) 2022 Ovatheme All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 */

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Ova_Elementor_Data_Project extends Widget_Base {

	public function get_name() {
		return 'ova_elementor_data_project';
	}

	public function get_title() {
		return esc_html__( 'Data Project', 'ova-project' );
	}

	public function get_icon() {
		return 'eicon-bullet-list';
	}

	public function get_categories() {
		return [ 'ovapro' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}

	protected function register_controls() {

		//TAB CONTENT
		$this->start_controls_section(
            'section_content',
            [
                'label' => esc_html__( 'Content', 'ova-project' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $this->add_control(
				'show_share_social',
				[
					'label' => esc_html__( 'Show Share Social', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'ova-project' ),
					'label_off' => esc_html__( 'Hide', 'ova-project' ),
					'return_value' => 'yes',
					'default' => 'yes',
				]
			);

        $this->end_controls_section();


		//TAB STYLES CONTENT
		$this->start_controls_section(
            'section_content_style',
            [
                'label' => esc_html__( 'Content', 'ova-project' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->start_controls_tabs(
				'style_controls_tabs'
			);

        		$this->start_controls_tab(
					'style_controls_label_tab',
					[
						'label' => esc_html__( 'LABEL', 'ova-project' ),
					]
				);
					$this->add_group_control(
						\Elementor\Group_Control_Typography::get_type(),
						[
							'name' 		=> 'label_typography',
							'selector' 	=> '{{WRAPPER}} .data-project .item .label',
						]
					);

					$this->add_control(
						'subtitle_color',
						[
							'label' 	=> esc_html__( 'Color', 'ova-project' ),
							'type' 		=> \Elementor\Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .data-project .item .label' => 'color: {{VALUE}}',
							],
						]
					);


				$this->end_controls_tab();

				$this->start_controls_tab(
					'style_controls_title_tab',
					[
						'label' => esc_html__( 'TITLE', 'ova-project' ),
					]
				);

					$this->add_group_control(
						\Elementor\Group_Control_Typography::get_type(),
						[
							'name' 		=> 'title_typography',
							'selector' 	=> '{{WRAPPER}} .data-project .item .title',
						]
					);

					$this->add_control(
						'title_color',
						[
							'label' 	=> esc_html__( 'Color', 'ova-project' ),
							'type' 		=> \Elementor\Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .data-project .item .title' => 'color: {{VALUE}}',
							],
						]
					);

				$this->end_controls_tab();

			$this->end_controls_tabs();
        
        	//TAB ITEM
        	$this->start_controls_tabs(
				'style_item_tabs'
			);

	    		$this->start_controls_tab(
					'style_controls_item_tab',
					[
						'label' => esc_html__( 'Item', 'ova-project' ),
					]
				);

	    			$this->add_group_control(
						\Elementor\Group_Control_Border::get_type(),
						[
							'name' 		=> 'item_border',
							'label' 	=> esc_html__( 'Border', 'ova-project' ),
							'selector' 	=> '{{WRAPPER}} .data-project',
						]
					);

					$this->add_control(
						'item_background',
						[
							'label' 	=> esc_html__( 'Background', 'ova-project' ),
							'type' 		=> \Elementor\Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .data-project' => 'background-color: {{VALUE}}',
							],
						]
					);


					$this->add_responsive_control(
			            'item_margin',
			            	[
			                'label'         => esc_html__( 'Margin Item', 'ova-project' ),
			                'type'          => Controls_Manager::DIMENSIONS,
			                'size_units'    => [ 'px', '%', 'em' ],
			                'selectors'     => [
			                    '{{WRAPPER}} .data-project .item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				                ],
				            ]
				    );

				    $this->add_responsive_control(
			            'item_padding',
			            	[
			                'label'         => esc_html__( 'Padding Item', 'ova-project' ),
			                'type'          => Controls_Manager::DIMENSIONS,
			                'size_units'    => [ 'px', '%', 'em' ],
			                'selectors'     => [
			                    '{{WRAPPER}} .data-project ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				                ],
				            ]
				    );


				    $this->add_group_control(
						\Elementor\Group_Control_Box_Shadow::get_type(),
						[
							'name' 		=> 'item_box_shadow',
							'label' 	=> esc_html__( 'Box Shadow', 'ova-project' ),
							'selector' 	=> '{{WRAPPER}} .data-project',
						]
					);


				$this->end_controls_tab();
			$this->end_controls_tabs();
			//END TAB ITEM

		$this->end_controls_section();
		//END TAB STYLES CONTENT
		
		//TAB STYLE ICON
		$this->start_controls_section(
            'section_icon_style',
            [
                'label' => esc_html__( 'Icon', 'ova-project' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

		    $this->add_responsive_control(
				'font_size_icon',
				[
					'label'			=> esc_html__( 'Size icon', 'ova-project' ),
					'type' 			=> \Elementor\Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
							'step' => 1,
						],
					],
					'default' => [
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}} .data-project ul.share-social-icons a i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'icon_color',
				[
					'label' 	=> esc_html__( 'Color', 'ova-project' ),
					'type' 		=> \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .data-project ul.share-social-icons a' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'icon_background',
				[
					'label' 	=> esc_html__( 'Background', 'ova-project' ),
					'type' 		=> \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .data-project ul.share-social-icons a' => 'background-color: {{VALUE}}',
					],
				]
			);

		    $this->add_responsive_control(
                'icon_border_radius',
                [
                    'label'         => esc_html__( 'Border Radius', 'ova-project' ),
                    'type'          => Controls_Manager::DIMENSIONS,
                    'size_units'    => [ 'px', '%', 'em' ],
                    'selectors'     => [
                        '{{WRAPPER}} .data-project ul.share-social-icons a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

			$this->add_responsive_control(
	            'icon_margin',
	            	[
	                'label'         => esc_html__( 'Margin ', 'ova-project' ),
	                'type'          => Controls_Manager::DIMENSIONS,
	                'size_units'    => [ 'px', '%', 'em' ],
	                'selectors'     => [
	                    '{{WRAPPER}} .data-project ul.share-social-icons li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		                ],
		            ]
		    );

        $this->end_controls_section();
		//END TAB STYLE ICON


	}

	protected function render() {

		$settings = $this->get_settings();
	
		$template = apply_filters( 'el_ovapro_data_project', 'elementor/data_project.php' );

		ob_start();
		ovapro_get_template( $template, $settings );
		echo ob_get_clean();
		
	}
}

$widgets_manager->register( new Ova_Elementor_Data_Project() );