<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Ova_Elementor_Project_Box extends Widget_Base {

	
	public function get_name() {
		return 'ova_elementor_project_box';
	}

	
	public function get_title() {
		return esc_html__( 'Project Box', 'ova-project' );
	}

	
	public function get_icon() {
		return 'eicon-image-box';
	}

	
	public function get_categories() {
		return [ 'ovapro' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'ova-project' ),
			]
		);	


		    // Add Class control
			$this->add_control(
				'template',
				[
					'label' => esc_html__( 'Template', 'ova-project' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'template1',
					'options' => [
						'template1' => esc_html__('Template 1', 'ova-project'),
						'template2' => esc_html__('Template 2', 'ova-project'),
						'template3' => esc_html__('Template 3', 'ova-project'),
						'template4' => esc_html__('Template 4', 'ova-project'),
						'template5' => esc_html__('Template 5', 'ova-project'),
						'template6' => esc_html__('Template 6', 'ova-project'),
					]
				]
			);

			$args = array(
				'taxonomy' 	=> 'category_project',
				'orderby' => 'name',
				'order' => 'ASC'
			);
  
		  	$categories   = get_categories($args);
		  	$cate_array   = array();
		  	$arrayCateAll = array( 'all' => esc_html__( 'All categories', 'ova-project' ) );
		  	if ($categories) {
			  	foreach ( $categories as $cate ) {
				  	$cate_array[$cate->slug] = $cate->name;
			  	}
		  	} else {
			  	$cate_array[ esc_html__( 'No content Category found', 'ova-project' ) ] = 0;
		  	}

		  	$this->add_control(
			  	'category',
			  	[
				  	'label' => esc_html__( 'Category', 'ova-project' ),
				  	'type' => Controls_Manager::SELECT,
				  	'default' => 'all',
				  	'options' => array_merge( $arrayCateAll, $cate_array ),
			  	]
		  	);

			$this->add_control(
				'number_column',
				[
					'label' => esc_html__( 'Column', 'ova-project' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'three_column',
					'options' => [
						'two_column' => esc_html__('2 Column', 'ova-project'),
						'three_column' => esc_html__('3 Column', 'ova-project'),
						'four_column' => esc_html__('4 Column', 'ova-project'),
					]
				]
			);

			$this->add_control(
				'post_per_page',
				[
					'label'   => esc_html__( 'Post Per Page', 'ova-project' ),
					'type'    => Controls_Manager::NUMBER,
					'min'     => 1,
					'default' => 6
				]
			);

			$this->add_control(
				'order_by',
				[
					'label'   => esc_html__( 'Order By', 'ova-project' ),
					'type'    => Controls_Manager::SELECT,
					'default' => 'date',
					'options' => [
						'title' => esc_html__( 'Title', 'ova-project' ),
						'date' 	=> esc_html__( 'Date', 'ova-project' ),
						'ID' 	=> esc_html__( 'ID', 'ova-project' ),	
						'ova_project_order_project'  => esc_html__( 'Custom Order', 'ova-project' ),		
					],
				]
			);

			$this->add_control(
				'order',
				[
					'label'   => esc_html__( 'Order', 'ova-project' ),
					'type'    => Controls_Manager::SELECT,
					'default' => 'DESC',
					'options' => [
						'DESC' => esc_html__( 'Descending', 'ova-project' ),
						'ASC'  => esc_html__( 'Ascending', 'ova-project' ),
					],
				]
			);

			$this->add_control(
				'target_blank',
				[
					'label' 		=> esc_html__( 'Target Blank', 'ova-project' ),
					'type' 			=> Controls_Manager::SWITCHER,
					'label_on' 		=> esc_html__( 'Yes', 'ova-project' ),
					'label_off' 	=> esc_html__( 'No', 'ova-project' ),
					'default' 		=> 'no',
				]
			);

		$this->end_controls_section();

		//******Project Box style*****/
		$this->start_controls_section(
			'section_project_box_style',
			[
				'label' => esc_html__( 'Item Project Box', 'ova-project' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'template' => ['template4']
				]
			]
		);

		     $this->add_control(
				'grid_gap',
				[
					'label' 		=> esc_html__( 'Grid Gap', 'ova-project' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor' => 'grid-gap: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'bgcolor_project_box',
				[
					'label' => esc_html__( 'Background Color', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template, {{WRAPPER}} .ova-project-box-elementor .ova-project-box-template4 .info' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'bgcolor_project_box_hover',
				[
					'label' => esc_html__( 'Background Color Hover', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template:hover, {{WRAPPER}} .ova-project-box-elementor .ova-project-box-template4:hover .info' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'padding_project_box',
				[
					'label' => esc_html__( 'Padding', 'ova-project' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border_project_box',
					'label' => esc_html__( 'Border', 'ova-project' ),
					'selector' => '{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'box_shadow_project_box',
					'label' => esc_html__( 'Box Shadow', 'ova-project' ),
					'selector' => '{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template',
				]
			);

        $this->end_controls_section();

		//******Info project Box style*****/
		$this->start_controls_section(
			'section_project_box_info_style',
			[
				'label' => esc_html__( 'Info Project Box', 'ova-project' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'template!' => ['template4']
				]
			]
		);

			$this->add_control(
				'bgcolor_project_box_info',
				[
					'label' => esc_html__( 'Background Color', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template .info' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'bgcolor_project_box_info_hover',
				[
					'label' => esc_html__( 'Background Color Hover', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template:hover .info' => 'background-color : {{VALUE}};',
					],
					'condition' => [
						'template!' => ['template2','template5']
					]
				]
			);

			$this->add_control(
				'bgcolor_project_box_info_template2_template5_hover',
				[
					'label' => esc_html__( 'Background Color Hover', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template .info:before, {{WRAPPER}} .ova-project-box-elementor .ova-project-box-template .info:after' => 'background-color : {{VALUE}};',
					],
					'condition' => [
						'template' => ['template2','template5']
					]
				]
			);

			$this->add_responsive_control(
				'padding_project_box_info',
				[
					'label' => esc_html__( 'Padding', 'ova-project' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template .info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'border_radius_project_box_info',
				[
					'label' => esc_html__( 'Border Radius', 'ova-project' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template .info' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'box_shadow_project_box_info',
					'label' => esc_html__( 'Box Shadow', 'ova-project' ),
					'selector' => '{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template .info',
				]
			);

        $this->end_controls_section();

        //******Category project*****/
		$this->start_controls_section(
			'section_category_project_style',
			[
				'label' => esc_html__( 'Category', 'ova-project' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'template!' => 'template5'
				]
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' => 'category_project_typography',
					'selector' => '{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template .info .category',
				]
			);

			$this->add_control(
				'line_color_project',
				[
					'label' => esc_html__( 'Line Color', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template .info .line' => 'background-color : {{VALUE}};',
					],
					'condition' => [
						'template' => ['template4','template6']
					]
				]
			);

			$this->add_control(
				'color_category_project',
				[
					'label' => esc_html__( 'Color', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template .info .category' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'color_category_project_hover',
				[
					'label' => esc_html__( 'Color Hover', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template:hover .info .category' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'padding_category_project',
				[
					'label' => esc_html__( 'Padding', 'ova-project' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template .info .category' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

        $this->end_controls_section();

        //******Title project*****/
		$this->start_controls_section(
			'section_title_project_style',
			[
				'label' => esc_html__( 'Title', 'ova-project' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' => 'title_project_typography',
					'selector' => '{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template .info .title',
				]
			);

			$this->add_control(
				'color_title_project',
				[
					'label' => esc_html__( 'Color', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template .info .title' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'color_title_project_hover',
				[
					'label' => esc_html__( 'Color Hover', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template:hover .info .title' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'padding_title_project',
				[
					'label' => esc_html__( 'Padding', 'ova-project' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template .info .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'margin_title_project',
				[
					'label' => esc_html__( 'Margin', 'ova-project' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template .info .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

        $this->end_controls_section();

        //****** Button *****/
		$this->start_controls_section(
			'section_button_style',
			[
				'label' => esc_html__( 'Button', 'ova-project' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'template!' => ['template5','template6']
				]
			]
		);

            $this->add_control(
				'icon_button_size',
				[
					'label' 		=> esc_html__( 'Icon Size', 'ova-project' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 40,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template a.next-button i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'button_color',
				[
					'label' => esc_html__( 'Color', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template a.next-button' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'button_color_hover',
				[
					'label' => esc_html__( 'Color Hover', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template a.next-button:hover' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'bgcolor_button',
				[
					'label' => esc_html__( 'Background Color', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-box-elementor .ova-project-box-template a.next-button, {{WRAPPER}} .ova-project-box-elementor .ova-project-box-template .info:before' => 'background-color : {{VALUE}};',
					],
				]
			);

        $this->end_controls_section();
	}

	// Render Template Here
	protected function render() {

		$settings       = $this->get_settings();
		$template       = apply_filters( 'el_ovapro_project_box', 'elementor/project-box.php' );

		ob_start();
		ovapro_get_template( $template, $settings );
		echo ob_get_clean();
	}

	
}

$widgets_manager->register( new Ova_Elementor_Project_Box() );