<?php
/**
 * @package    OVA Project by ovatheme
 * @author     Ovatheme
 * @copyright  Copyright (C) 2022 Ovatheme All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 */

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Ova_Elementor_Project_Filter_Ajax extends Widget_Base {

	public function get_name() {
		return 'ova_elementor_project_filter_ajax';
	}

	public function get_title() {
		return esc_html__( 'Project Filter Ajax', 'ova-project' );
	}

	public function get_icon() {
		return 'eicon-gallery-justified';
	}

	public function get_categories() {
		return [ 'ovapro' ];
	}

	public function get_script_depends() {
		wp_enqueue_style( 'project-owl-carousel', OVAPRO_PLUGIN_URI.'assets/libs/carousel/owl.carousel.min.css' );
		wp_enqueue_script( 'project-owl-carousel', OVAPRO_PLUGIN_URI.'assets/libs/carousel/owl.carousel.min.js', array('jquery'), false, true );
  		
  		wp_enqueue_script('project-fancybox', OVAPRO_PLUGIN_URI.'assets/libs/fancybox/fancybox.min.js', array('jquery'),null,true);
		wp_enqueue_style('project-fancybox', OVAPRO_PLUGIN_URI.'assets/libs/fancybox/fancybox.css', array(), null);

  		return [ 'ova-elementor-project-filter-ajax' ];
	}

  	
	protected function register_controls() {

		$this->start_controls_section(
			'section_project',
			[
				'label' => esc_html__( 'Project', 'ova-project' ),
			]
		);  


		    // Add Class control
			$this->add_control(
				'template',
				[
					'label' => esc_html__( 'Template', 'ova-project' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'template1',
					'options' => [
						'template1' => esc_html__('Template 1', 'ova-project'),
						'template2' => esc_html__('Template 2', 'ova-project'),
						'template3' => esc_html__('Template 3', 'ova-project'),
						'template4' => esc_html__('Template 4', 'ova-project'),
						'template5' => esc_html__('Template 5', 'ova-project'),
						'template6' => esc_html__('Template 6', 'ova-project'),
					]
				]
			); 

            $this->add_control(
				'posts_per_page',
				[
					'label'   => esc_html__( 'Project Per Category', 'ova-project' ),
					'type'    => Controls_Manager::NUMBER,
					'min'     => 1,
					'default' => 10
				]
			);

			$this->add_control(
				'project_orderby',
				[
					'label' => esc_html__( 'Order By', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'ID',
					'options' => [
						'ID'  => esc_html__( 'ID', 'ova-project' ),
						'title'   => esc_html__( 'Title', 'ova-project' ),
						'date'    => esc_html__( 'Date', 'ova-project' ),
					],
				]
			);

			$this->add_control(
				'project_order',
				[
					'label' => esc_html__( 'Order', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'ASC',
					'options' => [
						'ASC'  => esc_html__( 'Ascending', 'ova-project' ),
						'DESC'  => esc_html__( 'Descending', 'ova-project' ),
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_category',
			[
				'label' => esc_html__( 'Category Filter', 'ova-project' ),
			]
		);       

            $args = array(
				'taxonomy' 	=> 'category_project',
				'orderby' => 'name',
				'order' => 'ASC'
			);
  
		  	$categories   = get_categories($args);
		  	$cate_array   = array();
		  	$arrayCateAll = array( 'all' => esc_html__( 'All categories', 'ova-project' ) );
		  	if ($categories) {
			  	foreach ( $categories as $cate ) {
				  	$cate_array[$cate->slug] = $cate->name;
			  	}
		  	} else {
			  	$cate_array[ esc_html__( 'No content Category found', 'ova-project' ) ] = 0;
		  	}

			$this->add_control(
				'categories',
				[
					'label' => esc_html__( 'Categories', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'multiple' => true,
					'options' => array_merge( $arrayCateAll, $cate_array ),
					'default' => 'all'
				]
			);

			$this->add_control(
				'orderby',
				[
					'label' => esc_html__( 'Order By', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'ID',
					'options' => [
						'ID'  => esc_html__( 'ID', 'ova-project' ),
						'title'   => esc_html__( 'Title', 'ova-project' ),
						'date'    => esc_html__( 'Date', 'ova-project' ),
					],
				]
			);

			$this->add_control(
				'order',
				[
					'label' => esc_html__( 'Order', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'ASC',
					'options' => [
						'ASC'  => esc_html__( 'Ascending', 'ova-project' ),
						'DESC'  => esc_html__( 'Descending', 'ova-project' ),
					],
				]
			);

		$this->end_controls_section();

        /*****************************************************************
						START SECTION ADDITIONAL
		******************************************************************/

		$this->start_controls_section(
			'section_additional_options',
			[
				'label' => esc_html__( 'Additional Options Slider', 'ova-project' ),
			]
		);

			$this->add_control(
				'margin_items',
				[
					'label'   => esc_html__( 'Margin Right Items', 'ova-project' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 30,
					'description' => esc_html__( 'Item space between', 'ova-project' ),
				]	
			);

			$this->add_control(
				'stagePadding',
				[
					'label'   => esc_html__( 'Stage Padding', 'ova-project' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 0,
				]	
			);

			$this->add_control(
				'item_number',
				[
					'label'       => esc_html__( 'Item Number', 'ova-project' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Number Item', 'ova-project' ),
					'default'     => 2,
				]
			);

			$this->add_control(
				'slides_to_scroll',
				[
					'label'       => esc_html__( 'Slides to Scroll', 'ova-project' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Set how many slides are scrolled per swipe.', 'ova-project' ),
					'default'     => 1,
				]
			);

			$this->add_control(
				'pause_on_hover',
				[
					'label'   => esc_html__( 'Pause on Hover', 'ova-project' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'ova-project' ),
						'no'  => esc_html__( 'No', 'ova-project' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'infinite',
				[
					'label'   => esc_html__( 'Infinite Loop', 'ova-project' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'false',
					'options' => [
						'yes' => esc_html__( 'Yes', 'ova-project' ),
						'no'  => esc_html__( 'No', 'ova-project' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay',
				[
					'label'   => esc_html__( 'Autoplay', 'ova-project' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'false',
					'options' => [
						'yes' => esc_html__( 'Yes', 'ova-project' ),
						'no'  => esc_html__( 'No', 'ova-project' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay_speed',
				[
					'label'     => esc_html__( 'Autoplay Speed', 'ova-project' ),
					'type'      => Controls_Manager::NUMBER,
					'default'   => 3000,
					'step'      => 500,
					'condition' => [
						'autoplay' => 'yes',
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'smartspeed',
				[
					'label'   => esc_html__( 'Smart Speed', 'ova-project' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 1000,
				]
			);

			$this->add_control(
				'dots_control',
				[
					'label'   => esc_html__( 'Show Dots', 'ova-project' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'ova-project' ),
						'no'  => esc_html__( 'No', 'ova-project' ),
					],
					'frontend_available' => true,
				]
			);


		$this->end_controls_section();
		/****************************  END SECTION ADDITIONAL *********************/


		/****************************  SECTION TAB STYLE CATEGORY *********************/
		$this->start_controls_section(
			'style_section_category',
			[
				'label' => esc_html__( 'Category Filter', 'ova-project' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->start_controls_tabs('style_category_tabs');

				$this->start_controls_tab(
					'style_normal_category_tab',
					[
						'label' => esc_html__( 'Normal', 'ova-project' ),
					]
				);
			
					$this->add_control(
						'label_category_color',
						[
							'label' => esc_html__( 'Color', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-filter-ajax ul li' => 'color : {{VALUE}};',
							],
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Typography::get_type(),
						[
							'name' => 'category_label_typography',
							'selector' => '{{WRAPPER}} .ova-project-filter-ajax ul li ',
						]
					);

				
				$this->end_controls_tab();

				$this->start_controls_tab(
					'style_hover_category_tab',
					[
						'label' => esc_html__( 'Hover', 'ova-project' ),
					]
				);

					$this->add_control(
						'label_category_color_hover',
						[
							'label' => esc_html__( 'Color', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-filter-ajax ul li:hover .category' => 'color : {{VALUE}};',
								'{{WRAPPER}} .ova-project-filter-ajax ul li:hover .category-total' => 'color : {{VALUE}};',
							],
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Typography::get_type(),
						[
							'name' => 'category_label_typography_hover',
							'selector' => '{{WRAPPER}} .ova-project-filter-ajax ul li:hover .category',
						]
					);

				$this->end_controls_tab();

				$this->start_controls_tab(
					'style_active_category_tab',
					[
						'label' => esc_html__( 'Active', 'ova-project' ),
					]
				);

					$this->add_control(
						'label_category_color_active',
						[
							'label' => esc_html__( 'Color', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-filter-ajax ul li.active-category .category' => 'color : {{VALUE}};',
								'{{WRAPPER}} .ova-project-filter-ajax ul li.active-category .category-total' => 'color : {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'border_left_category_active_color',
						[
							'label' => esc_html__( 'Border Left Color', 'ova-project' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-project-filter-ajax ul li.active-category' => 'border-left-color : {{VALUE}};',
							],
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Typography::get_type(),
						[
							'name' => 'category_label_typography_active',
							'selector' => '{{WRAPPER}} .ova-project-filter-ajax ul li.active-category .category',
						]
					);

				$this->end_controls_tab();

			$this->end_controls_tabs();

			$this->add_control(
				'total_tab',
				[
					'label' => esc_html__( 'Total Category', 'ova-project' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

				// tab total category
				$this->start_controls_tabs('style_total_category_tabs');

					$this->start_controls_tab(
						'style_total_category_tab',
						[
							'label' => esc_html__( 'Normal', 'ova-project' ),
						]
					);

						$this->add_group_control(
							\Elementor\Group_Control_Typography::get_type(),
							[
								'name' => 'category_total_label_typography',
								'selector' => '{{WRAPPER}} .ova-project-filter-ajax ul li .category-total',
							]
						);

						$this->add_control(
							'label_category_total_color',
							[
								'label' => esc_html__( 'Color', 'ova-project' ),
								'type' => Controls_Manager::COLOR,
								'selectors' => [
									'{{WRAPPER}} .ova-project-filter-ajax ul li .category-total' => 'color : {{VALUE}};',
								],
							]
						);

					$this->end_controls_tab();

					$this->start_controls_tab(
						'style_total_hover_category_tab',
						[
							'label' => esc_html__( 'Hover', 'ova-project' ),
						]
					);
						
						$this->add_group_control(
							\Elementor\Group_Control_Typography::get_type(),
							[
								'name' => 'category_total_label_typography_hover',
								'selector' => '{{WRAPPER}} .ova-project-filter-ajax ul li:hover .category-total',
							]
						);

						$this->add_control(
							'label_category_total_color_hover',
							[
								'label' => esc_html__( 'Color', 'ova-project' ),
								'type' => Controls_Manager::COLOR,
								'selectors' => [
									'{{WRAPPER}} .ova-project-filter-ajax ul li:hover .category-total' => 'color : {{VALUE}};',
								],
							]
						);
					$this->end_controls_tab();

					$this->start_controls_tab(
						'style_total_active_category_tab',
						[
							'label' => esc_html__( 'Active', 'ova-project' ),
						]
					);
					
						$this->add_group_control(
							\Elementor\Group_Control_Typography::get_type(),
							[
								'name' => 'category_total_label_typography_active',
								'selector' => '{{WRAPPER}} .ova-project-filter-ajax ul li.active-category .category-total',
							]
						);

						$this->add_control(
							'label_category_total_color_active',
							[
								'label' => esc_html__( 'Color', 'ova-project' ),
								'type' => Controls_Manager::COLOR,
								'selectors' => [
									'{{WRAPPER}} .ova-project-filter-ajax ul li.active-category .category-total' => 'color : {{VALUE}};',
								],
							]
						);

					$this->end_controls_tab();

				$this->end_controls_tabs();

		$this->end_controls_section();
		/****************************  END SECTION TAB STYLE CATEGORY *********************/


		/****************************  SECTION TAB STYLE PROJECT BOX *********************/
		$this->start_controls_section(
			'section_project_box_style',
			[
				'label' => esc_html__( 'Item Project Box', 'ova-project' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'template' => ['template4']
				]
			]
		);

			$this->add_control(
				'bgcolor_project_box',
				[
					'label' => esc_html__( 'Background Color', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template, {{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template4 .info' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'bgcolor_project_box_hover',
				[
					'label' => esc_html__( 'Background Color Hover', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template:hover, {{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template4:hover .info' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'padding_project_box',
				[
					'label' => esc_html__( 'Padding', 'ova-project' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border_project_box',
					'label' => esc_html__( 'Border', 'ova-project' ),
					'selector' => '{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'box_shadow_project_box',
					'label' => esc_html__( 'Box Shadow', 'ova-project' ),
					'selector' => '{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template',
				]
			);

        $this->end_controls_section();

		//******Info project Box style*****/
		$this->start_controls_section(
			'section_project_box_info_style',
			[
				'label' => esc_html__( 'Info Project Box', 'ova-project' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'template!' => ['template4']
				]
			]
		);

			$this->add_control(
				'bgcolor_project_box_info',
				[
					'label' => esc_html__( 'Background Color', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template .info, {{WRAPPER}} .ova-project-filter-ajax .content-item .project-slider .info' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'bgcolor_project_box_info_hover',
				[
					'label' => esc_html__( 'Background Color Hover', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template:hover .info, {{WRAPPER}} .ova-project-filter-ajax .content-item .project-slider:hover .info' => 'background-color : {{VALUE}};',
					],
					'condition' => [
						'template!' => ['template2','template5']
					]
				]
			);

			$this->add_control(
				'bgcolor_project_box_info_template2_template5_hover',
				[
					'label' => esc_html__( 'Background Color Hover', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template .info:before, {{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template .info:after' => 'background-color : {{VALUE}};',
					],
					'condition' => [
						'template' => ['template2','template5']
					]
				]
			);

			$this->add_responsive_control(
				'padding_project_box_info',
				[
					'label' => esc_html__( 'Padding', 'ova-project' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template .info, {{WRAPPER}} .ova-project-filter-ajax .content-item .project-slider .info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'border_radius_project_box_info',
				[
					'label' => esc_html__( 'Border Radius', 'ova-project' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template .info, {{WRAPPER}} .ova-project-filter-ajax .content-item .project-slider .info' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'box_shadow_project_box_info',
					'label' => esc_html__( 'Box Shadow', 'ova-project' ),
					'selector' => '{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template .info, {{WRAPPER}} .ova-project-filter-ajax .content-item .project-slider .info',
				]
			);

        $this->end_controls_section();

        //******Category project*****/
		$this->start_controls_section(
			'section_category_project_style',
			[
				'label' => esc_html__( 'Category', 'ova-project' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'template!' => 'template5'
				]
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' => 'category_project_typography',
					'selector' => '{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template .info .category',
					'condition' => [
						'template!' => 'template1'
					]
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' => 'category_project_typography_t1',
					'selector' => '{{WRAPPER}} .ova-project-filter-ajax .content-item .project-slider .info .project-category',
					'condition' => [
						'template' => 'template1'
					]
				]
			);

			$this->add_control(
				'line_color_project',
				[
					'label' => esc_html__( 'Line Color', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template .info .line' => 'background-color : {{VALUE}};',
					],
					'condition' => [
						'template' => ['template4','template6']
					]
				]
			);

			$this->add_control(
				'color_category_project',
				[
					'label' => esc_html__( 'Color', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template .info .category, {{WRAPPER}} .ova-project-filter-ajax .content-item .project-slider .info .project-category' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'color_category_project_hover',
				[
					'label' => esc_html__( 'Color Hover', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template:hover .info .category, {{WRAPPER}} .ova-project-filter-ajax .content-item .project-slider:hover .info .project-category' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'padding_category_project',
				[
					'label' => esc_html__( 'Padding', 'ova-project' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template .info .category, {{WRAPPER}} .ova-project-filter-ajax .content-item .project-slider .info .project-category' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

        $this->end_controls_section();

        //******Title project*****/
		$this->start_controls_section(
			'section_title_project_style',
			[
				'label' => esc_html__( 'Title', 'ova-project' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' => 'title_project_typography',
					'selector' => '{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template .info .title',
					'condition' => [
						'template!' => 'template1'
					]
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' => 'title_project_typography_t1',
					'selector' => '{{WRAPPER}} .ova-project-filter-ajax .content-item .project-slider .info .name',
					'condition' => [
						'template' => 'template1'
					]
				]
			);

			$this->add_control(
				'color_title_project',
				[
					'label' => esc_html__( 'Color', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template .info .title, .ova-project-filter-ajax .content-item .project-slider .info .name' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'color_title_project_hover',
				[
					'label' => esc_html__( 'Color Hover', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template:hover .info .title, .ova-project-filter-ajax .content-item .project-slider .info .name:hover' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'padding_title_project',
				[
					'label' => esc_html__( 'Padding', 'ova-project' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template .info .title, .ova-project-filter-ajax .content-item .project-slider .info .name' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'margin_title_project',
				[
					'label' => esc_html__( 'Margin', 'ova-project' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template .info .title, .ova-project-filter-ajax .content-item .project-slider .info .name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

        $this->end_controls_section();

        //****** Button *****/
		$this->start_controls_section(
			'section_button_style',
			[
				'label' => esc_html__( 'Button', 'ova-project' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'template!' => ['template5','template6']
				]
			]
		);

            $this->add_control(
				'icon_button_size',
				[
					'label' 		=> esc_html__( 'Icon Size', 'ova-project' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 40,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template a.next-button i, {{WRAPPER}} .ova-project-filter-ajax .content-item .project-slider a.next-button' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'button_color',
				[
					'label' => esc_html__( 'Color', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template a.next-button, {{WRAPPER}} .ova-project-filter-ajax .content-item .project-slider a.next-button' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'button_color_hover',
				[
					'label' => esc_html__( 'Color Hover', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template a.next-button:hover, {{WRAPPER}} .ova-project-filter-ajax .content-item .project-slider a.next-button:hover' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'bgcolor_button',
				[
					'label' => esc_html__( 'Background Color', 'ova-project' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template a.next-button, {{WRAPPER}} .ova-project-filter-ajax .ova-project-box-template .info:before, {{WRAPPER}} .ova-project-filter-ajax .content-item .project-slider a.next-button' => 'background-color : {{VALUE}};',
					],
				]
			);

        $this->end_controls_section();
		/****************************  END SECTION TAB STYLE PROJECT *********************/


	}

	protected function render() {

		$settings = $this->get_settings();
	
		$template = apply_filters( 'el_ovapro_project_filter_ajax', 'elementor/project_filter_ajax.php' );

		ob_start();
		ovapro_get_template( $template, $settings );
		echo ob_get_clean();
		
	}
}

$widgets_manager->register( new Ova_Elementor_Project_Filter_Ajax() );