<?php
/**
 * @package    OVA Project by ovatheme
 * @author     Ovatheme
 * @copyright  Copyright (C) 2022 Ovatheme All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 */

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Ova_Elementor_Project_Title extends Widget_Base {

	public function get_name() {
		return 'ova_elementor_project_title';
	}

	public function get_title() {
		return esc_html__( 'Project Title', 'ova-project' );
	}

	public function get_icon() {
		return 'eicon-heading';
	}

	public function get_categories() {
		return [ 'ovapro' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}

	protected function register_controls() {
    

		$this->start_controls_section(
            'section_content',
            [
                'label' => esc_html__( 'Content', 'ova-project' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $this->add_control(
				'html_tag',
				[
					'label' 	=> esc_html__( 'HTML Tag', 'ova-project' ),
					'type' 		=> \Elementor\Controls_Manager::SELECT,
					'default' 	=> 'h2',
					'options' 	=> [
						'h1' 		=> esc_html__( 'H1', 'ova-project' ),
						'h2'  		=> esc_html__( 'H2', 'ova-project' ),
						'h3'  		=> esc_html__( 'H3', 'ova-project' ),
						'h4' 		=> esc_html__( 'H4', 'ova-project' ),
						'h5' 		=> esc_html__( 'H5', 'ova-project' ),
						'h6' 		=> esc_html__( 'H6', 'ova-project' ),
						'div' 		=> esc_html__( 'Div', 'ova-project' ),
						'span' 		=> esc_html__( 'span', 'ova-project' ),
						'p' 		=> esc_html__( 'p', 'ova-project' ),
					],
				]
			);

			$this->add_responsive_control(
				'align_heading',
				[
					'label' 	=> esc_html__( 'Alignment', 'ova-project' ),
					'type' 		=> \Elementor\Controls_Manager::CHOOSE,
					'options' 	=> [
						'left' => [
							'title' => esc_html__( 'Left', 'ova-project' ),
							'icon' 	=> 'eicon-text-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'ova-project' ),
							'icon' 	=> 'eicon-text-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'ova-project' ),
							'icon' 	=> 'eicon-text-align-right',
						],
					],
					'toggle' 	=> true,
					'selectors' => [
						'{{WRAPPER}} .ova-project-title' => 'text-align: {{VALUE}}',
					],
				]
			);
        

        $this->end_controls_section();

        //SECTION TAB STYLE TITLE
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'ova-project' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'content_typography_title',
					'label' 	=> esc_html__( 'Typography', 'ova-project' ),
					'selector' 	=> '{{WRAPPER}} .ova-project-title .project-title',
				]
			);

			$this->add_control(
				'color_title',
				[
					'label' 	=> esc_html__( 'Color', 'ova-project' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-project-title .project-title' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'padding_title',
				[
					'label' 	 => esc_html__( 'Padding', 'ova-project' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-project-title .project-title ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'margin_title',
				[
					'label' 	 => esc_html__( 'Margin', 'ova-project' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-project-title .project-title ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		//END SECTION TAB STYLE TITLE

	}

	protected function render() {

		$settings = $this->get_settings();

		$html_tag = $settings['html_tag'];
        
        // check id for get title
		$id 	  = get_the_ID();
        $all_ids  = ova_project_get_all_ids();
        
        $title    = '';
        if( in_array( $id, $all_ids ) ) {
        	$title = get_the_title( $id );
        } else {
        	$title = get_the_title( $all_ids[0] );
        }

		?>
            
            <?php if( !empty( $title ) ) : ?>

				<div class="ova-project-title">

	                <<?php printf($html_tag); ?> class="project-title"> 
						<?php echo esc_html( $title ); ?>
					</<?php printf( $html_tag ); ?>>

				</div>
				
			<?php endif; ?>

		<?php 
	}
}

$widgets_manager->register( new Ova_Elementor_Project_Title() );