<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Ovasev_Elementor_Service_Box extends Widget_Base {

	
	public function get_name() {
		return 'ovasev_elementor_service_box';
	}

	
	public function get_title() {
		return esc_html__( 'Service Box', 'ova-sev' );
	}

	
	public function get_icon() {
		return 'eicon-image-box';
	}

	
	public function get_categories() {
		return [ 'ovasev' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'ova-sev' ),
			]
		);	


		    // Add Class control
			$this->add_control(
				'template',
				[
					'label' => esc_html__( 'Template', 'ova-sev' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'template1',
					'options' => [
						'template1' => esc_html__('Template 1', 'ova-sev'),
						'template2' => esc_html__('Template 2', 'ova-sev'),
						'template3' => esc_html__('Template 3', 'ova-sev'),
						'template4' => esc_html__('Template 4', 'ova-sev'),
						'template5' => esc_html__('Template 5', 'ova-sev'),
						'template6' => esc_html__('Template 6', 'ova-sev'),
					]
				]
			);

			$args = array(
				'taxonomy' 	=> 'cat_sev',
				'orderby' => 'name',
				'order' => 'ASC'
			);
  
		  	$categories   = get_categories($args);
		  	$cate_array   = array();
		  	$arrayCateAll = array( 'all' => esc_html__( 'All categories', 'ova-sev' ) );
		  	if ($categories) {
			  	foreach ( $categories as $cate ) {
				  	$cate_array[$cate->slug] = $cate->name;
			  	}
		  	} else {
			  	$cate_array[ esc_html__( 'No content Category found', 'ova-sev' ) ] = 0;
		  	}

		  	$this->add_control(
			  	'category',
			  	[
				  	'label' => esc_html__( 'Category', 'ova-sev' ),
				  	'type' => Controls_Manager::SELECT,
				  	'default' => 'all',
				  	'options' => array_merge( $arrayCateAll, $cate_array ),
			  	]
		  	);

			$this->add_control(
				'number_column',
				[
					'label' => esc_html__( 'Column', 'ova-sev' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'three_column',
					'options' => [
						'two_column' => esc_html__('2 Column', 'ova-sev'),
						'three_column' => esc_html__('3 Column', 'ova-sev'),
						'four_column' => esc_html__('4 Column', 'ova-sev'),
					]
				]
			);

			$this->add_control(
				'post_per_page',
				[
					'label'   => esc_html__( 'Post Per Page', 'ova-sev' ),
					'type'    => Controls_Manager::NUMBER,
					'min'     => 1,
					'default' => 6
				]
			);

			$this->add_control(
				'order_by',
				[
					'label'   => esc_html__( 'Order By', 'ova-sev' ),
					'type'    => Controls_Manager::SELECT,
					'default' => 'date',
					'options' => [
						'title' => esc_html__( 'Title', 'ova-sev' ),
						'date' 	=> esc_html__( 'Date', 'ova-sev' ),
						'ID' 	=> esc_html__( 'ID', 'ova-sev' ),	
						'ova_sev_met_order_sev'  => esc_html__( 'Custom Order', 'ova-sev' ),		
					],
				]
			);

			$this->add_control(
				'order',
				[
					'label'   => esc_html__( 'Order', 'ova-sev' ),
					'type'    => Controls_Manager::SELECT,
					'default' => 'DESC',
					'options' => [
						'DESC' => esc_html__( 'Descending', 'ova-sev' ),
						'ASC'  => esc_html__( 'Ascending', 'ova-sev' ),
					],
				]
			);

			$this->add_control(
				'target_blank',
				[
					'label' 		=> esc_html__( 'Target Blank', 'ova-sev' ),
					'type' 			=> Controls_Manager::SWITCHER,
					'label_on' 		=> esc_html__( 'Yes', 'ova-sev' ),
					'label_off' 	=> esc_html__( 'No', 'ova-sev' ),
					'default' 		=> 'no',
				]
			);

		$this->end_controls_section();

		//******Service Box style*****/
		$this->start_controls_section(
			'section_service_box_style',
			[
				'label' => esc_html__( 'Item Service Box', 'ova-sev' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'template!' => ['template1','template2','template3']
				]
			]
		);

			$this->add_control(
				'bgcolor_service_box',
				[
					'label' => esc_html__( 'Background Color', 'ova-sev' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template, {{WRAPPER}} .ova-service-box-elementor .ova-service-box-template4 .info' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'bgcolor_service_box_hover',
				[
					'label' => esc_html__( 'Background Color Hover', 'ova-sev' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template:hover, {{WRAPPER}} .ova-service-box-elementor .ova-service-box-template4:hover .info' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'border_color_service_box_hover_template6',
				[
					'label' => esc_html__( 'Border Top Color Hover', 'ova-sev' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template6:hover' => 'border-top-color : {{VALUE}};',
					],
					'condition' => [
						'template' => 'template6'
					]
				]
			);

			$this->add_responsive_control(
				'padding_service_box',
				[
					'label' => esc_html__( 'Padding', 'ova-sev' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border_service_box',
					'label' => esc_html__( 'Border', 'ova-sev' ),
					'selector' => '{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'box_shadow_service_box',
					'label' => esc_html__( 'Box Shadow', 'ova-sev' ),
					'selector' => '{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template',
				]
			);

        $this->end_controls_section();

		//******Info Service Box style*****/
		$this->start_controls_section(
			'section_service_box_info_style',
			[
				'label' => esc_html__( 'Info Service Box', 'ova-sev' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'template!' => ['template4','template5','template6']
				]
			]
		);

			$this->add_control(
				'bgcolor_service_box_info',
				[
					'label' => esc_html__( 'Background Color', 'ova-sev' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template .info' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'bgcolor_service_box_info_hover',
				[
					'label' => esc_html__( 'Background Color Hover', 'ova-sev' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template:hover .info' => 'background-color : {{VALUE}};',
					],
					'condition' => [
						'template!' => 'template2'
					]
				]
			);

			$this->add_control(
				'bgcolor_service_box_info_template2_hover',
				[
					'label' => esc_html__( 'Background Color Hover', 'ova-sev' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template .info:before, {{WRAPPER}} .ova-service-box-elementor .ova-service-box-template .info:after' => 'background-color : {{VALUE}};',
					],
					'condition' => [
						'template' => 'template2'
					]
				]
			);

			$this->add_responsive_control(
				'padding_service_box_info',
				[
					'label' => esc_html__( 'Padding', 'ova-sev' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template .info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'border_radius_service_box_info',
				[
					'label' => esc_html__( 'Border Radius', 'ova-sev' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template .info' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'box_shadow_service_box_info',
					'label' => esc_html__( 'Box Shadow', 'ova-sev' ),
					'selector' => '{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template .info',
				]
			);

        $this->end_controls_section();

        //******Title Service*****/
		$this->start_controls_section(
			'section_title_service_style',
			[
				'label' => esc_html__( 'Title', 'ova-sev' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' => 'title_service_typography',
					'selector' => '{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template .info .title',
				]
			);

			$this->add_control(
				'color_title_service',
				[
					'label' => esc_html__( 'Color', 'ova-sev' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template .info .title' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'color_title_service_hover',
				[
					'label' => esc_html__( 'Color Hover', 'ova-sev' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template:hover .info .title' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'padding_title_service',
				[
					'label' => esc_html__( 'Padding', 'ova-sev' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template .info .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'margin_title_service',
				[
					'label' => esc_html__( 'Margin', 'ova-sev' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template .info .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

        $this->end_controls_section();

        //******Descriprion ( Excerpt )*****/
		$this->start_controls_section(
			'section_description_service_style',
			[
				'label' => esc_html__( 'Description', 'ova-sev' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'template!' => 'template1'
				]
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' => 'description_service_typography',
					'selector' => '{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template .description',
				]
			);

			$this->add_control(
				'color_description_service',
				[
					'label' => esc_html__( 'Color', 'ova-sev' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template .description' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'color_description_service_hover',
				[
					'label' => esc_html__( 'Color Hover', 'ova-sev' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template:hover .description' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'padding_description_service',
				[
					'label' => esc_html__( 'Padding', 'ova-sev' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template .description' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'margin_description_service',
				[
					'label' => esc_html__( 'Margin', 'ova-sev' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template .description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

        $this->end_controls_section();

		//****** Icon *****/
		$this->start_controls_section(
			'section_icon_style',
			[
				'label' => esc_html__( 'Icon', 'ova-sev' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

            $this->add_control(
				'icon_size',
				[
					'label' 		=> esc_html__( 'Icon Size', 'ova-sev' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 80,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template .img-service .icon i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'icon_color',
				[
					'label' => esc_html__( 'Icon Color', 'ova-sev' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template .img-service .icon i' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'bgcolor_icon',
				[
					'label' => esc_html__( 'Background Color', 'ova-sev' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template .img-service .icon' => 'background-color : {{VALUE}};',
					],
				]
			);


			$this->add_control(
				'bgcolor_square',
				[
					'label' => esc_html__( 'Square Background Color', 'ova-sev' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template1 .square' => 'background-color : {{VALUE}};',
					],
					'condition' => [
						'template' => 'template1',
					]
				]
			);

        $this->end_controls_section();

        //****** Button *****/
		$this->start_controls_section(
			'section_button_style',
			[
				'label' => esc_html__( 'Button', 'ova-sev' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

            $this->add_control(
				'icon_button_size',
				[
					'label' 		=> esc_html__( 'Icon Size', 'ova-sev' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 40,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template a.next-button i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'template!' => ['template2','template4']
					]
				]
			);

			$this->add_control(
				'button_color',
				[
					'label' => esc_html__( 'Color', 'ova-sev' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template a.next-button' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'button_color_hover',
				[
					'label' => esc_html__( 'Color Hover', 'ova-sev' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template a.next-button:hover' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'bgcolor_button',
				[
					'label' => esc_html__( 'Background Color', 'ova-sev' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template a.next-button, {{WRAPPER}} .ova-service-box-elementor .ova-service-box-template .info:before' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'bgcolor_button_hover',
				[
					'label' => esc_html__( 'Background Color Hover', 'ova-sev' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template a.next-button:hover' => 'background-color : {{VALUE}};',
					],
					'condition' => [
						'template!' => 'template6'
					]
				]
			);

			$this->add_control(
				'bgcolor_button_hover_template6',
				[
					'label' => esc_html__( 'Background Color Hover', 'ova-sev' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template6:hover a.next-button:before' => 'background-color : {{VALUE}};',
					],
					'condition' => [
						'template' => 'template6'
					]
				]
			);

			$this->add_responsive_control(
				'button_padding',
				[
					'label' => esc_html__( 'Padding', 'ova-sev' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .ova-service-box-elementor .ova-service-box-template a.next-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

        $this->end_controls_section();
	}

	// Render Template Here
	protected function render() {

		$settings       = $this->get_settings();
		$template       = apply_filters( 'el_ovasev_service_box', 'elementor/service-box.php' );

		ob_start();
		ovasev_get_template( $template, $settings );
		echo ob_get_clean();
	}

	
}

$widgets_manager->register( new Ovasev_Elementor_Service_Box() );